/***********************************************************************
 * Copyright (c) 2015 by SAS Institute Inc., Cary, NC, USA.            *
 *                                                                     *
 * NAME:          rrminit                                             *
 *                                                                     *
 * PURPOSE:       Initializes macro paths for SAS Regulatory Risk          *
 *                Management , reads the macro path         *
 *                from a metadata property and appends it to           *
 *                SASAUTO                                              *
 *                                                                     *
 * USAGE:         %rrminit(VERSION=)                                  *
 *                                                                     *
 * PARAMETERS:    VERSION     The product version number               *
 *                            (defaults to 5.2 in this release)        *
 *                                                                     *
 **********************************************************************/
%macro rrminit(VERSION=5.2);
*options mprint mlogic mprintnest mlogicnest symbolgen fullstimer;
   %global PRODUCT;
   %global RD_PRODNAME;
   %global RD_DVD;
   %global DVD;
   %global RD_SWC;


   %*------------------------------------------------------------------;
   %* Identify the product (note: values are case sensitive)           ;
   %*------------------------------------------------------------------;

   %let DVD=criskmmva;
   %let PRODUCT=CRISKM;
   %let RD_PRODNAME=SAS Regulatory Risk Management;
   %let RD_SWC=Reg Risk Mgmt Bank Srvr &VERSION;

   %*------------------------------------------------------------------;
   %* Check whether RD_DVD has already been set so that this logic is  ;
   %* not done twice.  To force the initialization to run again, set   ;
   %* RD_DVD back to empty.                                            ;
   %*------------------------------------------------------------------;

   %if (%bquote(&RD_DVD) eq &DVD) %then %do;
      %return;
   %end;

   %let RD_DVD = &DVD;

   /*set path for deployment root directory*/
   %global DEPLOYMENT_ROOT;
   %let DEPLOYMENT_ROOT=%sysget(SASROOT);

   /*get the ucmacros location from metadata property */
   %global outvar;
   data _null_;
      n = 1;
      length uri asn_uri propertyValue$ 500;
      length propertyName $32;
      uri="";
      asn_uri="";
      propertyValue="";
      propertyName="";
      nobj = metadata_getnobj("omsobj:SoftwareComponent?@Name='" || "&RD_SWC" || "'", n, uri);
      numasn = metadata_getnasn(uri, "PropertySets", 1, asn_uri);
      numasn = metadata_getnasn(asn_uri, "SetProperties", 1, uri);

      do while(1);
         rc = metadata_getattr(uri, "name", propertyName);
         if (propertyName = "criskmmvac.ucmacros.config.path") then do;
            rc = metadata_getattr(uri, "DefaultValue", propertyValue);
            call symput("outvar", trim(propertyValue));
            leave;
         end;
         else do;
            n = n + 1;
            if (n > numasn) then leave;
            rc = metadata_getnasn(asn_uri, "SetProperties", n, uri);
         end;
      end;

   run;

   /*get the Application location in Config location from metadata property */
   %global app_config_path;
   data _null_;
      n = 1;
      length uri asn_uri propertyValue$ 500;
      length propertyName $32;
      uri="";
      asn_uri="";
      propertyValue="";
      propertyName="";
      nobj = metadata_getnobj("omsobj:SoftwareComponent?@Name='" || "&RD_SWC" || "'", n, uri);
      numasn = metadata_getnasn(uri, "PropertySets", 1, asn_uri);
      numasn = metadata_getnasn(asn_uri, "SetProperties", 1, uri);

      do while(1);
         rc = metadata_getattr(uri, "name", propertyName);
         if (propertyName = "criskmmva.CMHOME") then do;
            rc = metadata_getattr(uri, "DefaultValue", propertyValue);
            call symput("app_config_path", trim(propertyValue));
            leave;
         end;
         else do;
            n = n + 1;
            if (n > numasn) then leave;
            rc = metadata_getnasn(asn_uri, "SetProperties", n, uri);
         end;
      end;

   run;

	
   %*------------------------------------------------------------------;
   %* Handling Lock down                                               ;
   %*------------------------------------------------------------------;
   filename tmp_file temp;
   libname testlib "&app_config_path";
   %rechk:
   data _null_;
	   dsetnm=compress("_&sysdate.&systime"||int(ranuni(0)*10000)," :");
	   call symput("dsetnm",dsetnm);
   run;
   %if %sysfunc(exist(&dsetnm))=0 %then %do;
   data testlib.&dsetnm;
		a=1;
   run;
   proc sql noprint;
		drop table testlib.&dsetnm;
   quit;
   %end;
   %if %sysfunc(exist(&dsetnm)) %then %do;
   		%goto rechk;
   %end;
   %if %eval(&syscc > 4 ) %then %do;
        %let rrm_err_key = 7;
		%put ERROR: %sysfunc(sasmsg(sashelp.msg1, &rrm_err_key., NOQUOTE)) &app_config_path..;
        %goto exit_postinit;
   %end;
	
	
   %*------------------------------------------------------------------;
   %* Set up HOST_UCMACRO_PATH according to the naming convention on   ;
   %* the current host machine                                         ;
   %*------------------------------------------------------------------;


   %let AUTOLIST = %sysfunc(compress(%sysfunc(getoption(sasautos)),%str(%(%))));
   %global HOST_UCMACRO_PATH;


      %let host_ucmacro_path = &host_ucmacro_path &outvar;


   %*------------------------------------------------------------------;
   %* Prepend the host_ucmacro path and remove any nested parentheses  ;
   %* and commas                                                       ;
   %*------------------------------------------------------------------;

     options sasautos = ("&host_ucmacro_path/common" &AUTOLIST);


	
	
	%exit_postinit:
	%let syscc=0;
	
	;
%mend rrminit;
