/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stored_process_reg.sas
 *
 *
 * PURPOSE: This program is a stored procedure running the regulatory project.
 *
 *   USAGE: 
 *
 *   NOTES: 1. Modified for V4.2
 *          2. 
 *          3. 
 *
 *         
 *         
 *****************************************************************************/


*Processbody;
%rrminit;

%macro runreg;

%local STP_NAME;
%let STP_NAME=B Regulatory calculations;

/*---------------------------------------------------------------------------
 * Step 1.
 *
 * Call autoexec for basic setup
 * -------------------------------------------------------------------------*/


%getdelimiter;


%autoexec_criskm (sysid=&SYSTEM_ID, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=&reg_ctxt,config_set=&config_set);

%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     ); 

/*---------------------------------------------------------------------------
 * Step 2.
 *
 * Check for existence of data files for user - continue if found
 * -------------------------------------------------------------------------*/
  %if &SYSTEM_FATAL_ERROR EQ N %then %do;
    /*- Check for a copy of the user directories -*/ 

    /*- need to remember user-specified options -*/
    
/*---------------------------------------------------------------------------
 * Step 3.
 *
 * Run approrpriate batch jobs - given previous runs by client
 * -------------------------------------------------------------------------*/

        %if %symglobl(RUN_STAGE) NE 1 %then %do;
            %let REFRESH = YES;
        %end;

        /*- only run necessary files -*/
        %if &REFRESH NE NO %then %do;
            %batch_criskm_00_initialize;     
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=10% );
            %batch_criskm_10_define_functions;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=20% );
            %batch_criskm_20_process_data;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );
            %batch_criskm_30_create_template;  
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=50% );
            %batch_criskm_35_run_tb_project;
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% );
      %batch_criskm_40_run_mtm_project;          
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=80% );
        %end;

        %else %if &RUN_STAGE = 0 %then %do;
            %batch_criskm_10_define_functions;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=20% );
            %batch_criskm_20_process_data;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );
            %batch_criskm_30_create_template;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=50% );
        %end;

        %else %if &RUN_STAGE = 10 %then %do;
            %batch_criskm_20_process_data;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );
            %batch_criskm_30_create_template;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=50% );
        %end;

        %else %if &RUN_STAGE = 20 %then %do;
            %batch_criskm_30_create_template;             
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=50% );
        %end;

        %else %if &RUN_STAGE = 30 %then %do;
        %batch_criskm_35_run_tb_project;
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% );
        %end;

        %else %if &RUN_STAGE = 35 %then %do;
        %batch_criskm_40_run_mtm_project;
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=80% );
        %end;

        %batch_crisk_50_run_reg_proj;
%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Complete,STATUS_PCT=100% );

        /*Creating the Result Views*/                                          
        %criskm_create_result_views; 

		options noovp noquotelenmax nocardimage;
%end; %else
    %if &SYSTEM_FATAL_ERROR EQ Y %then %do;
		%print_msg (error,1,5);
		%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Failed,STATUS_PCT=0% );
    %end;   
%mend runreg;

%runreg;
