/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stored_process_regrpt_prj_run_usfinal.sas
 *
 * PURPOSE: Runs extra projects for internal report data
 *
 *   USAGE: 
 *
 *   NOTES: 1. This runs data for internal report projects
 * 
 * UPDATES:
 * 1) 29th Jan 2009- runsasfile removed. lines 22 and 23 modified.
 *****************************************************************************/

%rrminit;

%global CUBE_OUTPUT;
%let CUBE_OUTPUT=NO;

%macro projmacro (CATEGORY);
   

%if %upcase(&CATEGORY)=WHOLESALE %then %e10_proj_regrpt_cap_usfinal(WHOLESALE); 
%else 
%if %upcase(&CATEGORY)=SECURITIZATION %then %e10_proj_regrpt_cap_usfinal(SECURITIZATION);  
%else 
%if %upcase(&CATEGORY)=RETAIL %then %e10_proj_regrpt_cap_usfinal(RETAIL); 
%else 
%if %upcase(&CATEGORY)=EQUITY %then %e10_proj_regrpt_cap_usfinal(EQUITY); 
%else 
%if %upcase(&CATEGORY)=ALL %then 
	%do;
	%e10_proj_regrpt_cap_usfinal(EQUITY);	
	%e10_proj_regrpt_cap_usfinal(RETAIL); 	
	%e10_proj_regrpt_cap_usfinal(SECURITIZATION);  	
	%e10_proj_regrpt_cap_usfinal(WHOLESALE); 

	%end;
%mend projmacro;





%macro regrpt; 

%local STP_NAME;
%let STP_NAME=Load FFIEC regulatory report data;


/*---------------------------------------------------------------------------
 * Step 1.
 *
 * Invoke autoexec to define libraries
 * 
 * -------------------------------------------------------------------------*/

 
 
%autoexec_criskm (sysid=&system_id, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=USFINAL);

%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );



/*Define frm_a00_init global macro variable to identify the call of a00_init_options macro from a00_init macro*/
%global frm_a00_init;
%let frm_a00_init=0;
%a00_init_options ;
%u00_recreate_macro_definitions;
%u_00_prep_port_header_usfinal;
 
%if "%trim(&run_stage)" ne "60" or %symexist(run_stage)=0 %then %do; %let SYSTEM_FATAL_ERROR=Y;%print_msg (error,3,23);%end;

/*---------------------------------------------------------------------------
 * Step 3. - Optional Run the setup if user requests
 *
 * Define library to regulatory project catalog and environments
 * We need to check to see if the portfolio was created
 * -------------------------------------------------------------------------*/
%if &SYSTEM_FATAL_ERROR EQ N %then %do;
        /*-Check security for user and request mode -*/


        %if &REFRESH ne NO %then %do;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %a00_initial_regrpt_usfinal; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %a10_create_regrpt_fmt_usfinal; %end;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=25% );     
          
          
          %if &SYSTEM_FATAL_ERROR NE Y %then 
            %do;
        		%if %upcase(&CATEGORY)=WHOLESALE %then 
        		%do; %b25_prep_regrpt_port_ws_usfinal;%end;
        		%else
        		%if %upcase(&CATEGORY)=SECURITIZATION %then 
        		%do; %b30_prep_regrpt_port_sec_usfinal; %end;
        		%else
                %if %upcase(&CATEGORY)=RETAIL %then 
                %do; %b20_prep_regrpt_port_ret_usfinal; %end;
                %else %if %upcase(&CATEGORY)=EQUITY %then
                %do; %b15_prep_regrpt_port_equ_usfinal; %end;
                %else %if %upcase(&CATEGORY)=ALL %then
                %do; 
                    %b15_prep_regrpt_port_equ_usfinal;
                    %b20_prep_regrpt_port_ret_usfinal;
                    %b25_prep_regrpt_port_ws_usfinal;
                    %b30_prep_regrpt_port_sec_usfinal;
                                         
                %end;

            %end;	
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=50% );     
            
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %c00_create_regrpt_environment; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %c10_def_regrpt_inst_var_usfinal; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %c10_def_regrpt_out_var_usfinal; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %c20_def_regrpt_ccvars_usfinal; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %d00_pm_regrpt_usfinal; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %d00_pm_regrpt_rollup_usfinal; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %d10_def_regrpt_inst_type_usfinal; %end;
          %if &SYSTEM_FATAL_ERROR NE Y %then %do; %d20_create_regrpt_portfolios; %end;
        %end;
        %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=75% );     

        /*---------------------------------------------------------------------------
         * Step 4.
         *
         * Run the Risk Dimensions projects for each of the major reports requested
         * Only run the project if the portfolio exists and no major errors are reported
         * -------------------------------------------------------------------------*/

        /* Set fileref tmprpt for report invocation statements */
        filename projrun catalog 'work.temp.projects.source'; 

        /*---------------------------------------------------------------------------
         * Step 5.
         *
         * Define library to internal reports catalog and environments
         * We need to check to see if the portfolio was created
         * -------------------------------------------------------------------------*/

        data _null_;
         file projrun;
         put '%macro runproject;';
         put '%put &CATEGORY;';
         put '%projmacro(&CATEGORY);';
         put '%mend runproject;';
         put '%runproject;';
        run;

        
        %inc projrun;

        %goto FINISH;

        %FINISH:
        %criskm_update_stp_status(STP_NAME=&STP_NAME,
									STP_STATUS=Complete,STATUS_PCT=100%,UPDATE_DTTM_FLG=Y  );


%end ; 
 %else
    %if &SYSTEM_FATAL_ERROR EQ Y %then %do;
		%error_occured:
		%print_msg (error,1,5);
		%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
										  STP_STATUS=Failed,STATUS_PCT=0%, UPDATE_DTTM_FLG=Y );
    %end;

%mend regrpt;

%regrpt;
/*****************************************************************************
 *  Save Macro Definitions so this step doesnot have to be run multiple times.
 *****************************************************************************/
 
%u00_save_macro_definitions;
