
/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a10_def_hcut_mat_bnd_rtn_bkt_fmt.sas
 *
 * PURPOSE: Creates formats for haircut maturity bands and rating buckets.
 *
 *   USAGE: 
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/
%macro a10_def_hcut_mat_bnd_rtn_bkt_fmt;

/*- 1: expand rating grade ranges for haircut buckets -*/
/*- formats for rating agencies have to be defined first -*/
%macro rating_bucket;  

    %local i AGEN; 
    
    data rd_conf.map_haircut_rating_buckets(keep = HAIRCUT_SET_ID HAIRCUT_TYPE EXT_ISSUE_MAP_RATING HAIRCUT_RATING_BUCKET);
    set rd_conf.map_haircut_rating_buckets;
    
    /*- the case where issue rating matters for haircut -*/
    if RATING_AGENCY NE '' and &NUM_AGENCIES_ISSUE > 0 then do;
    
        %do i = 1 %to &NUM_AGENCIES_ISSUE;
            %let AGEN = &&&AGENCY_ISSUE&i;
            if RATING_AGENCY = "&AGEN" then do;        
                if SHORT_TERM_FLG = 1 then do;
                    EXT_MAP_RATING_MIN = put(BUCKET_MIN_GRADE, $&AGEN._ST.);
                    EXT_MAP_RATING_MAX = put(BUCKET_MAX_GRADE, $&AGEN._ST.);              
                end;
                else do;
                    EXT_MAP_RATING_MIN = put(BUCKET_MIN_GRADE, $&AGEN..);
                    EXT_MAP_RATING_MAX = put(BUCKET_MAX_GRADE, $&AGEN..);              
                end;
            end;
        %end;
        END = input(substr(EXT_MAP_RATING_MIN, 4, 2), 8.);        
        START   = input(substr(EXT_MAP_RATING_MAX, 4, 2), 8.);
        PREFIX = substr(EXT_MAP_RATING_MAX, 1, 3);
        do i = START to END;
            if i < 10 then EXT_ISSUE_MAP_RATING = compress(PREFIX || '0' || i);
            else  EXT_ISSUE_MAP_RATING = compress(PREFIX || i);
            output;
        end;
        
    end;
    /*- the case where issue rating doesn't matter for haircut -*/    
    else do;
    
        EXT_ISSUE_MAP_RATING = '';
        output;
        
    end;
    
    run;
    
%mend;

%rating_bucket;

/*- 2: format for determining if rating bucket is needed -*/
/*- whether rating matters depends only on HAIRCUT_SET_ID and HAIRCUT_TYPE -*/
data fmt(drop = HAIRCUT_RATING_BUCKET);
set RD_CONF.map_haircut_rating_buckets(keep = HAIRCUT_SET_ID HAIRCUT_TYPE HAIRCUT_RATING_BUCKET);
HAIRCUT_RATING_NEEDED=(HAIRCUT_RATING_BUCKET NE 'ALL');
run;

proc sort data=fmt nodup;
by HAIRCUT_SET_ID HAIRCUT_TYPE HAIRCUT_RATING_NEEDED;
run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set fmt end = lastobs;
      FMTNAME          = 'MAP_HAIRCUT_RATING_NEEDED' ;
      START            = compress(HAIRCUT_SET_ID || HAIRCUT_TYPE) ;
      END              = START          ;
      LABEL            = HAIRCUT_RATING_NEEDED ;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            = '**OTHER**' ;
         END              = START;
         HLO              = 'O' ;
         LABEL            = .;
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- 3: format for needed rating buckets -*/
data fmt(keep = HAIRCUT_SET_ID EXT_ISSUE_MAP_RATING HAIRCUT_RATING_BUCKET);
set RD_CONF.map_haircut_rating_buckets(where = (HAIRCUT_RATING_BUCKET NE 'ALL'));
run;

proc sort data=fmt nodup;
by HAIRCUT_SET_ID EXT_ISSUE_MAP_RATING HAIRCUT_RATING_BUCKET;
run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set fmt end=lastobs;
      FMTNAME          = 'MAP_HAIRCUT_RATING_BUCKET' ;
	  TYPE='C';
      if &NUM_AGENCIES_ISSUE > 0 then do;       
         START            = compress(HAIRCUT_SET_ID || EXT_ISSUE_MAP_RATING) ;
         END              = START          ;
         LABEL            = HAIRCUT_RATING_BUCKET ;
         output ;
      end;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- 4: get necessary maturity band and rating bucket combination -*/
proc sql;
create table _haircut_mat_bands_ as
select unique
       h.HAIRCUT_SET_INDEX, h.HAIRCUT_SET_ID, 
       m.HAIRCUT_TYPE, m.HAIRCUT_MAT_START, m.HAIRCUT_MAT_END, m.HAIRCUT_MAT_BAND,
       r.HAIRCUT_RATING_BUCKET
from RD_CONF.map_haircut_mat_bands as m
     inner join RD_CONF.haircuts as h 
     on m.HAIRCUT_SET_ID = h.HAIRCUT_SET_ID and m.HAIRCUT_TYPE = h.HAIRCUT_TYPE and m.HAIRCUT_MAT_BAND = h.HAIRCUT_MAT_BAND
     inner join RD_CONF.map_haircut_rating_buckets as r
     on r.HAIRCUT_SET_ID = h.HAIRCUT_SET_ID and r.HAIRCUT_TYPE = h.HAIRCUT_TYPE and r.HAIRCUT_RATING_BUCKET = h.HAIRCUT_RATING_BUCKET
;
quit;

data RD_CONF.map_haircut_mat_bands;
set _haircut_mat_bands_;
run;

/*- 5: format for determining if residual maturity band is needed -*/
/*- whether residual maturity matters in haircut determination depends on the following factors -*/
/*- HAIRCUT_SET_ID HAIRCUT_TYPE HAIRCUT_RATING_BUCKET -*/
data fmt(drop = HAIRCUT_MAT_BAND);
set RD_CONF.map_haircut_mat_bands(keep = HAIRCUT_SET_ID HAIRCUT_TYPE HAIRCUT_RATING_BUCKET HAIRCUT_MAT_BAND);
HAIRCUT_MAT_NEEDED = (HAIRCUT_MAT_BAND NE 'ALL'); 
run;

proc sort data=fmt nodup;
by HAIRCUT_SET_ID HAIRCUT_TYPE HAIRCUT_RATING_BUCKET HAIRCUT_MAT_NEEDED;
run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set fmt end = lastobs;
      FMTNAME          = 'MAP_HAIRCUT_MAT_NEEDED' ;
      START            = compress(HAIRCUT_SET_ID || HAIRCUT_TYPE || HAIRCUT_RATING_BUCKET) ;
      END              = START          ;
      LABEL            =  HAIRCUT_MAT_NEEDED ;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            = '**OTHER**' ;
         END              = START;
         HLO              = 'O' ;
         LABEL            = .;
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*-6: format for needed maturity bands -*/
data fmt(keep = HAIRCUT_SET_INDEX HAIRCUT_MAT_START HAIRCUT_MAT_END HAIRCUT_MAT_BAND);
set RD_CONF.map_haircut_mat_bands(where = (HAIRCUT_MAT_BAND NE 'ALL'));
run;

proc sort data=fmt nodup;
by HAIRCUT_SET_INDEX HAIRCUT_MAT_START HAIRCUT_MAT_END HAIRCUT_MAT_BAND;
run;

data fmt (keep=FMTNAME START END LABEL TYPE SEXCL EEXCL HLO);
set fmt end = lastobs;
by HAIRCUT_SET_INDEX;
      FMTNAME          = compress('MAP_HAIRCUT_' || HAIRCUT_SET_INDEX || '_MAT_BAND');
      START            = putc(left(HAIRCUT_MAT_START), 32.) ;
      END              = putc(left(HAIRCUT_MAT_END), 32.) ;
      LABEL            = HAIRCUT_MAT_BAND;
      TYPE             = 'N' ;
      if first.HAIRCUT_SET_INDEX then SEXCL = 'N';
      else                      SEXCL = 'Y';     
      EEXCL = 'N';
      output ;
      
      if last.HAIRCUT_SET_INDEX then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*-7: delete unwanted data sets -*/
%clean_lib;
%mend a10_def_hcut_mat_bnd_rtn_bkt_fmt;
