
/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a15_define_mtm_functions.sas
 *
 * PURPOSE: Create a library of general utility functions for mark-to-market.
 *
 *   USAGE: 
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/
%macro a15_define_mtm_functions;
/*- function to get row name and column name in haircut parameter matrix -*/
Subroutine GET_HAIRCUT_NAME(HAIRCUTTYPE $, ISSUERTYPE $, RATINGBUCKET $, 
                            RESMATBAND $, HAIRCUTNAME $, HAIRCUTCOLUMN $)
           kind  = "MtM Functions";

    length HAIRCUTNAME   $ 32 ;
    length HAIRCUTCOLUMN $ 32 ;
    length HAIRCUTTYPE   $ 32 ;
    length ISSUERTYPE    $ 32 ;
    length RATINGBUCKEt  $  8 ;
    length RESMATBAND    $  8 ;
    length THAIRCUTNAME  $ 32 ;

    outargs HAIRCUTNAME, HAIRCUTCOLUMN ;
  
    if ISSUERTYPE = 'SOVEREIGN' then 
        HAIRCUTCOLUMN = 'HAIRCUT_SOVEREIGN';
    else
        HAIRCUTCOLUMN = 'HAIRCUT_OTHER';

    if HAIRCUTTYPE = '' then THAIRCUTNAME = 'H_ZERO';
    else THAIRCUTNAME = compress('H_' || HAIRCUTTYPE);
    
    THAIRCUTNAME = compress(tHAIRCUTNAME || '_' || RATINGBUCKET || '_' || RESMATBAND);
    
    HAIRCUTNAME = THAIRCUTNAME;

endsub;


Subroutine GET_ADDON_NAME(ADDONMETHOD $, ADDONTYPE $, RESMATBAND $, ADDONNAME $)
           kind = "MtM Functions";
           
    length ADDONMETHOD $  8;
    length ADDONTYPE   $ 20;
    length RESMATBAND  $  8;
    length ADDONNAME   $ 36;
    length TADDONNAME  $ 36;
    outargs ADDONNAME;
    
    TADDONNAME = kcompress('ADDON_' || ADDONMETHOD || '_' || ADDONTYPE || '_' || RESMATBAND);

    ADDONNAME = TADDONNAME;

endsub;           


Subroutine GET_CCF_NAME_SUPERVISORY(APPROACH $, CCFTYPE $, CCFNAME $)
           kind = "MtM Functions";

    length CCFTYPE       $ 32;
    length APPROACH      $ 8;
    length CCFNAME       $ 32;
    length TCCFNAME      $ 32;
    outargs CCFNAME;
   
    if APPROACH = 'STD' then TCCFNAME =compress('STD' || '_' || CCFTYPE);
    else TCCFNAME =compress('IRB' || '_' || CCFTYPE);
    
    CCFNAME = TCCFNAME;

endsub;

Subroutine GET_CCF_NAME_OWN_ESTIMATE(CCFBUCKETTYPE $, CCFNAME $)
           kind = "MtM Functions";

    length CCFBUCKETTYPE $ 32;
    length CCFNAME       $ 32;
    
    outargs CCFNAME;
       
    CCFNAME = CCFBUCKETTYPE;

endsub;

Subroutine GET_CCF_NAME_SEC_EAP(EAPTYPE $, CCFTYPE $, CCFNAME $)
           kind = "MtM Functions";

    length EAPTYPE $ 32;
    length CCFTYPE $ 32;
    length CCFNAME $ 32;
    length TCCFNAME      $ 32;
    
    outargs CCFNAME;
       
    if EAPTYPE = 'CONTROLLED' then do;
        tCCFNAME = compress('CEAP_' || CCFTYPE);
    end;
    else if EAPTYPE = 'NON_CONTROLLED' then do;
        tCCFNAME = compress('NCEAP_' || CCFTYPE);
    end;
    
    CCFNAME = TCCFNAME;

endsub;

/*- calculates the date that is exactly Nmbr_mth months after Refdate -*/
function Calc_Next_Date (Refdate, Nmbr_mth)
  label = "Return the date that is exactly Nmbr_mth months further than Refdate"
  kind  = "General Functions";

  beginmonth = intnx('month',RefDate,Nmbr_mth);
  daymax = day (intnx ('month',beginmonth ,1)-1);
  if day(refdate) le daymax then
     sameday_next = mdy (month(beginmonth) , day(refdate), year(beginmonth));
  else
     sameday_next = mdy (month(beginmonth) , daymax, year(beginmonth));

  return (sameday_next);
endsub;


function Bond_CF_PRC(valuation_date, parvalue, n_annum_coupon, coupon, maturity_date, spotval[*], maturity[*]) kind  = pricing
  label = "Fixed Coupon Bond Pricing";;
    
  prc = 0;
  prcdate = valuation_date;
  npoint = dim(spotval);
  /*-- case if stale -----------------------------------------*/
  if (prcdate > maturity_date) then return(0);

  if n_annum_coupon < 0 then return(.);
  if n_annum_coupon = 0 then do;
    time = intck('day',prcdate,maturity_date)/365;
    /*- get spotrates by simple linear interpolation ----------------*/
    if ( time <= maturity{1} ) then spotrate = spotval{1};
    if ( time >= maturity{npoint} ) then spotrate = spotval{npoint};

    if (time > maturity{1}) and (time < maturity{npoint}) then do;
      do j = 1 to npoint-1;
      if (time > maturity{j}) and (time <= maturity{j+1}) then do;
        spotrate = spotval{j} + ( ( spotval{j + 1} - spotval{j} )
          * ( time - maturity{j} ) / ( maturity{j+1} - maturity{j} )
          );
        end;
      end;
    end;
    prc = prc + parvalue* exp ( - (spotrate * time) );
  end;
  else do;
    coupfreq = 12/n_annum_coupon;
    mondiff = 0;

    /*-- real coupon rate --------------------------------------*/
    rate = coupon * coupfreq / 12;
    valdate = maturity_date;
    
    /*-- calculate the cash flow dates and amounts --------------*/
    do while(prcdate <= valdate);
      time = intck('day',prcdate,valdate)/365;
      /*- get spotrates by simple linear interpolation ----------------*/
      if ( time <= maturity{1} ) then spotrate = spotval{1};
      if ( time >= maturity{npoint} ) then spotrate = spotval{npoint};
      
      if (time > maturity{1}) and (time < maturity{npoint}) then do;
        do j = 1 to npoint-1;
          if (time > maturity{j}) and (time <= maturity{j+1}) then do;
            spotrate =  spotval{j} + ( ( spotval{j + 1} - spotval{j} )
      * ( time - maturity{j} ) / ( maturity{j+1} - maturity{j} )
      );
    end;
  end;
      end;
      prc = prc + rate*parvalue* exp ( - (spotrate * time) );
      
      if (valdate = maturity_date) then prc = prc + parvalue* exp ( - (spotrate * time) );
      
      mondiff = mondiff - coupfreq;
      valdate = intnx('month', maturity_date, mondiff, 'same');
    end;
  end;
  return(prc);
endsub;

function Bond_EFF_MAT(current_date, parvalue, n_annum_coupon, coupon, maturity_date)
  label = "Fixed Coupon Bond Effective Maturity";

  if parvalue = 0 or current_date > maturity_date then return (0);
  /*- Temporary variables -*/
  numerator   = 0;
  denominator = 0;
  prcdate = current_date;
  
  /*- The case of stale should be already checked in ETL -*/
  if n_annum_coupon <0  then return(.);
  if n_annum_coupon = 0 then do;
    numerator   = numerator + (maturity_date - current_date) * parvalue / 365.25;
    denominator = denominator + parvalue;
  end;
  else do;
    /*- calculate coupon frequency -------------------------*/
    coupfreq = 12/n_annum_coupon;
    mondiff = 0;
    /*- calculate periodic cashflow -------------------------*/
    cashflow = coupfreq * parvalue * coupon/12 ;
    
    valdate = maturity_date;
    /*-- calculate the cash flow dates and amounts --------------*/
    do while(prcdate <= valdate);
      numerator = numerator + (valdate - prcdate) * cashflow / 365.25;
      denominator = denominator + cashflow;
      if (valdate = maturity_date) then do;
        numerator = numerator + (valdate - prcdate) * parvalue / 365.25;
        denominator = denominator + parvalue;
      end;
      
      mondiff = mondiff - coupfreq;
      valdate = intnx('month', maturity_date, mondiff, 'same');
    end;
  end;
  return(numerator/denominator);
endsub;
%mend a15_define_mtm_functions;
