/*****************************************************************************
* Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b30_prep_regrpt_port_le45_crd4.sas
*
* PURPOSE: Create portoflio data for CR regulatory reports (LE Template )
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
 
/*---------------------------------------------------------------------------
* Step 1. Check to see if the user has requested LE4 or LE5 data
* -------------------------------------------------------------------------*/
 
%macro b30_prep_regrpt_port_le45_crd4;
%macro prepare_regrpt_port_le45 (inputds);
%let HAVEDATA=NO;
 
%if  
	 (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LE4_CRD4) OR
	 (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LE5_CRD4) OR
     (%UPCASE(&REGPROJECTNAME) EQ ALL) 


%then %do;
 
%if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
%then %do;
 
   libname _incrlib  "&REGPATH";
   %goto checkirba_opt;
 
%end;
 
%else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
%then %do;
 
   libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
   %goto checkirba_rnk;
 
%end;
 
%end;
    
%else %goto SKIP;
 
 
/*---------------------------------------------------------------------------
* Step 2. Check to see if we have data
* -------------------------------------------------------------------------*/
 
%SKIP:
/* User did not request LE portfolio - skip */
%put WARNING: User did not request Large exposure template;
%return;
 
 
%CHECKIRBA_OPT:
%checkdata (_incrlib, &INPUTDS , LE_COUNTERPARTY_RK ne .);
 
%CHECKIRBA_RNK:
%checkdata (_incrlib, &INPUTDS , LE_COUNTERPARTY_RK ne .);
 
 
/* If no data then return*/
%if   (&HAVEDATA = NO)  %then %do;
   %print_msg (WARNING,3,1);/*------------------------>Change this message*/
   %return;
%end;
 
/*---------------------------------------------------------------------------
* Step 3. Creating portfolio for LE counterparties
* -------------------------------------------------------------------------*/
 
%print_msg(note,3,26);
%if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,108);
/*Filter out data on the basis of LE_COUNTERPARTY_RK*/ 
/*calculate the obligor_pd buckets (by counterparty) */

data work._inputs_;
   set _incrlib.&INPUTDS(where=(LE_COUNTERPARTY_RK NE .));
   if CRM_ID NE '' then _pd_val_ = PD_CRM_COUNTERPARTY;
   else _pd_val_ = PD_EXP;
run;

proc sort data=work._inputs_ ;
   by LE_COUNTERPARTY_RK;
run;


/*Make sure that the SPECIFIC_PROVISIONS will be nullified for duplicate EXP_ID records*/
proc sort data=work._inputs_;
   by EXP_ID;
run;


data work._inputs_;
   set work._inputs_;
   if FIRST.EXP_ID then VALID_PROVISION = 1;
   else VALID_PROVISION = 0;
   by exp_id;
run;


data _intds.CAPITAL_LE45;
   length INTERNAL_ORG_RK LECPTYID $25.;
   set work._inputs_(rename=(INTERNAL_ORG_RK=INT_ORG_RK));
   if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) ); 
   
   /* 3e. Define the CRM groups and products */
   IF CRM_ID NE '' then DO;
      SPECIFIC_PROVISION = 0;
   END;
   
   INSTID = compress('INSTID_'||_n_);
   if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) );
   INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);

   IF (NOT MISSING(LE_COUNTERPARTY_RK)) THEN LECPTYID = compress('LE' || input(LE_COUNTERPARTY_RK, $30.));
   VALUE_ADJ_AMT = sum(0, SPECIFIC_PROVISION); /*col 210*/
   IF	UNDERLYING_EXP_EAD NOT IN (.,0) THEN DO;
      UNDERLYING_FLG='YES';
   END;
   ELSE DO;
      UNDERLYING_FLG='NO';
   END;
   RESIDUAL_MATURITY_MTH1=RESIDUAL_MATURITY*12;
	
   TOT_ORIG_EXP= SUM(LE_ORIG_EXPOSURE_AMT,UNDERLYING_EXP_EAD);
		
run;

 /*enrichment of crm allocation with cashflow information begins*/
proc sql;
   create table  _intds.cashflow_cpty_details as
   select  a.LE_counterparty_rk, a.counterparty_id, a.counterparty_group,
           a.counterparty_cd, b.* from _intds.CAPITAL_LE45 as a join rd_stage.cashflow_details as b
   on a.exp_id=b.instid
   ;
quit;

%let rundate1=%sysfunc(putn(&rundate,date9.));

data _intds.cashflow_cpty_details; 
   set _intds.cashflow_cpty_details;
   RESIDUAL_MATURITY = max(0, round(YRDIF(&RUNDATE, cashflow_dt, "&DAY_BASIS"),&MATURITY_ROUNDOFF.));
   RESIDUAL_MATURITY_MTH=RESIDUAL_MATURITY*12;
run;

DATA _intds.cashflow_capital_le;
   merge _intds.cashflow_cpty_details(rename=(instid=exp_id)) _intds.CAPITAL_LE45;
   by exp_id;
RUN;

data _intds.cashflow_capital_le;
   set _intds.cashflow_capital_le;
   if missing(cashflow_dt) then RESIDUAL_MATURITY_MTH=RESIDUAL_MATURITY_MTH1;
   MATURITY_DESCRIPTION =  put(RESIDUAL_MATURITY_MTH,MAP_MAT_BUCKETS_LE.);
   if missing (CASHFLOW_AMT) then CASHFLOW_AMT=LE_ORIG_EXPOSURE_AMT;

run;

proc sort data=_intds.cashflow_capital_le; 
  by exp_id; 
run;

data _intds.cashflow_capital_le ;
   set _intds.cashflow_capital_le;
   by exp_id;
   if (first.exp_id*last.exp_id) eq 1 or cashflow_amt ne .;
run;
/*enrichment of crm allocation with cashflow information ends*/

/*Part 3: Calculate all largest exposures, 10 largest (URE, FI)*/

proc sql noprint;
   create table capital_le_group as 
   select *
   FROM _INTDS.CAPITAL_LE45 
   where COUNTERPARTY_GROUP is not missing and COUNTERPARTY_GROUP ^= "" ;
QUIT;

PROC SQL NOPRINT;
   CREATE TABLE capital_le_IND AS 
   SELECT *
   FROM _INTDS.CAPITAL_LE45
   where COUNTERPARTY_GROUP is missing
   GROUP BY LECPTYID ;
QUIT;

%get_valid_large_exposures_crd4(get_largest_IRB = FALSE);
 
 
 proc sql ;
  create table _intds.capital_le4 as
 	select *, 'regrpt_le4' as INSTTYPE
 		from _intds.cashflow_capital_le
 			where le_counterparty_rk in ( &le_cpty_i,&le_cpty_u);
 quit;
 
 proc sql ;
  create table _intds.capital_le5 as
 	select *, 'regrpt_le5' as INSTTYPE
  		from _intds.cashflow_capital_le
  			where le_counterparty_rk in ( &le_cpty_i,&le_cpty_u);
  quit;
 
data _intds.capital_le5;
   set _intds.capital_le5;
   insttype='regrpt_le5';
   where counterparty_group ne '';
run;


%checkdata (_intds,CAPITAL_LE4, LE_COUNTERPARTY_RK NE . );
data _intds.CAPITAL_LE4_CRD4;
   set _intds.CAPITAL_LE4;
run; 

proc sql; 
   drop table _intds.CAPITAL_LE4;
quit;	

%if &HAVEDATA = YES %then %do;
   %status(CAPITAL_LE4_CRD4,SUCCESS,Large Exposures,CAPITAL_LE4_CRD4);
%end;
%else %do;
   %print_msg (WARNING,3,62);
   %status(CAPITAL_LE4_CRD4,ERROR,Problems creating input data for portfolio,CAPITAL_LE4_CRD4);
%end;


%checkdata (_intds,CAPITAL_LE5, LE_COUNTERPARTY_RK NE . );
data _intds.CAPITAL_LE5_CRD4;
   set _intds.CAPITAL_LE5;
run; 

proc sql; 
   drop table _intds.CAPITAL_LE5;
quit;	

%if &HAVEDATA = YES %then %do;
   %status(CAPITAL_LE5_CRD4,SUCCESS,Large Exposures,CAPITAL_LE5_CRD4);
%end;
%else %do;
   %print_msg (WARNING,3,62);
   %status(CAPITAL_LE5_CRD4,ERROR,Problems creating input data for portfolio,CAPITAL_LE5_CRD4);
%end;

/*deassign the library */ 
%mend prepare_regrpt_port_le45;
 
 
%prepare_regrpt_port_le45(crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail);
options notes source;


%mend b30_prep_regrpt_port_le45_crd4;
