/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b36_process_trading_book.sas
 *
 * PURPOSE: Process trading book data
 *   USAGE: 
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/
 

%macro b36_process_trading_book;

/*- define macro to retrieve financial collaterals on the trading book -*/
 %global N_TB_IMM N_TB_STD MAX_RES_MATURITY MAX_ORG_MATURITY;
 %let N_TB_IMM = 0;
 %let N_TB_STD = 0;
 
/*- get financial collaterals that are used in trading books -*/
 %macro get_fin_collateral_trading_book(crm_data);
  data &crm_data._trading_book &crm_data (drop=CCR_APPROACH index=(ISSUE_KEY));
  merge &crm_data (in=a) RD_POS.fin_collateral_trading_book (in=b);
  by INSTID;
  if a;
  if b then do;
     COLLATERAL_FLG = 1;
     output &crm_data._trading_book;
  end;
  else output &crm_data;
  run;
 %mend get_fin_collateral_trading_book;

/*- get user supplied risk positons together with position data -*/
 %macro get_risk_positions(in_data, collateral);
  %local VAR_EXIST;
  %let VAR_EXIST=%varexist(&in_data, NEXT_CONTRACT_RESET_DATE);
  
  data &in_data._rp (keep=COUNTERPARTY_RK INSTID ISSUE_KEY NETTINGSETID HEDGING_SET_ID 
                          HEDGING_SET_RK RISK_POSITION_ID RISK_COMPONENT_AMT RISK_COMPONENT_CURRENCY_CD
                          RISK_FACTOR_ID RESIDUAL_MATURITY HEDGING_SET_TYPE_CD COLLATERAL_FLG 
                          COUNTERPARTYID INSTTYPE SHORTPOSITION CCF_SET CCF_TYPE HOLDING
                          %if &VAR_EXIST %then %do; NEXT_CONTRACT_RESET_DATE %end; 
                          %if &collateral = 0 %then %do; NETTING_SET_RK %end;
                     rename=(RISK_COMPONENT_AMT=DELTA RISK_COMPONENT_CURRENCY_CD=CURRENCY)
                     index=(RPKEY=(INSTID ISSUE_KEY RISK_FACTOR_ID))
                     ); 
  merge &in_data (in=a) RD_POS.risk_position (in=b);
  by ISSUE_KEY;
  retain counter 1;
  if a and b;
  length INSTTYPE $32.;    
  INSTID=compress(INSTID||"_U_"||counter);
  %if &VAR_EXIST %then %do;
  if not missing(NEXT_CONTRACT_RESET_DATE) then
     HEDGING_SET_MATURITY = max(0, round(YRDIF(&RUNDATE, NEXT_CONTRACT_RESET_DATE, "&DAY_BASIS"),&MATURITY_ROUNDOFF.));
  else 
  %end;
     HEDGING_SET_MATURITY = RESIDUAL_MATURITY;
  
  HEDGING_SET_MAT_BAND = put(HEDGING_SET_MATURITY, MAP_HEDGING_SET_MAT_BAND.);
  if MAT_BAND_FLG = 1 then
     HEDGING_SET_ID = compress(HEDGING_SET_ID||"_"||HEDGING_SET_MAT_BAND);
  if &collateral then COLLATERAL_FLG = 1;
  
  CCF_SET = put("&CCF_SET", $MAP_CCF_SET.);
  CCF_TYPE = put(compress("&CCF_SET" ||HEDGING_SET_TYPE_CD), $MAP_CCF_TYPE_STD_CCR.);
  
  if COLLATERAL_FLG=1 then 
     SHORTPOSITION = 1;
  else 
     SHORTPOSITION = 0;
  INSTTYPE = 'PRICED_RP';
  counter = counter + 1;
  run;
 %mend;
 
/*- main body macro -*/
 %macro process_trading_book;
 %local N_EXP_NO_RF N_STD_NO_RF N_IMM_NO_RF;
 
 /*- only if trading book exposures exist -*/
 %if &N_TRADING_BOOK_EXP GT 0 %then %do;
 /*- The following block could be optional if a trading book item is purchasd
     as a credit mitigant against a banking book exposure then it needs to 
     be flaggd here.  A better way to handle it is not to enter such 
     exposure as a trading book exposure.  But a bank may like to do so
     for the data integrity purpose                                      -*/
     proc sql;
     alter table RD_POS.exposure_trading_book
     add BANK_BOOK_CRM_FLG num;
     
     update RD_POS.exposure_trading_book
     set BANK_BOOK_CRM_FLG = 
     case when INSTID in (select CRM_ID from RD_POS.exposure_crm_link) then 1 else 0 end;
     quit;

 /*- end of the optional block -*/
     %local CHECK_BANKING_BOOK_CRM;
     %let CHECK_BANKING_BOOK_CRM=%varexist(RD_POS.exposure_trading_book, BANK_BOOK_CRM_FLG);
     
 /*- 1. prepare data for each method -*/
     data RD_POS.exposure_trading_book (drop=NOTE INSTSOURCE EAD BANK_BOOK_CRM_FLG COMPUTED_FLG NOVATION_INSTID
                                        index=(ISSUE_KEY))
          RD_POS.exposure_trading_book_zero_ead (keep=INSTID INSTSOURCE NOTE EAD)
          RD_POS.exp_trading_book_ead_supplied (drop=BANK_BOOK_CRM_FLG NOVATION_INSTID COMPUTED_FLG
                                                     NOTE NETTINGSETID EAD INSTSOURCE)
          RD_POS.exp_trading_book_no_instid
          imm (keep=INSTID ISSUE_KEY NETTINGSETID index=(INSTID))
          std (keep=INSTID ISSUE_KEY NETTINGSETID index=(INSTID));
     merge RD_POS.exposure_trading_book (in=a)
           RD_POS.netting_set (in=b keep=NETTING_SET_RK COMPUTED_FLG NOVATION_INSTID);
     by NETTING_SET_RK;
 
     length NOTE $32. NETTINGSETID $20.;
     if a;
     
     if not missing(NOVATION_INSTID) then NETTINGSETID = NOVATION_INSTID;
     else if not missing(NETTING_SET_RK) then NETTINGSETID = compress("NET**"||put(NETTING_SET_RK, 20.));
     else NETTINGSETID = compress("NET__"||INSTID);
     
 /*- exposure to the eligible central counterparty is zero : ANNEX IV 6 -*/
     if ELIG_CCR_CENTRAL_CPTY_FLG = 1 then do;
        EAD = 0; 
        NOTE = "EXP TO ELIGIBLE CENTRAL CPTY";
        INSTSOURCE = "TradingBook";
        output RD_POS.exposure_trading_book_zero_ead;
     end;
 /*- check for banking book crms -*/
     %if &CHECK_BANKING_BOOK_CRM %then %do;
     else if BANK_BOOK_CRM_FLG = 1 then do;
          EAD = 0;
          NOTE = "BANKING BOOK CRM";
          INSTSOURCE = "TradingBook";
          output RD_POS.exposure_trading_book_zero_ead;
     end;
     %end;
 /*- other cases -*/
     else do;
          if COMPUTED_FLG = 1 then do; 
             INSTTYPE = "PRICED_TB_EXP";
             ORIG_NETTING_SET_RK = NETTING_SET_RK;
             output RD_POS.exp_trading_book_ead_supplied;
          end;
          else do;
             if b and missing(NETTINGSETID) then
                output RD_POS.exp_trading_book_no_instid;
             else do;
                output RD_POS.exposure_trading_book;
                if CCR_APPROACH = 'IMM' then 
                   output imm;
                else 
                   output std;
             end;
          end;
     end;
     run;
     
 /*- issue notes -*/
     %if %attrn(RD_POS.exp_trading_book_ead_supplied, NOBS) GT 0 %then %do;
         %put;
         %print_msg(note, 2, 319); 
         %put;
     %end;
     %if %attrn(RD_POS.exp_trading_book_no_instid, NOBS) GT 0 %then %do;
         %put;
         %print_msg(warning, 2, 320); 
         %put;
     %end;
     
 /*- get the financial collaterals for each method -*/     
     proc sort data=RD_POS.exposure_crm_link_trading_book;
     by EXP_ID;
     run;
     
     data fin_collateral_1 (keep=CRM_ID CCR_APPROACH NETTINGSETID rename=(CRM_ID=INSTID) index=(INSTID))
          fin_collateral_2 (keep=CRM_ID CCR_APPROACH NETTINGSETID rename=(CRM_ID=INSTID) index=(INSTID))
          RD_POS.fin_collateral_imm_std (keep=CRM_ID rename=(CRM_ID=INSTID))
          RD_POS.fin_col_trading_book_notused (keep=CRM_ID rename=(CRM_ID=INSTID));
     merge imm (in=imm rename=(INSTID=EXP_ID))
           std (in=std rename=(INSTID=EXP_ID))
           RD_POS.exposure_crm_link_trading_book;
     by EXP_ID;
     
     if imm and std then 
          output RD_POS.fin_collateral_imm_std; 
     else if imm then do;
          CCR_APPROACH = 'IMM';
          output fin_collateral_1;
     end;
     else if std then do;
          CCR_APPROACH = 'STD';
          output fin_collateral_2;
     end;
     else 
          output RD_POS.fin_col_trading_book_notused;
     run;
     
 /*- get counters -*/
     %let N_TB_IMM = %eval(%attrn(imm, NOBS));
     %let N_TB_STD = %eval(%attrn(std, NOBS));   
 /*- end of block 1 -*/
 
 /*- 2. process financial collaterals -*/
 /*- cannot support financial collateral used in both IMM and STD -*/
     %if %attrn(RD_POS.fin_collateral_imm_std, NOBS) GT 0 %then %do;
         proc sort data=RD_POS.fin_collateral_imm_std nodup;
         by INSTID;
         run;
         %put ;
         %print_msg(warning,2,308);
         %put;
     %end;
     
 /*- financial collaterals that are not used due to zero EAD of the exposure -*/
     %if %attrn(RD_POS.fin_col_trading_book_notused, NOBS) GT 0 %then %do;
         proc sort data=RD_POS.fin_col_trading_book_notused nodup;
   by INSTID;
         run;
         %put ;
         %print_msg(note,2,309);
         %put;
     %end;
     
 /*- create financial collateral data for each approach -*/
     proc append base=fin_collateral_1 data=fin_collateral_2 force; 
     run;
     
     proc sort data=fin_collateral_1 nodupkey out=RD_POS.fin_collateral_trading_book;
     by INSTID;
     run;
        
     %get_fin_collateral_trading_book(RD_POS.crm_instrument);
     /* %get_fin_collateral_trading_book(RD_POS.crm_account); no need */
     %get_fin_collateral_trading_book(RD_POS.crm_derivative);     
     
 /*- end of block 2 -*/
 
 /*- 3. Risk factors -*/
 /*- get all risk factors that have data -*/
     proc contents data=rd_mkt.mkt_current out=rfdata (keep=NAME rename=(NAME=RISK_FACTOR_ID)) noprint;
     run;
     
 /*- get all risk factors used by the trading books -*/
     proc sql;
     create table RD_POS.issue_risk_factor as
     select ISSUE_KEY, upcase(RISK_FACTOR_ID) as RISK_FACTOR_ID from RD_STAGE.issue_risk_factor
     where ISSUE_KEY in (select ISSUE_KEY from RD_POS.exposure_trading_book);
     
     delete from RD_POS.issue_risk_factor 
     where RISK_FACTOR_ID not in (select RISK_FACTOR_ID from rfdata);
     quit;
     
/*- beginning of imm or std block -*/      
     %if &N_TB_IMM GT 0 or &N_TB_STD GT 0 %then %do; 
     proc sort data=RD_POS.issue_risk_factor out=issue_with_rf nodupkey;
     by ISSUE_KEY;
     run;
     
/*- get all the exposures that do not have risk factor data -*/
     data RD_POS.exposure_trading_book (index=(ISSUE_KEY) drop=nstd nimm)
          RD_POS.exposure_tb_without_rf(drop=NETTINGSETID nstd nimm RISK_FACTOR_ID);
     merge RD_POS.exposure_trading_book (in=a) 
           issue_with_rf (in=b) end=lastobs;
     by ISSUE_KEY;
     retain nstd 0 nimm 0;
     
     if a;
     if not b then do;
          if CCR_APPROACH = "IMM" then nimm = nimm+1;
          else if CCR_APPROACH = "STD" then nstd = nstd+1;
          CCR_APPROACH="CEM";
          output RD_POS.exposure_tb_without_rf;
     end;
     else
          output RD_POS.exposure_trading_book;
          
     if lastobs then do;
        call symput("N_STD_NO_RF", nstd);
        call symput("N_IMM_NO_RF", nimm);
     end;
     run;
     
     %let N_EXP_NO_RF=%attrn(RD_POS.exposure_tb_without_rf, NOBS);
     %if &N_EXP_NO_RF GT 0 %then %do;
         proc append base=RD_POS.exposure_instrument data=RD_POS.exposure_tb_without_rf force;
         run;
         %if %symexist(N_STD_NO_RF) %then %do;
             %let N_TB_STD =%eval(&N_TB_STD - &N_STD_NO_RF);
         %end;
         %if %symexist(N_IMM_NO_RF) %then %do;
             %let N_TB_IMM =%eval(&N_TB_IMM - &N_IMM_NO_RF);
         %end;
         %put;
         %print_msg(warning, 2, 316);
         %print_msg(warning, 2, 317);
         %put;
     %end;
     %end;
 /*- end of imm or std block -*/     
 %end;
 /*- update N_TRADING_BOOK_EXP -*/
 %let N_TRADING_BOOK_EXP=%attrn(RD_POS.exposure_trading_book, NOBS);
  
 /*- margin agreement -*/
 %if &N_TRADING_BOOK_EXP GT 0 %then %do;     

 /*- get the risk factor hedging set for the STD method -*/
     proc sql;
     create table RD_POS.risk_factors_std as select distinct RISK_FACTOR_ID 
     from RD_POS.issue_risk_factor where ISSUE_KEY in (select ISSUE_KEY from std)
     order by RISK_FACTOR_ID;
     quit;
     
     data RD_POS.risk_factor_hedging_set;
     merge RD_STAGE.risk_factor (in=a keep=RISK_FACTOR_ID HEDGING_SET_RK)
           RD_POS.risk_factors_std (in=b);
     by RISK_FACTOR_ID;
     if a and b;
     run;
     
 /*- process risk factors -*/
     data RD_POS.risk_factor (index=(RISK_FACTOR_ID));
     set RD_STAGE.risk_factor (rename=(CURRENCY_CD=CURRENCY));
     MATURITY_UNIT = put(MATURITY_TIME_UOM_CD,$MAP_TIME_UNIT.);
     CURRENCY = upcase(CURRENCY);
     
     if MATURITY_LENGTH_OF_TIME_AMT = . then do;
         MATURITY_LENGTH = 0;
         MATURITY_UNIT   = 'YEAR';
     end;
     else if MATURITY_UNIT = '' then
         MATURITY_UNIT   = 'YEAR';
     
         select (MATURITY_UNIT);
         when ('DAY'  ) MATURITY = MATURITY_LENGTH_OF_TIME_AMT/365.25;
         when ('WEEK' ) MATURITY = MATURITY_LENGTH_OF_TIME_AMT/52    ;
         when ('MONTH') MATURITY = MATURITY_LENGTH_OF_TIME_AMT/12    ;
         when ('YEAR' ) MATURITY = MATURITY_LENGTH_OF_TIME_AMT       ;
         otherwise      MATURITY = MATURITY_LENGTH_OF_TIME_AMT       ;
     end;
     run;
     
 /*- get hedging sets to be used -*/
     proc sql;
     create table RD_POS.hedging_set as 
     select *, 0 as MAT_BAND_FLG from RD_STAGE.hedging_set
     where HEDGING_SET_RK in (select HEDGING_SET_RK from RD_POS.risk_factor_hedging_set)
     order by HEDGING_SET_RK;
     
 /*- flag hedging sets that need maturity bands -*/
     update RD_POS.hedging_set
     set MAT_BAND_FLG = 1
     where HEDGING_SET_TYPE_CD in 
     (select HEDGING_SET_TYPE_CD from RD_CONF.hedging_set_type_x_mat_band);
     quit;
     
 /*- check if user has provided risk positions -*/
     proc sql;
     create table RD_POS.risk_position as
     select a.*, b.HEDGING_SET_ID, b.HEDGING_SET_TYPE_CD, b.MAT_BAND_FLG 
     from RD_STAGE.risk_position as a
     left join RD_POS.hedging_set as b
     on a.HEDGING_SET_RK=b.HEDGING_SET_RK
     order by ISSUE_KEY;
     quit;
     
     proc sql;
     alter table RD_POS.exposure_trading_book
     add RISK_POSITION_FLG num;
     
     update RD_POS.exposure_trading_book
     set RISK_POSITION_FLG =
     case when ISSUE_KEY in (select ISSUE_KEY from RD_STAGE.risk_position) then 1 else 0 end;
     quit;
     
     %get_risk_positions(RD_POS.exposure_trading_book, 0);
     %get_risk_positions(RD_POS.crm_instrument_trading_book, 1);
     /* %get_risk_positions(RD_POS.crm_account_trading_book, 1); no need */
     %get_risk_positions(RD_POS.crm_derivative_trading_book, 1);
     
 /*- find the maximum residual maturity in the netting sets -*/
     proc sort data=RD_POS.exposure_trading_book (keep=NETTINGSETID RESIDUAL_MATURITY ORIGINAL_MATURITY)
               out=exp_maturity;
     by NETTINGSETID;
     run;
     
     proc means data=exp_maturity max noprint;
     by NETTINGSETID;
     var RESIDUAL_MATURITY ORIGINAL_MATURITY;
     output out=trading_book_max_maturity (drop=_TYPE_ _FREQ_) 
     max=MAX_RESIDUAL_MATURITY MAX_ORIGINAL_MATURITY;
     run;
     
     data RD_POS.netting_exposures;
     merge RD_POS.netting_exposures (in=a)
           trading_book_max_maturity(rename=(NETTINGSETID=INSTID));
     by INSTID;
     if a;
     run;
     
 /*- maximum original and residual maturity in the portfolio -*/    
     %if &N_TB_IMM GT 0 %then %do;
         proc sql noprint;
         select max(MAX_RESIDUAL_MATURITY), max(MAX_ORIGINAL_MATURITY) 
         into : MAX_RES_MATURITY, : MAX_ORG_MATURITY
         from trading_book_max_maturity;
         quit;
     %end;
      
 /*- end of all trading book block -*/
 %end; 
 %mend process_trading_book;
 
 %process_trading_book;
 %clean_lib;
%mend b36_process_trading_book;
