/* $Id: b45_prepare_regrpt_sec_det_crd4.sas,v 1.1.4.22.4.1 2015/05/07 16:54:31 keqyan Exp $ */
/*****************************************************************************
* Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b45_prepare_regrpt_sec_det_crd4.sas
*
* PURPOSE: Create portoflio data for SEC DETAILS regulatory report
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
%macro b45_prepare_regrpt_sec_det_crd4 ;

   %macro prepare_regrpt_port_sec_det (inputds1, inputds2) ;

   /*---------------------------------------------------------------------------
   * Step 1. Check to see if the user has requested the report 
   * -------------------------------------------------------------------------*/

   %let INPUTDS = all_exp_for_sec_details ;
   %let HAVEDATA=NO;

   %if  
      (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRSEC_DET_CRD4 OR  %UPCASE(&REGPROJECTNAME) EQ ALL )

      %then %do;
         %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL %then %do;
            libname _incrlib  "&REGPATH";
            %goto checkirba_opt;
         %end;
         %else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK %then %do;
            libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
            %goto checkirba_rnk;
         %end;
      %end;

   %else %goto SKIP;

   /*---------------------------------------------------------------------------
   * Step 2. Check to see if we have data
   * -------------------------------------------------------------------------*/

   %SKIP:
   %print_msg (NOTE,3,60);/*-------------------------->Add another message*/
   %return;

 
   %CHECKIRBA_OPT:
   data work.&INPUTDS;
      set _incrlib.&INPUTDS1 _incrlib.&INPUTDS2;
   run ;
   %checkdata (WORK, &INPUTDS , );


   %CHECKIRBA_RNK:
   data work.&INPUTDS;
      set _incrlib.&INPUTDS1 _incrlib.&INPUTDS2;
   run ;
   %checkdata (WORK, &INPUTDS , );
 
   /* If no data then return*/
   %if (&HAVEDATA = NO)  %then %do;
      %print_msg (WARNING,3,1);/*------------------------>Change this message*/
      %return;
   %end;

   /*---------------------------------------------------------------------------
   * Step 3a. Creating portfolio for SEC Details report
   * -------------------------------------------------------------------------*/

   /*- Need to sort the data set for the by statement -*/
   proc sort data = &INPUTDS out = exposure_sec;
      by SECURITIZATION_POOL_RK TRANCHE_LOSS_RANK; 
   run;

   data exposure_sec1;
      set exposure_sec;
      by SECURITIZATION_POOL_RK TRANCHE_LOSS_RANK; 
      /* keep only securitization exposures. */
      where (not missing(SECURITIZATION_POOL_RK)) and SECURITIZATION_EXPOSURE_FLG;
      /*- Col. 230 - 280 -*/
      if first.TRANCHE_LOSS_RANK then TRANCHE_FACE_VALUE_AMT_tmp = TRANCHE_FACE_VALUE_AMT;
      else call missing(TRANCHE_FACE_VALUE_AMT_tmp);
   run;

   /* populate non-missing values for the variables in pool_var_list */
   %let pool_var_list = SEC_STRUCTURE_TYPE SEC_ACCTING_TREATMENT PRIMARY_BANK_ROLE SEC_RPT_PORT_TYPE SEC_RPT_PORT_TYPE_CD
      SEC_RETENTION_TYPE SEC_RETENTION_COMPLIANCE_FLG SEC_STRUCTURE_SUBTYPE INSTITUTION_SHARE_PCT 
      POOL_FACE_VALUE_AMT EFFECTIVE_NUMBER_OF_EXPOSURES ORIGINATION_COUNTRY_CD WEIGHTED_AVG_LGD_PCT 
      TOTAL_PROVISION_AMT K_IRB FIRST_POSSIBLE_TERM_DT LONGEST_MATURITY_DATE ORIGINATOR_CPTY_CODE 
      ORIGINATOR_CPTY_NAME RESECURITIZATION_FLG UNDERLYING_APPROACH_TYPE INCEPTION_DATE SEC_RETENTION_PCT;

   %if &pool_var_list ne  %then %do;
       %let i = 1;
       %do %while (%scan(&pool_var_list,&i)  ne  );
           %let var&i = %scan(&pool_var_list,&i);
           %let tmpvar&i = &&var&i..1;
           %let i = %eval(&i+1);
       %end;
       %let _n_vars = %eval(&i-1);
   %end;

   /* pool information */
   data pool_info;
      set exposure_sec1;
      retain isin_tmp not_owned_tmp trading_tmp banking_tmp resec_tmp;
      retain %do i = 1 %to &_n_vars;
                &&tmpvar&i
             %end;
      ;
      by SECURITIZATION_POOL_RK;
      if missing(EXP_NOT_OWNED_FLG) then EXP_NOT_OWNED_FLG = 0;
      if missing(TRADING_BOOK_FLG) or TRADING_BOOK_FLG eq '.' then TRADING_BOOK_FLG = '0';
      if first.SECURITIZATION_POOL_RK then do;
         /*- Col. 20 -*/
         if upcase(scan(ISSUE_CODE, 2, ':')) eq 'ISIN' then isin_tmp = substr(scan(ISSUE_CODE, 1, ':'), 1, 8);
         else isin_tmp = '';
         /*- Col. 60 -*/
         not_owned_tmp = EXP_NOT_OWNED_FLG;
         call missing(trading_tmp); 
         call missing(banking_tmp);
         if EXP_NOT_OWNED_FLG ne 1 then do;
            trading_tmp = TRADING_BOOK_FLG;
            banking_tmp = 1 - TRADING_BOOK_FLG;
         end;
         /*- Col. 70 -*/
         resec_tmp = RESECURITIZATION_FLG; 
         /* populate non-missing values for the variables in pool_var_list */
         %do i = 1 %to &_n_vars;
            &&tmpvar&i = &&var&i;
         %end;
      end;
      else do;
         /*- Col. 20 -*/
         if upcase(scan(ISSUE_CODE, 2, ':')) eq 'ISIN' then isin_tmp = substr(scan(ISSUE_CODE, 1, ':'), 1, 8);
         /*- Col. 60 -*/
         not_owned_tmp = min(not_owned_tmp, EXP_NOT_OWNED_FLG);
         if EXP_NOT_OWNED_FLG ne 1 then do;
            trading_tmp = max(trading_tmp, TRADING_BOOK_FLG);
            banking_tmp = max(banking_tmp, 1 - TRADING_BOOK_FLG);
         end;
         /*- Col. 70 -*/
         resec_tmp = max(resec_tmp, RESECURITIZATION_FLG);
         /* populate non-missing values for the variables in pool_var_list */
         %do i = 1 %to &_n_vars;
            if not missing(&&var&i) then &&tmpvar&i = &&var&i;
         %end;
      end;
      /*- Col. 20 -*/
      if not missing (isin_tmp) then SECURITIZATION_ID = isin_tmp;
      else SECURITIZATION_ID = SECURITIZATION_POOL_ID;
      /*- Col. 60 -*/
      SOLVENCY_TREATMENT=''; 
      if not_owned_tmp = 1 then SOLVENCY_TREATMENT = 'N'; 
      else do;
         if (trading_tmp = 1 and banking_tmp = 0) then SOLVENCY_TREATMENT = 'T';
         else if (trading_tmp = 0 and banking_tmp = 1) then SOLVENCY_TREATMENT = 'B';
         else if (trading_tmp = 1 and banking_tmp = 1) then SOLVENCY_TREATMENT = 'A';
      end;
      /*- Col. 70 -*/
      if resec_tmp = 1 then SECURITIZATION_RESEC = 'R'; 
      else SECURITIZATION_RESEC = 'S'; 

      if last.SECURITIZATION_POOL_RK then do;
         /* populate non-missing values for the variables in pool_var_list */
         %do i = 1 %to &_n_vars;
            if not missing(&&tmpvar&i) then &&var&i = &&tmpvar&i;
         %end;
         output;
      end;
      keep SECURITIZATION_POOL_RK SECURITIZATION_ID SOLVENCY_TREATMENT SECURITIZATION_RESEC;
      keep &pool_var_list;
   run;

   data _intds.CAPITAL_CRSEC_DET_CRD4;
      merge exposure_sec1(drop=&pool_var_list)  pool_info;
      by SECURITIZATION_POOL_RK;
      length INSTTYPE $ 16 INSTID ORIGINATOR_ID INTERNAL_CODE $ 32;
      
      INSTTYPE = "REGRPT_SEC_DET"; 
      INSTID = compress('SEC_DET_'||_N_);

      /*- Col. 10 -*/
      INTERNAL_CODE = SECURITIZATION_POOL_RK;

      /*- Col. 20 -*/
      /* SECURITIZATION_ID has been taken care of in the step before. */

      /*- Col. 30 -*/
      if not missing(ORIGINATOR_CPTY_CODE) then ORIGINATOR_ID = ORIGINATOR_CPTY_CODE;
      else  ORIGINATOR_ID = ORIGINATOR_CPTY_NAME;

      /*- Col. 40 -*/
      if SEC_STRUCTURE_TYPE = 'TRADITIONAL' then SECURITIZATION_TYPE = 'T';
      else if SEC_STRUCTURE_TYPE = 'SYNTHETIC' then SECURITIZATION_TYPE = 'S'; 

      /*- Col. 50 -*/
      ACCOUNTING_TREATMENT = SEC_ACCTING_TREATMENT; 

      /*- Col. 60 -*/
      /* SOLVENCY_TREATMENT has been taken care of in the step before. */
      if PRIMARY_BANK_ROLE ne 'ORIGINATOR' or SEC_RPT_PORT_TYPE in ('COVERED_BONDS','OTHER_LIABILITIES') then SOLVENCY_TREATMENT = '';

      /*- Col. 70 -*/
      /* SECURITIZATION_RESEC has been taken care of in the step before. */

      /*- Col. 80 -*/
      RETENTION_TYPE = SEC_RETENTION_TYPE;

      /*- Col. 90 -*/
      call missing(RETENTION_PCT);
      if first.SECURITIZATION_POOL_RK then do;
         if RETENTION_TYPE not in ('E','N') then do; 
             RETENTION_PCT = SEC_RETENTION_PCT;
         end;
      end;

      /*- Col. 100 -*/
      if RETENTION_TYPE not in ('E','N') then do; 
         if SEC_RETENTION_COMPLIANCE_FLG = 1 then RETENTION_COMPLIANCE = 'Y'; 
         else RETENTION_COMPLIANCE = 'N';
      end;
      else call missing(RETENTION_COMPLIANCE); 

      /*- Col. 110 -*/
      if PRIMARY_BANK_ROLE = 'ORIGINATOR' then INSTITUTION_ROLE = 'O'; 
      else if PRIMARY_BANK_ROLE = 'SPONSOR' then INSTITUTION_ROLE = 'S'; 
      else if PRIMARY_BANK_ROLE = 'INVESTOR' then INSTITUTION_ROLE = 'I'; 
      else if PRIMARY_BANK_ROLE = 'ORIGINAL_LENDER' then INSTITUTION_ROLE = 'L'; 

      /*- Col. 120 -*/
      if SEC_STRUCTURE_SUBTYPE ne "ABCP" then NON_ABCP_ORIGINATION_DATE = INCEPTION_DATE;
      else call missing(NON_ABCP_ORIGINATION_DATE); 

      /*- Col. 130 -*/
      call missing(NON_ABCP_ORIGINATION_AMT);
      if first.SECURITIZATION_POOL_RK then do;
          if SEC_STRUCTURE_SUBTYPE ne "ABCP" then NON_ABCP_ORIGINATION_AMT = POOL_FACE_VALUE_INCEP_AMT;
      end;

      /*- Col. 140 -*/
      if missing(INSTITUTION_SHARE_PCT) then INSTITUTION_SHARE_PCT = 100; 
      call missing(TOTAL_AMOUNT);
      if first.SECURITIZATION_POOL_RK then do;
         TOTAL_AMOUNT =  INSTITUTION_SHARE_PCT /100 * POOL_FACE_VALUE_AMT;
      end;

      /*- Col. 150 -*/
      call missing(INSTITUTION_SHARE);
      if first.SECURITIZATION_POOL_RK then do;
         INSTITUTION_SHARE = INSTITUTION_SHARE_PCT; 
      end;

      /*- Col. 160 -*/
      ASSET_LIABILITY_TYPE = SEC_RPT_PORT_TYPE_CD; 

      /*- Col. 170 -*/
      if (SEC_RPT_PORT_TYPE not in ('COVERED_BONDS','OTHER_LIABILITIES')) and (PRIMARY_BANK_ROLE ne 'SPONSOR') then 
         APPROACH_APPLIED = UNDERLYING_APPROACH_TYPE;
      else call missing(APPROACH_APPLIED); 

      /*- Col. 180 -*/
      call missing(NUMBER_OF_EXPOSURES);
      if first.SECURITIZATION_POOL_RK then do;
         if (SEC_RPT_PORT_TYPE not in ('COVERED_BONDS','OTHER_LIABILITIES')) and (PRIMARY_BANK_ROLE ne 'INVESTOR') and (SOLVENCY_TREATMENT ne 'N') then 
            NUMBER_OF_EXPOSURES = EFFECTIVE_NUMBER_OF_EXPOSURES; 
      end;

      /*- Col. 190 -*/
      COUNTRY = ORIGINATION_COUNTRY_CD; 

      /*- Col. 200 -*/
      call missing(ELGD);
      if first.SECURITIZATION_POOL_RK then do;
         if (APPROACH_APPLIED = "I") and (SEC_RPT_PORT_TYPE not in ('COVERED_BONDS','OTHER_LIABILITIES')) 
            and (PRIMARY_BANK_ROLE ne 'SPONSOR') and (SOLVENCY_TREATMENT ne 'N') then 
                  ELGD = WEIGHTED_AVG_LGD_PCT; 
      end;

      /*- Col. 210 -*/
      call missing(VALUE_ADJUST_PROVISIONS);
      if first.SECURITIZATION_POOL_RK then do;
         if SEC_RPT_PORT_TYPE not in ('COVERED_BONDS','OTHER_LIABILITIES') and PRIMARY_BANK_ROLE ne 'SPONSOR' then do;
            VALUE_ADJUST_PROVISIONS = TOTAL_PROVISION_AMT;
         end; 
      end; 

      /*- Col. 220 -*/
      call missing(OWN_FUND_REQ_PRE_SECURITIZATION);
      if first.SECURITIZATION_POOL_RK then do;
         if SEC_RPT_PORT_TYPE not in ('COVERED_BONDS','OTHER_LIABILITIES') and PRIMARY_BANK_ROLE ne 'SPONSOR' then do;
            OWN_FUND_REQ_PRE_SECURITIZATION = K_IRB; 
         end; 
      end; 

      /*- Cols. 230, 240, 250 -*/
      call missing(ON_BS_SENIOR_TRANCHE_VALUE); 
      call missing(ON_BS_MEZZ_TRANCHE_VALUE); 
      call missing(ON_BS_FIRST_LOST_TRANCHE_VALUE); 
      if missing(OFF_BALANCE_SHEET_TYPE_CD) and STD_PRODUCT_SUBCLASS = 'TRANCHE' then do; 
         if SENIORITY_CD = 'SEN' then ON_BS_SENIOR_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT_tmp; 
         else if SENIORITY_CD = 'MEZ' then ON_BS_MEZZ_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT_tmp;
         else if TRANCHE_LOSS_RANK = 1 then ON_BS_FIRST_LOST_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT_tmp; 
      end;
         
      /*- Cols. 260, 270, 280 -*/
      call missing(OFF_BS_SENIOR_TRANCHE_VALUE); 
      call missing(OFF_BS_MEZZ_TRANCHE_VALUE); 
      call missing(OFF_BS_FIRST_LOST_TRANCHE_VALUE); 
      if not missing(OFF_BALANCE_SHEET_TYPE_CD) and STD_PRODUCT_SUBCLASS = 'TRANCHE' then do; 
         if SENIORITY_CD = 'SEN' then OFF_BS_SENIOR_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT_tmp; 
         else if SENIORITY_CD = 'MEZ' then OFF_BS_MEZZ_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT_tmp;
         else if TRANCHE_LOSS_RANK = 1 then OFF_BS_FIRST_LOST_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT_tmp; 
      end;

      /*- Col. 290 -*/
      FIRST_TERMINATION_DATE = FIRST_POSSIBLE_TERM_DT;

      /*- Col. 300 -*/
      LEGAL_FINAL_DATE = LONGEST_MATURITY_DATE; 

      /*- Cols. 310, 320, 330 -*/
      call missing(ON_BS_SENIOR_EXP_VALUE); 
      call missing(ON_BS_MEZZ_EXP_VALUE); 
      call missing(ON_BS_FIRST_LOST_EXP_VALUE); 
      if missing(OFF_BALANCE_SHEET_TYPE_CD) and EXP_NOT_OWNED_FLG ne 1 and STD_PRODUCT_SUBCLASS = 'TRANCHE' then do; 
            if SENIORITY_CD = 'SEN' then ON_BS_SENIOR_EXP_VALUE = EXP_VALUE; 
            else if SENIORITY_CD = 'MEZ' then ON_BS_MEZZ_EXP_VALUE = EXP_VALUE;
            else if TRANCHE_LOSS_RANK = 1 then ON_BS_FIRST_LOST_EXP_VALUE = EXP_VALUE; 
      end;
         
      /*- Cols. 340, 350, 360 -*/
      call missing(OFF_BS_SENIOR_EXP_VALUE); 
      call missing(OFF_BS_MEZZ_EXP_VALUE); 
      call missing(OFF_BS_FIRST_LOST_EXP_VALUE); 
      if EXP_NOT_OWNED_FLG ne 1 then do;
         if not missing(OFF_BALANCE_SHEET_TYPE_CD) and STD_PRODUCT_SUBCLASS = 'TRANCHE' then do; 
             if SENIORITY_CD = 'SEN' then OFF_BS_SENIOR_EXP_VALUE = EXP_VALUE; 
             else if SENIORITY_CD = 'MEZ' then OFF_BS_MEZZ_EXP_VALUE = EXP_VALUE;
             else if TRANCHE_LOSS_RANK = 1 then OFF_BS_FIRST_LOST_EXP_VALUE = EXP_VALUE; 
         end;
         else if STD_PRODUCT_CLASS = 'DERIVATIVE' then OFF_BS_SENIOR_EXP_VALUE = EXP_VALUE; 
      end;

      /*- Cols. 370, 380, 390, 400 -*/
      call missing(DCS_MEMO); 
      call missing(IRS_CRS_MEMO); 
      call missing(FAC_MEMO); 
      call missing(OTHER_MEMO); 
      if EXP_NOT_OWNED_FLG ne 1 then do;
         if put(OFF_BALANCE_SHEET_TYPE_CD,$MAP_OBSI_SEC_DETAIL_REGRPT.) in ('DCS') then
            DCS_MEMO = EXP_VALUE; 
         else if put(OFF_BALANCE_SHEET_TYPE_CD,$MAP_OBSI_SEC_DETAIL_REGRPT.) in ('IRS','CRS') then
            IRS_CRS_MEMO = EXP_VALUE; 
         else if put(OFF_BALANCE_SHEET_TYPE_CD,$MAP_OBSI_SEC_DETAIL_REGRPT.) in ('FAC') then
            FAC_MEMO = EXP_VALUE; 
         else if not missing(OFF_BALANCE_SHEET_TYPE_CD) or STD_PRODUCT_CLASS = 'DERIVATIVE' then OTHER_MEMO = EXP_VALUE;   
      end;

      /*- Col. 410 -*/
      if not missing(EARLY_AMORTIZATION_TYPE) then CCF_APPLIED = CCF; 

      /*- Col. 420 -*/
      OWN_FUNDS_DEDUCTION = - SEC_DEDUCTION_AMT; 

      /*- Col. 430 -*/
      if EXP_NOT_OWNED_FLG ne 1 and SEC_RPT_PORT_TYPE not in ('COVERED_BONDS','OTHER_LIABILITIES') then do;
         PRE_CAP_EXPOSURE = RWA_BEFORE_CAP;
      end;

      /*- Col. 440 -*/
      if EXP_NOT_OWNED_FLG ne 1 and SEC_RPT_PORT_TYPE not in ('COVERED_BONDS','OTHER_LIABILITIES') then do;
         POST_CAP_EXPOSURE = RWA; 
      end;

      /*- Col. 450 - 480 -*/
      CTP_NON_CTP = '';
      call missing(LONG_POSITION_NET); 
      call missing(SHORT_POSITION_NET); 
      call missing(SPECIFIC_RISK); 

      /* keep only securitization exposures that the bank owns, or originated / sponsored  */
      /* during the year of report, in case it holds no position.*/
      if (year(INCEPTION_DATE) = year(&rundate) or (SOLVENCY_TREATMENT ne 'N')) then output;

      keep INSTID INSTTYPE INTERNAL_CODE SECURITIZATION_ID ORIGINATOR_ID SECURITIZATION_TYPE ACCOUNTING_TREATMENT SOLVENCY_TREATMENT 
      SECURITIZATION_RESEC RETENTION_TYPE RETENTION_PCT RETENTION_COMPLIANCE INSTITUTION_ROLE NON_ABCP_ORIGINATION_DATE 
      NON_ABCP_ORIGINATION_AMT TOTAL_AMOUNT INSTITUTION_SHARE ASSET_LIABILITY_TYPE APPROACH_APPLIED NUMBER_OF_EXPOSURES
      COUNTRY ELGD VALUE_ADJUST_PROVISIONS OWN_FUND_REQ_PRE_SECURITIZATION ON_BS_SENIOR_TRANCHE_VALUE 
      ON_BS_MEZZ_TRANCHE_VALUE ON_BS_FIRST_LOST_TRANCHE_VALUE OFF_BS_SENIOR_TRANCHE_VALUE OFF_BS_MEZZ_TRANCHE_VALUE 
      OFF_BS_FIRST_LOST_TRANCHE_VALUE ON_BS_SENIOR_EXP_VALUE ON_BS_MEZZ_EXP_VALUE ON_BS_FIRST_LOST_EXP_VALUE 
      OFF_BS_SENIOR_EXP_VALUE OFF_BS_MEZZ_EXP_VALUE OFF_BS_FIRST_LOST_EXP_VALUE DCS_MEMO IRS_CRS_MEMO FAC_MEMO
      OTHER_MEMO CCF_APPLIED OWN_FUNDS_DEDUCTION PRE_CAP_EXPOSURE POST_CAP_EXPOSURE CTP_NON_CTP LONG_POSITION_NET
      SHORT_POSITION_NET SPECIFIC_RISK FIRST_TERMINATION_DATE LEGAL_FINAL_DATE; 

   run;

    data _intds.SEC_DETAIL_DATE_INFO;
      set _intds.CAPITAL_CRSEC_DET_CRD4;
      keep INTERNAL_CODE  NON_ABCP_ORIGINATION_DATE FIRST_TERMINATION_DATE LEGAL_FINAL_DATE; 
    run;
    

   /*---------------------------------------------------------------------------
   * Step 4. Check to see if data was created
   * -------------------------------------------------------------------------*/

   %checkdata (_intds,CAPITAL_CRSEC_DET_CRD4, );

   %if &HAVEDATA = YES %then %do;
      %status(CAPITAL_CRSEC_DET_CRD4,SUCCESS,SEC Details,CAPITAL_CRSEC_DET_CRD4);
   %end;
   %else %do;
      %print_msg (WARNING,3,62);
      %status(CAPITAL_CRSEC_DET_CRD4,Problems creating input data for portfolio,CAPITAL_CRSEC_DET_CRD4);
   %end;

   %mend prepare_regrpt_port_sec_det ;

   %prepare_regrpt_port_sec_det (crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail, exp_not_owned_&MITIGANTS_ALLOCATION_METHOD._detail);
   options notes source;

%mend b45_prepare_regrpt_sec_det_crd4 ;
