/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: Batch_CRiskM_20_Process_Data.sas
 *
 * PURPOSE: CRiskM batch run: process market and position data.
 *
 *   USAGE: 
 *
 *   NOTES: The numbers in filenames indicates run sequence groups.  In general, 
 *          programs within the same group can run in any order.  
 *          
 *
 *****************************************************************************/

 %macro batch_criskm_20_process_data;

/****************************************************************************
 *        Redefine calculation, output and crm allocation options
 ****************************************************************************/

/*Define frm_a00_init global macro variable to identify the call of a00_init_options macro from a00_init macro*/
%global frm_a00_init;
%let frm_a00_init=0;
%a00_init_options ;

%b00_process_data_initial;
/*****************************************************************************
 *                      Parameter Matrix Data Sets
 *****************************************************************************/

/*- create a ccf parameter matrix for each set -*/
%b05_process_ccf_sets ;

/*- create a haircut parameter matrix for each set -*/
%b05_process_haircut_sets ;


/*****************************************************************************
 *                              Market Data
 *****************************************************************************/

/*- market data for interest rates -*/
%b10_process_market_ir ;

/*- market data for foreign exchange rates -*/
%b10_process_market_fx ;

/*- market data for equity prices -*/
%b10_process_market_equities ;

/*- market data for investment funds under USFINAL configuration -*/
/*%b10_process_mkt_fund_usfinal;*/ 

/*- market data for PD/LGD -*/
%b10_process_market_pd_lgd ;

/*- market data for collateralization levels -*/
%b10_process_mkt_colateralan_lvl;

/*- market data for RW -*/
%b10_process_market_rw ;

/*- concatenate all market data horizontally -*/
%b10_process_market_vector ;


/*****************************************************************************
 *         Provision Data Sets and Preparation for Position Data
 *****************************************************************************/

%b15_process_exposure_provisions ;

%b15_process_general_provisions ;

%b15_process_counterparty ;

%b15_process_positions_initial ;


/*****************************************************************************
 *                       Position Data Sets
 *****************************************************************************/


%b20_process_exposures_accounts ;

%b20_process_exp_instruments ;

%b20_process_exposures_facilities ;

%b20_process_exposures_rec ;

%b20_process_exposures_sec ;

/*%b20_process_exposures_segments ;*/ 

%b20_process_netting_sets ;

%b20_process_crms_accounts ;

/*%b20_process_crms_segments ;*/ 

%b20_process_crms_instruments ;

%b20_process_crms_guarantee ;

%b20_process_crms_derivatives ;

%b20_process_crms_insurance ;

%b20_process_crms_rec ;

%b20_process_crms_physical ;

%b25_process_exp_sec_underlying ;

%b30_process_exposure_crm_links ;

%b35_process_facility_exp_links ;

%b36_process_trading_book ;

%b37_process_simulation_data ;



%b40_process_positions_end ;

/*- subsequent batch runs need to know which previous batches have been run -*/
%global RUN_STAGE;
%let RUN_STAGE = 20;

/*****************************************************************************
 *  Save Macro Definitions so this step doesnot have to be run multiple times.
 *****************************************************************************/

%u00_save_macro_definitions;
%mend batch_criskm_20_process_data;
