/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: create_counterparty_rating.sas
 *
 * PURPOSE: Stores code that transposes counterparty ratings from multi-rows per
 *          counterparty into single-row per counterparty
 *
 *   USAGE: %create_counterparty_rating;
 *          
 *
 *   NOTES: 1. RD_STAGE.counterparty_ratings table needs to be pre-sorted on
 *             COUNTERPARTY_RK .
 *
 *
 *****************************************************************************/

%macro create_counterparty_rating;

/*- get eligible external agency -*/
/*- check for null eligible external rating agencies -*/

   %if &NUM_AGENCIES_CPTY=0 or &NUM_ELIGIBLE_AGENCY=0 %then %do;
       data RD_POS.counterparty_ratings;
       length COUNTERPARTY_RK 8.;
	   stop;
       run;

	   proc transpose data   = RD_STAGE.counterparty_ratings (where=(RATING_AGENCY = 'INT'))
                      out    = RD_POS.counterparty_int_ratings (drop=_NAME_)
       suffix=_RATING;
       by  COUNTERPARTY_RK;
       id  RATING_AGENCY;
       var RATING;
       run;

	   data rd_pos.counterparty_int_ratings;
	   	set rd_pos.counterparty_int_ratings;
		where counterparty_rk ne .;
	   run;
   %end;
   %else %do;
       %let AGENCY_FILTER=RATING_AGENCY in (%quote_list(list=&ELIGIBLE_AGENCY, case=));

       proc transpose data   = RD_STAGE.counterparty_ratings (where=(RATING_AGENCY NE 'INT' and &AGENCY_FILTER))
                      out    = RD_POS.counterparty_ratings (drop=_NAME_)
                      prefix = EXT_RATING_ ;
       by  COUNTERPARTY_RK;
       id  RATING_AGENCY;
       var RATING;
       run;
   
       data RD_POS.counterparty_int_ratings(drop=RATING_AGENCY rename=(RATING=INT_RATING));
       set RD_STAGE.counterparty_ratings;
	   stop;
       run;
   %end;
%mend create_counterparty_rating;
