/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_addon_info.sas
 *
 * PURPOSE: Get add-on information: type and maturity band.
 *
 *   USAGE: %get_addon_info(RESET_EXIST=0);
 *          RESET_EXIST: whether NEXT_CONTRACT_RESET_DATE exists in data
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro get_addon_info(RESET_EXIST=0);

   /*- determine add-on type -*/
    ADDON_TYPE  = put(OFF_BALANCE_SHEET_TYPE_CD, $MAP_ADDON_TYPE.);
    if ADDON_TYPE  NE '' then PE_APPROACH = 'CE';   
    else PE_APPROACH = '';

    /*- For contracts structured to settle outstanding exposure following specified   -*/
    /*- payment dates and where terms are reset such that MtM is 0, residual maturity -*/
    /*- is set to the time until the next reset time.                                 -*/
    %if &RESET_EXIST = 0 %then %do; 
        NEXT_CONTRACT_RESET_DATE = .;
    %end;

    if "&PE_APPROACH_IR_FX_GOLD" = "OE" and ADDON_TYPE in ('IR', 'FX', 'GOLD') then do ;
       PE_APPROACH = 'OE';
       if ADDON_TYPE ='IR' and NETTING_SET_RK ne . then ADDON_TYPE ='IR_NET' ;
       else if ADDON_TYPE ='FX' and NETTING_SET_RK ne . then ADDON_TYPE ='FX_NET' ;
    end ;
      
    /*- Current Exposure Method -*/
    if PE_APPROACH = 'CE' then do;
        
        if NEXT_CONTRACT_RESET_DATE NE . then        
            ADDON_MAT_BAND = put(round(yrdif(&RUNDATE, NEXT_CONTRACT_RESET_DATE, "&DAY_BASIS"),&MATURITY_ROUNDOFF.), MAP_ADDON_MAT_BAND_CE.);
        else
            ADDON_MAT_BAND = put(RESIDUAL_MATURITY, MAP_ADDON_MAT_BAND_CE.);

    end;
    
    /*- Potential Exposure Method -*/    
    else if PE_APPROACH = 'OE' then do;

        /*- For IR contracts, add-on may be based on residual maturity -*/
        if ADDON_TYPE = 'IR' and "&MATURITY_SPEC_IR_ADDON_OE" = "RESIDUAL" then do;
            ADDON_MAT_BAND = put(RESIDUAL_MATURITY, MAP_ADDON_MAT_BAND_OE.);
        end;
        else
            ADDON_MAT_BAND = put(ORIGINAL_MATURITY, MAP_ADDON_MAT_BAND_OE.);

    end;    

%mend get_addon_info;
