/*****************************************************************************
 * Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_valid_large_exposures_crd4
 *
 * PURPOSE: Get all counterparties that qualify as Large Exposures
 *
 *   USAGE: 
 *
 *   NOTES: 1. This runs data for LE reports 
*  MODIFIED V4.8
 *****************************************************************************/

%macro get_valid_large_exposures_crd4(get_largest_IRB = TRUE);

/*to calculate all largest exposures i.e. those exposures that have value that is > 10% of ead*/
PROC SQL ;
CREATE table all_largest_group as 
SELECT distinct LE_COUNTERPARTY_RK,counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as sum_ead_portion
FROM CAPITAL_LE_group
GROUP BY counterparty_group
having sum_ead_portion gt &VALID_LE_EXP
ORDER BY SUM_EAD_PORTION DESC
;
quit;

PROC SQL ;
CREATE table all_largest_ind as 
SELECT distinct LE_COUNTERPARTY_RK,counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as sum_ead_portion
FROM CAPITAL_LE_ind
GROUP BY le_counterparty_rk
having sum_ead_portion gt &VALID_LE_EXP
ORDER BY SUM_EAD_PORTION DESC
;
quit;

data all_largest;
   set all_largest_group all_largest_ind;
run;

proc sql noprint;
   create table le_counterparty_rk_list as
   select le_counterparty_rk 
   from all_largest
   ;
quit;

proc sort data = WORK.LE_COUNTERPARTY_RK_LIST nodupkey; 
   by LE_COUNTERPARTY_RK; 
run;

%if %upcase(&get_largest_IRB) eq %upcase(TRUE) %then %do;
/*to calculate 20 largest exposures under IRB approach*/
   PROC SQL noprint;
   create table twenty_largest_irb_group as 
   SELECT
   distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
   ,sum(VALUE_ADJ_AMT) as sum_value_adj 
   ,sum(LE_EXEMPTED_AM) as sum_le_exempt
   from capital_le_group
   where approach IN ("IRB","IRBF","IRBA")
   GROUP BY counterparty_group;
   quit;

   PROC SQL noprint;
   create table twenty_largest_irb_ind as 
   SELECT
   distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
   ,sum(VALUE_ADJ_AMT) as sum_value_adj 
   ,sum(LE_EXEMPTED_AM) as sum_le_exempt
   from capital_le_ind
   where approach IN ("IRB","IRBF","IRBA")
   GROUP BY le_counterparty_rk;
   quit;

   data twenty_largest_irb;
   set twenty_largest_irb_group twenty_largest_irb_ind;
   run;

   data twenty_largest_irb;
   set twenty_largest_irb;
   large_exp_twenty=SUM(SUM_EAD_PORTION,-sum_value_adj,-sum_le_exempt);
   run;

   proc sort data = twenty_largest_irb;
   by large_exp_twenty;
   run; 

   proc rank data = twenty_largest_irb  out=twenty_largest_irb ties=dense descending ;
   var large_exp_twenty;
   ranks rank;
   run;
   %if %attrn(twenty_largest_irb, NOBS) NE 0 %then %do;
   proc sql noprint;
   select le_counterparty_rk into :le_cpty_irb separated by ',' from twenty_largest_irb
   where rank between 1 and 20;
   quit;
   %end;
   %else %do;
     %let le_cpty_irb=0;
   %end;
%end;

/*to calculate 10 largest for financial and unregulated entities*/
/*SUM(SUM_EAD_PORTION,-VALUE_ADJ_AMT)*/

PROC SQL noprint;
create table ten_largest_fi_group as 
SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
,sum(VALUE_ADJ_AMT) as sum_value_adj
from capital_le_group
where financial_entity_type_cd="I"
GROUP BY counterparty_group;
quit;


PROC SQL noprint;
create table ten_largest_fi_ind as 
SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
,sum(VALUE_ADJ_AMT) as sum_value_adj
from capital_le_ind
where financial_entity_type_cd="I"
GROUP BY le_counterparty_rk;
quit;
data ten_largest_fi;
set ten_largest_fi_group ten_largest_fi_ind;
run;

data ten_largest_fi;
set ten_largest_fi;
large_exp_ten_fi=SUM(SUM_EAD_PORTION,-sum_value_adj);
run;

proc sort data = ten_largest_fi;
by large_exp_ten_fi;
run; 

proc rank data = ten_largest_fi  out=ten_largest_fi ties=dense descending ;
var large_exp_ten_fi;
ranks rank;
run;
%if %attrn(ten_largest_fi, NOBS) NE 0 %then %do;
proc sql noprint;
select le_counterparty_rk into :le_cpty_i separated by ',' from ten_largest_fi
where rank between 1 and 10;
quit;
%end;
%else %do;
  %let le_cpty_i=0;
%end;

PROC SQL noprint ;
CREATE table  ten_largest_ure_group as 
SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
,sum(VALUE_ADJ_AMT) as sum_value_adj
FROM capital_le_group 
where financial_entity_type_cd="U"
GROUP BY counterparty_group
;
quit;

PROC SQL noprint ;
CREATE table  ten_largest_ure_ind as 
SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
,sum(VALUE_ADJ_AMT) as sum_value_adj
FROM capital_le_ind
where financial_entity_type_cd="U"
GROUP BY le_counterparty_rk
;
quit;

data ten_largest_ure;
set ten_largest_ure_group ten_largest_ure_ind;
run;
data ten_largest_ure;
set ten_largest_ure;
large_exp_ten_ure=SUM(SUM_EAD_PORTION,-sum_value_adj);
run;
proc sort data = ten_largest_ure;
by large_exp_ten_ure;
run; 

proc rank data = ten_largest_ure  out=ten_largest_ure ties=dense descending ;
var large_exp_ten_ure;
ranks rank;
run;
%if %attrn(ten_largest_ure, NOBS) NE 0 %then %do;
proc sql nowarn noprint;
select le_counterparty_rk into :le_cpty_u  separated by ',' from 
ten_largest_ure
where rank between 1 and 10;
;
quit;
%end;
%else %do;
  %let le_cpty_u=0;
%end;
%mend get_valid_large_exposures_crd4;
