/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_retail_irb_usfinal.sas
 *
 * PURPOSE: Method program code for retail exposures under IRB approach.
 *          
 *
 *   USAGE: %pm_exp_retail_irb_usfinal;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_exp_retail_irb_usfinal;

/*- initialize outvars -*/
    %initialize_reg_outvars_usfinal;
    %if &RETAIL_EXP_IND_LOAD_USFINAL = YES %then %do;    
    	%get_pd_issue;
    %end;
    /* Apply LGD Floor for RM exposures */    
    %get_lgd_irba;
    if OUTV_LGD NE . and IRB_PRODUCT_CLASS = 'RESIDENTIAL_MORTGAGE' then do;
		OUTV_LGD = max(OUTV_LGD,IRB_LGD_RETAIL_RME_FLOOR);
		end;
    
/*- RWA for Defaulted exposures is dollar-risk based capital requirement(=0.08 multiplied by EAD)
	multiplied by 12.5 and scaling factor (pg. no. 69336). We need to give 0.08 as percent. So put 8 in formula. -*/      
    if OUTV_PD_ISSUE = 100 then do;
    	  %get_el_irb ;
          OUTV_RW_ISSUE = 8 / &CAPITAL_RATIO * IRB_SCALING_FACTOR;
    end;
    else do;
        OUTV_EL      = OUTV_PD_ISSUE * OUTV_LGD / 100;    
        if IRB_PRODUCT_CLASS = 'RESIDENTIAL_MORTGAGE' then 
            OUTV_RW_ISSUE = IRB_RW_RETAIL_RME_USFINAL(OUTV_PD_ISSUE, OUTV_LGD, IRB_SCALING_FACTOR);
        else if IRB_PRODUCT_CLASS = 'QUALIFYING_REVOLVING' then 
            OUTV_RW_ISSUE = IRB_RW_RETAIL_QRRE_USFINAL(OUTV_PD_ISSUE, OUTV_LGD, IRB_SCALING_FACTOR);            
        else 
            OUTV_RW_ISSUE = IRB_RW_RETAIL_ORE_USFINAL(OUTV_PD_ISSUE, OUTV_LGD, IRB_SCALING_FACTOR);        
    end;
    
    
/* Starting Segemnet level calculations */     
/*- Get PD at Segment level -*/    
  if SEG_PD_PCT NE . then do;
  	if IN_DEFAULT_FLG = 1 then OUTV_PD_SEG = 100 ;
        else OUTV_PD_SEG = SEG_PD_PCT ;
end;
	
/*- Get LGD at Segment level -*/        
        if SEG_LGD_PCT NE . then do;
        OUTV_LGD_SEG = SEG_LGD_PCT;
/* Apply LGD Floor for RM segments */ 
		 if IRB_PRODUCT_CLASS = 'RESIDENTIAL_MORTGAGE' then
		OUTV_LGD_SEG = max(OUTV_LGD_SEG,IRB_LGD_RETAIL_RME_FLOOR);
		end;
        else OUTV_LGD_SEG = .;
        
/*- Get RW at Segment Level -*/
/*defaulted exposures  */
    if OUTV_PD_SEG = 100 then do;
    	  if SEG_EL_PCT NE . then
        OUTV_EL_SEG = SEG_EL_PCT;
        else OUTV_EL_SEG = .;
             OUTV_RW_SEG = 8 / &CAPITAL_RATIO * IRB_SCALING_FACTOR;
    end;
    /*Non-defaulted exposures */ 
    else do;
        OUTV_EL_SEG = OUTV_PD_SEG * OUTV_LGD_SEG / 100;    
        if IRB_PRODUCT_CLASS = 'RESIDENTIAL_MORTGAGE' then 
            OUTV_RW_SEG = IRB_RW_RETAIL_RME_USFINAL(OUTV_PD_SEG, OUTV_LGD_SEG, IRB_SCALING_FACTOR);
        else if IRB_PRODUCT_CLASS = 'QUALIFYING_REVOLVING' then 
            OUTV_RW_SEG = IRB_RW_RETAIL_QRRE_USFINAL(OUTV_PD_SEG, OUTV_LGD_SEG, IRB_SCALING_FACTOR);            
        else 
            OUTV_RW_SEG = IRB_RW_RETAIL_ORE_USFINAL(OUTV_PD_SEG, OUTV_LGD_SEG, IRB_SCALING_FACTOR);        
    end;

/*RW of Non-Material exposures is 100% (See Para (4) Page 69412)*/
	If NON_MAT_EXP_FLG = 1 and approach = "US_IRB" then do;
		%if &RETAIL_EXP_IND_LOAD_USFINAL = YES %then %do;
			OUTV_RW_ISSUE = 100;
		%end;
		if SEGMENT_ID NOT IN ("","_#_") then OUTV_RW_SEG = 100;
	end;

    OUTV_FIRM_SIZE = COUNTERPARTY_SIZE; /*need to be removed later */ 
    OUTV_BALANCE_AMT_SEG = BALANCE_AMT_SEG ;  
    
    _VALUE_ = EXP_VALUE ;
    
%mend pm_exp_retail_irb_usfinal;
