/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_securitization_irb.sas
 *
 * PURPOSE: Method program code for securitization exposures under RBA/IAA approach.
 *          
 *
 *   USAGE: %pm_exp_securitization_irb;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_exp_securitization_irb;

/*- initialize outvars -*/
    %initialize_regulatory_outvars;

/*- for mitigation purpose and for user inputs for SFA -*/
    %get_lgd_irba;    

/*- Basel II - 557: no capital requirement for transactions with eligible clean-up call -*/
    if ELIGIBLE_CLEAN_UP_CALL_FLG =1 then OUTV_RW_ISSUE = 0;
        
/*- get RW based on issue rating -*/
    else if IRB_RW_BUCKET = '_#_' then do;
    
    end;
    
    else if SHORT_TERM_ASSESS_FLG = 1 then do;
        if RESECURITIZATION_FLG = 1 then do;     
          if TRANCHE_SENIORITY_RANK = 1 and UNDERLYING_RESEC_EXPOSURES_FLG = 0 then 
            OUTV_RW_ISSUE = IRB_RW_RESEC_SHORT_SENIOR_REF.IRB_RW_BUCKET;
          else 
            OUTV_RW_ISSUE = IRB_RW_RESEC_SHORT_BASE_REF.IRB_RW_BUCKET;	
        end;        
        else if EFFECTIVE_NUMBER_OF_EXPOSURES < &IRB_SEC_GRANULARITY_THRESHOLD then
            OUTV_RW_ISSUE = IRB_RW_SEC_SHORT_NG_REF.IRB_RW_BUCKET;
        
        else if TRANCHE_SENIORITY_RANK = 1 then
            OUTV_RW_ISSUE = IRB_RW_SEC_SHORT_SENIOR_REF.IRB_RW_BUCKET;
        else 
            OUTV_RW_ISSUE = IRB_RW_SEC_SHORT_BASE_REF.IRB_RW_BUCKET;        
        
    end;

    else do;

        if RESECURITIZATION_FLG = 1 then do; 
          if TRANCHE_SENIORITY_RANK = 1 and UNDERLYING_RESEC_EXPOSURES_FLG = 0 then
            OUTV_RW_ISSUE = IRB_RW_RESEC_SENIOR_REF.IRB_RW_BUCKET;    
          else 
            OUTV_RW_ISSUE = IRB_RW_RESEC_BASE_REF.IRB_RW_BUCKET;
        end;        
        else if EFFECTIVE_NUMBER_OF_EXPOSURES < &IRB_SEC_GRANULARITY_THRESHOLD then
            OUTV_RW_ISSUE = IRB_RW_SEC_NG_REF.IRB_RW_BUCKET;
        
        else if TRANCHE_SENIORITY_RANK = 1 then
            OUTV_RW_ISSUE = IRB_RW_SEC_SENIOR_REF.IRB_RW_BUCKET;

        else 
            OUTV_RW_ISSUE = IRB_RW_SEC_BASE_REF.IRB_RW_BUCKET;        

    end;

    OUTV_RW_ISSUE = OUTV_RW_ISSUE * IRB_SCALING_FACTOR;
    _VALUE_ = EXP_VALUE ;
    
%mend pm_exp_securitization_irb;
