/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_mtm_2_crd4.sas
 *
 * PURPOSE: Process facility group and exposure-facility links and update facility EAD.
 *
 *   USAGE: 
 *
 *   NOTES: 5/1/2013, Modified facility_drawn table for STD approach of CRD-IV  
 *           
 *
 *****************************************************************************/

%macro r00_post_mtm_2_crd4;

/*- process exposure-facility links                                   -*/
/*- if there are no links between facilities and exposures, then stop -*/
    %local N_EXP_FAC_LINK;
    %let N_EXP_FAC_LINK = %attrn(RD_POS.exposure_facility_link, NOBS);
    %if &N_EXP_FAC_LINK = 0 %then %goto EXIT;    

/*- get values for all exposures linked to facilities -*/    
    data facilities_drawn(keep=FACILITY_ID EXP_ID DRAWN_AMT EAD SPECIFIC_PROVISION );

    length EXP_ID $32. FACILITY_ID $32.;

    if _N_ = 1 then do;
        declare hash h(hashexp:6, dataset:'RD_POS.exposure_facility_link');
        rc = h.defineKey('EXP_ID');
        rc = h.defineData('FACILITY_ID');
        rc = h.defineDone();
        call missing(EXP_ID, FACILITY_ID); 
    end;

    set &RESLIB1..all_exposures(keep=EXP_ID EXP_VALUE BALANCE_AMT INTEREST_AMT EAD SPECIFIC_PROVISION);

    rc = h.find();
    
/*- the credit should inflate the facility capital charge -*/
/*    if not missing(BALANCE_AMT) then 
       DRAWN_AMT = max(0, EXP_VALUE * BALANCE_AMT / SUM(BALANCE_AMT, INTEREST_AMT));*/
    if not (BALANCE_AMT in (.,0) and INTEREST_AMT in (.,0)) then
       DRAWN_AMT = max(0, EXP_VALUE * (BALANCE_AMT / SUM(BALANCE_AMT,INTEREST_AMT)));
    else
       DRAWN_AMT = max(0, EXP_VALUE);
       
    if rc = 0 then output;   

    run;

    proc sort data=facilities_drawn;by FACILITY_ID;run;
    
    proc summary data=facilities_drawn;
    var DRAWN_AMT EAD;
    by FACILITY_ID;
    output out=&RESLIB1..facilities_update(keep=FACILITY_ID DRAWN_AMT EAD rename=(EAD=DRAWN_EAD)) sum=DRAWN_AMT EAD;
    run;

/*-   create facility_info to get specific_provision and limit_amt info for all facilities -*/
   proc sql ; 
   create table facility_info as
   select EXP_ID as FACILITY_ID, LIMIT_AMT as FACILITY_LIMIT_AMT, SPECIFIC_PROVISION as FACILITY_SPECIFIC_PROVISION
     from   &RESLIB1..all_exposures 
     where  EXP_ID in (select distinct FACILITY_ID from RD_POS.exposure_facility_link)
   ;
   quit ; 

    proc sort data=facilities_drawn;
    by FACILITY_ID;
    run;
    
    proc sort data=facility_info ; 
    by FACILITY_ID ;
    run;

    data facilities_drawn(drop=drawn_amt);
    merge facilities_drawn(in=a) 
          &RESLIB1..facilities_update(in=b)
          facility_info ; 

    by FACILITY_ID;
    /*remove the following */
    /*if a and b then 
    do;
    if not (DRAWN_EAD in (.,0)) then
    SPECIFIC_PROVISION=SUM(SPECIFIC_PROVISION,((EAD*FACILITY_SPECIFIC_PROVISION)/DRAWN_EAD));
    end;
    */
    run;

    proc sort data=facilities_drawn;by exp_ID;run;
            
    data &RESLIB1..all_exposures;
      merge &RESLIB1..all_exposures(in=a) facilities_drawn(keep=EXP_ID SPECIFIC_PROVISION );
      by EXP_ID;
      if a;
    run;

  /*  proc sql;
        update &RESLIB1..all_exposures
            set SPECIFIC_PROVISION=0
            where   EXP_ID in(select FACILITY_ID from &RESLIB1..facilities_update);
    quit;
  /****************************************/
  
/*- get undrawn amount and update facility EAD -*/
    data &RESLIB1..all_exposures(drop=NOTE DRAWN_AMT DRAWN_EAD) 
        %if "&REPORT_ZERO_EAD" eq "YES" %then %do ;
            facilities_with_zero_ead(keep=CAPITAL CAPITAL_NO_CRM EXP_ID CCF EAD INSTSOURCE INSTNUMBER CCF_LR
                                       NOTE RW RWA RW_NO_CRM RWA_NO_CRM RWA_SECURED /*RWA_DBL_DEF_EFFECT*/ RWA_UNSECURED RW_EXP
                                      /* RW_EXP_OTHER*/) ;
        %end ;
        %else %do ;
            facilities_with_zero_ead(keep=EXP_ID INSTSOURCE INSTNUMBER CCF EAD NOTE);
        %end ;

    merge &RESLIB1..all_exposures(in=exp) &RESLIB1..facilities_update(rename=(FACILITY_ID=EXP_ID) in=fac);
    by EXP_ID;
    if exp;
    length NOTE $32.;

    /*- update the facility with drawn/undrawn amount only when EAD is not supplied -*/
    if fac then do;
    /*- if drawn portion is linked -*/
        EXP_VALUE = max(0, sum(EXP_VALUE, - DRAWN_AMT));
    /*- EAD is supplied for the facility but need to deduct the drawn portion -*/
        if not missing(EAD_AMT) then 
           EAD = max(0, sum(EAD, - DRAWN_EAD));
        else 
           EAD = EXP_VALUE * CCF / 100;

    /*- Calculate the EAD for facilities under Reg-Y  -*/
    /*- Both receive the same risk weight under Reg-Y -*/
    EAD_REG_Y = max(0,sum(EAD_REG_Y-DRAWN_EAD))*(CCF_REG_Y/100) + DRAWN_EAD ; 

        %if "&APPLY_CCF_AFTER_CRM" NE "YES" %then %do;
        /*- zero CCF doesn't matter if CCF is to be applied after CRM -*/
           if EAD = 0 OR missing(EAD) then do;
              NOTE = "Facility fully drawn or zero CCF";
              
              %if "&REPORT_ZERO_EAD" = "YES" %then %do ;
                  CAPITAL = 0 ;
                  CAPITAL_NO_CRM = 0 ;
                  RW = 0 ;
                  RWA = 0 ;
                  RW_NO_CRM = 0 ;
                  RWA_NO_CRM = 0 ;
                  RWA_SECURED = 0 ;
                  /* RWA_DBL_DEF_EFFECT = 0; */ 
                  RWA_UNSECURED = 0 ;
                  RW_EXP = 0 ; 
                  /*RW_EXP_OTHER = 0 ;*/ 
             %end ;
              output facilities_with_zero_ead;
           end;
        else   
        %end;
           output &RESLIB1..all_exposures;
    end;
    else do;
        output &RESLIB1..all_exposures;
    end;    
    run;
          
/*- add to exposures_with_zero_ead data set */
    proc append base=&RESLIB1..exposures_with_zero_ead data=facilities_with_zero_ead force;
    run;

    %local NINVALID;
    %let NINVALID = %attrn(&RESLIB1..exposures_with_zero_ead, NOBS);
    %if &NINVALID > 0 %then %do;
            %put ;    
            %print_msg(warning,2,38);
            %print_msg(warning,2,33);        
            %print_msg(warning,2,39);
            %put ;        
    %end;
    
    %local NUPDATE;
    %let NUPDATE = %attrn(&RESLIB1..facilities_update, NOBS);
    %if &NUPDATE > 0 %then %do;
        %put ;
        %print_msg(note,2,40);
        %print_msg(note,2,41);
        %put ;
    %end;

    %EXIT:
    
%mend r00_post_mtm_2_crd4;
