/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_mtm_7_usfinal.sas
 *
 * PURPOSE: Assign instrument types for regulatory calculations.
 *          
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *****************************************************************************/


%macro r00_post_mtm_7_usfinal;

/*- 1: create regulatory instrument types for exposures -*/ 
    data &RESLIB1..all_exposures
       &RESLIB1..other_items_unclassified;  
 
    length INSTTYPE $32.;
    length IRB_SCALING_FACTOR 8.;
    
    set &RESLIB1..all_exposures;

    /*- default case -*/
    INSTTYPE = compress('EXP_' || COUNTERPARTY_CLASS || '_' || APPROACH);
    
    /*- special cases -*/
    
    if APPROACH ='US_IRB' and IRB_PRODUCT_CLASS = 'HVCRE'  then 
        INSTTYPE = compress('EXP_CORPORATE_HVCRE_' || APPROACH);    

    if APPROACH = 'STD' then do;
        MAT_EFF = .;
        if STD_PRODUCT_CLASS in ('SEC', 'SECURITIZATION') then INSTTYPE = 'EXP_SECURITIZATION_STD';
        
        else if PAST_DUE_CLAIM_FLG = 1 then INSTTYPE = 'EXP_PASTDUE_STD';
        
        else if HIGH_RISK_CPTY_FLG = 1 or STD_PRODUCT_CLASS = 'HIGH_RISK' then INSTTYPE = 'EXP_HIGH_RISK_STD';
        
        else if STD_PRODUCT_CLASS = 'MORTGAGE' then do;
            if STD_PRODUCT_SUBCLASS = 'RESIDENTIAL' then INSTTYPE = 'EXP_RME_STD';
            else if STD_PRODUCT_SUBCLASS = 'COMMERCIAL' then INSTTYPE = 'EXP_CME_STD';
        end;
        
        else if STD_PRODUCT_CLASS = 'OTHER_ASSETS' then INSTTYPE = 'EXP_OTHER_ASSETS_STD';
        else if COUNTERPARTY_CLASS = ' ' then do;
            INSTTYPE = 'EXP_OTHER_ASSETS_STD';
      output &RESLIB1..other_items_unclassified;
    end;
          
    end;        
    
    /*- retail exposures -*/
    else if APPROACH = 'IRB' then do;
        if RECEIVABLE_EXPOSURE_FLG = 1 then do;
            INSTTYPE = 'EXP_RETAIL_REC_IRB';
        end;
        else do;
            INSTTYPE = 'EXP_RETAIL_IRB';
        end;
    end;
    
    /*- specialized lending (HVCRE) and purchased receivables -*/
    else if APPROACH in ('IRBF', 'IRBA') then do;  
        if APPROACH = 'IRBF' and "&IRBF_M_SUPERVISORY" = "YES" then do;
           MAT_EFF = &IRBF_M;
           if IRB_PRODUCT_CLASS = 'REPO_STYLE' then
              MAT_EFF = &IRBF_M_REPO;
        end;
        
        if IRB_PRODUCT_CLASS = 'SL' and IRB_PRODUCT_SUBCLASS = 'HVCRE' then 
            INSTTYPE = compress('EXP_CORPORATE_HVCRE_' || APPROACH);
        else if IRB_PRODUCT_CLASS = 'PURCHASED_REC' then do;
            INSTTYPE = compress('EXP_CORPORATE_REC_' || APPROACH);           
            if APPROACH = 'IRBF' then MAT_EFF = &IRBF_M_REC_DEFAULT;
        end;
    end;
    
    /*- securitization exposures -*/
    else if APPROACH in ('IRB_RBA', 'IRB_IAA') then do;
        MAT_EFF = .;
        INSTTYPE = 'EXP_SECURITIZATION_IRB';             
    end; 
    
    /*- slotting criteria for specilized lending -*/
    else if APPROACH = 'IRB_SLOTTING' then do;
        MAT_EFF = &IRBF_M;
        if IRB_PRODUCT_SUBCLASS = 'HVCRE' then INSTTYPE = 'EXP_HVCRE_IRB_SLOTTING';
        else INSTTYPE = 'EXP_SL_IRB_SLOTTING';
    end;
    
    /*- equity exposures under US Final US_SRWA approach -*/
    else if APPROACH in ('US_SRWA') then do;
        /*MAT_EFF = &IRB_M_EQUITY;*/
        INSTTYPE = compress('EXP_EQ_' || APPROACH);
    end;
    
    /*- Investment fund exposures under IRB approach -*/
    else if APPROACH in ('US_SIMPLE_LKTHRU', 'US_MMF') then do;
                INSTTYPE = compress('EXP_FND_' || APPROACH);
    end;
    
    /*- define scaling factor according to approach -*/
    IRB_SCALING_FACTOR = input(put(APPROACH, $MAP_CAPITAL_SCALING_FACTOR.), best12.);
    
    /*- a special case is the securitization pool capital charge for the originator bank -*/
    if POSITION_CATEGORY = 'SEC_POOL' then do;
        INSTTYPE = 'EXP_SECURITIZATION_POOL';
        IRB_SCALING_FACTOR = 1; /* scaling factor is one no matter what approach */  
    end;
    
    if APPROACH ='US_IRB' and IRB_PRODUCT_CLASS = 'SECURITIZATION'  then do;
          INSTTYPE = 'EXP_SECURITIZATION_POOL';
          IRB_SCALING_FACTOR = 1; /* scaling factor is one no matter what approach */  
    end;
    
    /*- lease residual value -*/
    if IRB_PRODUCT_SUBCLASS = 'LEASE_RESIDUAL' then do;
        INSTTYPE = 'EXP_LEASE_RESIDUAL_VALUE';
        IRB_SCALING_FACTOR = 1; /* scaling factor is one no matter what approach */  
    end;

  output &RESLIB1..all_exposures ;

    run;

  %local NOTHERS;
  %let NOTHERS = %attrn(&RESLIB1..other_items_unclassified, NOBS);
  %if &NOTHERS > 0 %then %do;
  %put; 
    %print_msg(warning, 2, 305);
  %print_msg(warning, 2, 306);
  %print_msg(warning, 2, 307);
  %put;
  %end;   
    
   /* Invalidate exp data with missing instrument types */ 
       data  &RESLIB1..all_exposures  
          &RESLIB1..Invalid_exp_insttypes ; 
      set &RESLIB1..all_exposures  ; 
     if missing (INSTTYPE) or (INDEX(INSTTYPE, '#') NE 0) then  output &RESLIB1..Invalid_exp_insttypes ; 
     else output 
          &RESLIB1..all_exposures ; 

   /* Applying Labels to ALL_EXPOSURES data set */
     label 
      ACCOUNT_AGE = "Account Age"
      ACCOUNT_LE_TWO_YR_FLG = "Flag indicating for Account Age less than two years" 
      AVG_AGE_MNTHS = "Average age in months"
      BALANCE_AMT = "Balance Amount"
      BALANCE_SHEET_AMT = "Balance Sheet Amount"
      BALANCE_AMT_SEG = "Balance Amount Segment"
      CAPITAL = "Capital"
      CAPITAL_NO_CRM = "Capital required if CRM effects is not considered"
      EAD_LE_TWO_YEARS = "EAD amount where Account Age is less than two years at exposure level"
      EAD_TWO_YEARS = "EAD amount for the exposures where Account Age is less than two years at segment level"
      ELIGIBLE_SECURITIZATION = "Eligible securitization"
      INSTTYPE = "Instrument Type"
      INTEREST_AMT = "Interest Amount"
      IRB_SCALING_FACTOR = "IRB Scaling Factor"
      IRB_PRODUCT_CLASS_CHANGED_FLG = "Flag indicating  IRB product Class changed from QUALIFYING_REVOLVING to OTHER_RETAIL"
      NUM_EXPOSURES = "Number of Exposures"
      PRIMARY_BANK_ROLE = "Primary Bank Role"
      RECEIVABLE_EXPOSURE_FLG = "Receivable Exposure Flag"
      RW = "Risk Weights"
      RW_EXP = "Risk Weight for Exposure"
      RW_EXP_OTHER = "Exposure Risk Weight using LGD_OTHER value "
      RWA = "Risk Weighted Assets" 
      RW_NO_CRM = "Risk weight without considering the CRM effect"
      RWA_DBL_DEF_EFFECT = "RWA Amount for Double Default treatment"
      RWA_NO_CRM = "RWA Amount without considering CRM effect"
      RWA_SECURED = "RWA Amount that is secured by CRMs"
      RWA_UNSECURED = "RWA Amount which remains unsecured in partially covered CRM cases or Non-CRM cases"
      SEC_STRUCTURE_TYPE = "Securitization Structure Type"
      SECURITIZATION_EXPOSURE_FLG = "Securitization Exposure Flag"
      UNDRAWN_AMT_SEG = "Undrawn Amount for Segment"
     HEDGE_PAIR_PORTION = "Portion of the Exposure which is part of the Hedge pair"
     REMAINING_EQ_EXP = "Remaining Equity exposure after Hedging"
     EAD_ADJ = "Adjusted EAD for RWA"
     CRM_TYPE = "Regulatory CRM Type";
   run ;     
    
/*- 2: create regulatory instrument types for crms -*/    
    data &RESLIB1..all_crms;

    length INSTTYPE $32.;
    
    set &RESLIB1..all_crms;    
      
    select (CRM_TYPE);
    
        when ('FINANCIAL_COLLATERAL')
            INSTTYPE = 'CRM_FINANCIAL';

        when ('IRB_COLLATERAL') 
            INSTTYPE = 'CRM_IRB';
 
        when ('GUARANTEE')
            INSTTYPE = 'CRM_GUARANTEE';

        when ('CREDIT_DERIVATIVE')
            INSTTYPE = 'CRM_DERIVATIVE';

        when ('INSURANCE')
            INSTTYPE = 'CRM_INSURANCE';

        when ('NETTING') 
            INSTTYPE = 'CRM_NETTING';           
   
        otherwise;
        
    end;
    
    run;

 /* Invalidate crm data with missing instrument types */ 
       data  &RESLIB1..all_crms  
          &RESLIB1..Invalid_crms_types ; 
      set &RESLIB1..all_crms  ; 
     if missing (INSTTYPE) then  output &RESLIB1..Invalid_crms_types ; 
      else output 
          &RESLIB1..all_crms ;

       run ; 

 
/*- 3: report -*/    
    %put ;
    %print_msg(note,2,53);

    %local NO_EXP;
    %let NO_EXP = %attrn(&RESLIB1..all_exposures, NOBS);

    proc summary data=&RESLIB1..all_crms missing;
    class CRM_TYPE;
    output out=crm_summary ;
    run;

    %print_msg(note,2,54);
    %print_msg(note,2,55);

    %put ;
    %print_msg(note,2,56);
    
    data _null_;
    set crm_summary;
    if _type_ = 1 then do ;
        call execute('%put &NOTE: ***' !! trim(left(_freq_)) !! ' ' !! CRM_TYPE !! ' ***;');
    end;
    run;

    %put ;


%mend r00_post_mtm_7_usfinal;
