/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_3_usfinal.sas
 *
 * PURPOSE: Check CRM eligibility based on exposure approach and etc. Also,
 *          create a data set for the Reg Y information to be appended to  
 *          the allexposures for Reg Y calculations.                       
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *****************************************************************************/

%macro r00_post_regulatory_3_usfinal;

/*- 1: eligibility based on exposure approach, maturity mismatch criteria, and crm accounted for in PD/LGD -*/
    data &RESLIB1..exposure_crm(drop=INVALID_FLG index = (EXPCRM=(EXP_ID CRM_ID)))
         &RESLIB1..exposure_crm_sec_underlying(drop=INVALID_FLG index = (EXPCRM=(EXP_ID CRM_ID)))
         _exp_crm_irb_(index=(EXP_ID))
         &RESLIB1..all_exposure_crm_invalid
         (keep=EXP_ID CRM_ID APPROACH ELIGIBLE_CRM_TYPE INCEPTION_DATE CRM_INCEPTION_DATE MATURITY_DATE 
               CRM_MATURITY_DATE LINK_MATURITY_DATE REASON RW_EXP RW_EXP_OTHER RW_CRM PD_EXP PD_CRM_COUNTERPARTY
          index = (EXPCRM=(EXP_ID CRM_ID))
         )
         ;
    length REASON $256.;         
    
    set &RESLIB1..all_exposure_crm;

    
    label LINK_RESIDUAL_MATURITY="(Effective) Residual Maturity of the CRM Link";
    INVALID_FLG = 0;

/*- update link_residual_maturity -*/

    if LINK_MATURITY_DATE = . then
        LINK_RESIDUAL_MATURITY = CRM_RESIDUAL_MATURITY;
    else do;
    LINK_RESIDUAL_MATURITY=max(0, round(YRDIF(&RUNDATE, LINK_MATURITY_DATE, "&DAY_BASIS"),&MATURITY_ROUNDOFF.));
    LINK_RESIDUAL_MATURITY = min(LINK_RESIDUAL_MATURITY, CRM_RESIDUAL_MATURITY);
    end;
    if APPROACH = 'BASEL_I' then do;
      if ELIGIBLE_CRM_TYPE not in ('CRM_BASELI') then do;
          REASON = 'CRM not eligible under BASEL I';
            INVALID_FLG = 1;
        end;
    end;  

    else if APPROACH in ('US_IRB','IRB_RBA', 'IRB_IAA') then do;

        if ELIGIBLE_CRM_TYPE not in ('CRM_BASELI','CREDIT_DERIVATIVE','NETTING','GUARANTEE',
                                     'FINANCIAL_COLLATERAL','NON_FINANCIAL_COLLATERAL' )
        then do;
            REASON = "%print_msg(,2,160,1)";
            INVALID_FLG = 1 ;
        end;
      /* Change condition for invalid such that for guarantee, cd and insurance, even if pd or lgd flg is 1, */
      /*   they are not routed to invalid table. This ensures the crm amount gets calculated                 */
        else if (ELIGIBLE_CRM_TYPE in ('FINANCIAL_COLLATERAL','NON_FINANCIAL_COLLATERAL','CRM_BASELI','NETTING' ) and
        (PD_CRM_ADJUSTED_FLG = 1 or LGD_CRM_ADJUSTED_FLG = 1)) or (IRB_PRODUCT_CLASS = "RESIDENTIAL_MORTGAGE")
        then do;
            REASON = "%print_msg(,2,161,1)";
            INVALID_FLG = 1 ;
        end;

        else if RESIDUAL_MATURITY = . or LINK_RESIDUAL_MATURITY = .  then do;
            /*- exception: repo-style transactions -*/
             if IRB_PRODUCT_CLASS NE 'REPO_STYLE' and IRB_PRODUCT_CLASS NE 'EML' then do;
               REASON = "%print_msg(,2,167,1)";
               INVALID_FLG = 1 ;
            end;
        end;

        else if INCEPTION_DATE = . or CRM_INCEPTION_DATE = . then do;
            REASON = "%print_msg(,2,169,1)";
            INVALID_FLG = 1 ;
        end;
        
        else if LINK_RESIDUAL_MATURITY < RESIDUAL_MATURITY then do;
            /*- exception: repo-style transactions -*/
             if IRB_PRODUCT_CLASS NE 'REPO_STYLE' and IRB_PRODUCT_CLASS NE 'EML' then do; 
                if CRM_ORIGINAL_MATURITY < &MAT_MISMATCH_ORGMAT_MIN_CRM then do;
                   REASON = "%print_msg(,2,157,1)";
                   INVALID_FLG = 1 ;
                end;
    
                else if LINK_RESIDUAL_MATURITY <= &MAT_MISMATCH_RESMAT_MIN_CRM then do;
                   REASON = "%print_msg(,2,158,1)";
                   INVALID_FLG = 1 ;
                end;
            end;
        end;

    end;

    else if POSITION_CATEGORY = "SECURITIZATION_POSITION" and 
            PRIMARY_BANK_ROLE in ('ORIGINATOR', 'SPONSOR') then do;
        if upcase(ELIGIBLE_SECURITIZATION) ~= 'Y' then do;
           REASON = "%print_msg(,2,249, 1)";
           INVALID_FLG = 1 ;
        end;
    end;
    
    if INVALID_FLG = 1 then output &RESLIB1..all_exposure_crm_invalid;
    else do;
        /*- all links except when an exposure is securitized -*/
        if SEC_UNDERLYING_EXP_FLG NE 1 then output &RESLIB1..exposure_crm;
        /*- all links with securitized exposures -*/
        else output &RESLIB1..exposure_crm_sec_underlying; 
        /*- need to get all valid CRMs for exposures subject to IRB for min collateralization level check -*/
        if APPROACH =: 'IRB' then output _exp_crm_irb_;
    end;

    run;

/*- 2: additional eligibility based on minimum collateralization levels of IRB collateral -*/
/*- If CRM values from IRB collateral (CRE/RRE and OTHER) is less than minimum collateralization level multipiled     -*/
/*- by exposure EAD after other CRM values are taken out, then the IRB collateral (CRE/RRE and OTHER) can not be used -*/
/*- If the binding minimum collateralization levels are different, a more elegant approach needs to be used !         -*/

/*- get IRB exposures and their crms -*/
/*- This is done without consideration of the fact that multiple exposures may share the same CRMs -*/

/*- for each exposure, find if IRB collateral collectively satisfies min collateralization level -*/
    data _exp_crm_irb_invalid_(keep=EXP_ID index=(EXP_ID)); 
    set _exp_crm_irb_;
    by EXP_ID;
    retain CRM_VALUE_BINDING CRM_VALUE_NOT_BINDING IRB_COLL_MIN_LEVEL 0;

    if first.EXP_ID then do;
        C_STAR_BINDING_COUNT = 0;
        CRM_VALUE_BINDING = 0;
        CRM_VALUE_NOT_BINDING = 0;
    end;    

    if CRM_TYPE = 'IRB_COLLATERAL' and CRM_SUBTYPE in ('CRE', 'RRE', 'OTHER') then do;
        C_STAR_BINDING_FLG = 1;
        CRM_VALUE_BINDING = sum(CRM_VALUE_BINDING, CRM_VALUE);
        IRB_COLL_MIN_LEVEL = C_STAR;
    end;
    else do;
        C_STAR_BINDING_FLG = 0;
        CRM_VALUE_NOT_BINDING = sum(CRM_VALUE_NOT_BINDING, CRM_VALUE);
    end;

    /*- since the binding minimum collateralization levels are the same -*/    
    MIN_COLL_FAILED_FLG = (CRM_VALUE_BINDING < sum(EAD, - CRM_VALUE_NOT_BINDING) * IRB_COLL_MIN_LEVEL / 100);
    
    if last.EXP_ID and MIN_COLL_FAILED_FLG then output _exp_crm_irb_invalid_; 

    run;

    /*- all binding CRMs: invalid -*/
    data _exp_crm_irb_invalid_
        (keep=EXP_ID CRM_ID APPROACH ELIGIBLE_CRM_TYPE INCEPTION_DATE CRM_INCEPTION_DATE MATURITY_DATE 
         CRM_MATURITY_DATE REASON PD_EXP RW_EXP RW_EXP_OTHER PD_CRM_COUNTERPARTY RW_CRM LINK_MATURITY_DATE
         index = (EXPCRM=(EXP_ID CRM_ID)));
    merge _exp_crm_irb_ _exp_crm_irb_invalid_(in=invalid);
    by EXP_ID;
    if invalid and CRM_TYPE = 'IRB_COLLATERAL' and CRM_SUBTYPE in ('CRE', 'RRE', 'OTHER');
    length REASON $256.;
    REASON = "%print_msg(,2,162,1)";
    run;

    /*- all invalid links -*/
    proc append base=&RESLIB1..all_exposure_crm_invalid data=_exp_crm_irb_invalid_;run;

/*- 3: remove additional invalid exposure-crm link -*/    
    %local NINVALID;
    %let NINVALID = %attrn(_exp_crm_irb_invalid_, NOBS);
    %if &NINVALID > 0 %then %do;
        data &RESLIB1..exposure_crm;
        merge &RESLIB1..exposure_crm(in=link) 
              _exp_crm_irb_invalid_(in=invalid keep=EXP_ID CRM_ID)
              ;
        by EXP_ID CRM_ID;
        if not invalid;
        run;
        
        data &RESLIB1..exposure_crm_sec_underlying ; 
        merge &RESLIB1..exposure_crm_sec_underlying(in=link) 
              &RESLIB1..all_exposure_crm_invalid(in=invalid keep=EXP_ID CRM_ID)
              ;
        by EXP_ID CRM_ID;
        if not invalid;
        run;    
    %end;
 
/*- 4: report the removed invalid links -*/
    %let NINVALID = %attrn(&RESLIB1..all_exposure_crm_invalid, NOBS);
    %if &NINVALID > 0 %then %do;
        %put ;
        %print_msg(warning,2,65);
        %print_msg(warning,2,66);
        %put ;
    %end;
    
/*- 5: check LGD floor for retail mortgage in the IRB approach, if requested -*/
/*- A specific floor is assigned to the LGD estimate for mortgages.  
    All the exposures with LGD lower than this floor will be reported for further
    attention.  But these exposures won't be excluded from further calculation    -*/

    %if "&APPLY_LGD_RETAIL_RME_FLOOR" = "YES" %then %do ;

        /*- Create a macro variable containing the transitional LGD floor -*/
        data _null_ ;
            set RD_MKT.current_lgd (where = (LGD_NAME = 'IRB_LGD_RETAIL_RME_FLOOR')) ;
            call symput(trim(left(LGD_NAME)),trim(left(LGD_VALUE))) ;
        run ;

        data &RESLIB1..res_mortgages_low_lgd (keep=EXP_ID APPROACH IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS
                                                   LGD_EXP LGD_MODEL_ID LGD_MODEL_RATING_GRADE LGD_PCT);
            set &RESLIB1..all_exposures 
                (where=(APPROACH in ('US_IRB') and IRB_PRODUCT_CLASS='RESIDENTIAL_MORTGAGE')); 
            if LGD_PCT < &IRB_LGD_RETAIL_RME_FLOOR then
            output;
        run;
    
        %local NLOWLGD;
        %let NLOWLGD = %attrn(&RESLIB1..res_mortgages_low_lgd, NOBS);
            %if &NLOWLGD > 0 %then %do;
                %put ;
                %print_msg(warning,2,247);
                %print_msg(warning,2,248);
                %put ;
        %end;
    %end ;
    
%mend r00_post_regulatory_3_usfinal;
