/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: recreate_macros.sas
 *
 * PURPOSE: Recreate global macro definitions from a data set.
 *
 *   USAGE: recreate_macros.sas;
 *
 *   NOTES: Macro definitions are from RD_ROOT.gmacros.
 *          
 *
 *****************************************************************************/

/*- recreate macro definitions from a previously saved data set -*/
/*- a macro definition is recreated if the macro is not defined in the current session -*/
/*- or if it is defined in this session but without a value                            -*/
%macro recreate_macros ();

    %if (%dsexist(RD_ROOT.gmacros)) EQ 1 %then %do;
        /*data _null_;
	        set RD_ROOT.gmacros(WHERE=(MACRO_NAME NOT IN ("RPT_LANG0","REPORTING_LANGUAGE0")));
        	call symputx(trim(left(MACRO_NAME)), ktrim(kleft(MACRO_VALUE)),'g');
    	run;*/
	data PREV_macros;
	attrib macro_name length =$32.;
	attrib macro_value length=$32000.;
	stop;
	run;
	%if (%dsexist(RD_ROOT.gmacros)) EQ 1 %then %do;
		proc append data=rd_root.gmacros base=prev_macros force;
		run;
	%end;

	/*In case project info table is already present then rename it*/
	%if (%dsexist(RD_ROOT.project_info)) EQ 1 %then %do;
		proc datasets library=rd_root nolist;
			change project_info=project_inf1;
		run;
	%end;
	/*Save the current session macros in RD_ROOT.GMACROS*/
	%u00_save_macro_definitions;
	/*Move RD_ROOT.GMACROS to WORK.EMP_MACROS*/
	proc copy in=rd_root out=work;
		select gmacros;
	run;quit;
	/*Rename WORK.GMACROS to TEMP_MACROS*/
	proc datasets nolist library=work;
		delete temp_macros;
		change gmacros=temp_macros;
	run;quit;
	/*Reset the project info and delete gmacros*/
	proc datasets library=rd_root nolist;
		delete project_info;
		change project_inf1=project_info;
		delete gmacros;
	run;quit;
	data all_session_macros;
		merge 
	    prev_macros(WHERE=(MACRO_NAME NOT IN ("RPT_LANG0","REPORTING_LANGUAGE0")))
		temp_macros;
		by macro_name;
		call symputx(trim(left(MACRO_NAME)), ktrim(kleft(MACRO_VALUE)),'g');
	run;
	%end;
        
%mend recreate_macros;
