/*****************************************************************************
* Copyright (c) 2015 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_capital_cva_crd4.sas
*
* PURPOSE: Creates report for the CRGB SA report
*
*
*   USAGE: This is a draft
*
*   Macro Options:
*****************************************************************************/
 
%macro regrpt_capital_cva_crd4;

/* Create Data for Report */
%regrpt_d0_capital_cva_crd4;
 
proc format;
value $exp_type (default=256)
   "CVA_RISK_TOTAL"='CVA risk total'
   "ACC_ADV_METHOD"='According to Advanced method'
   "ACC_STD_METHOD"='According to Standardised method'
   "OEM"='Based on OEM'
;
RUN;

proc format;
   value $Aggregate
            "+"="Aggregate Total"
            ;
run;   
   
**********************************************************;
* Create Local macros for CVA Reporting                 *;
**********************************************************;
%let style_type=%str(style=Data[Tagattr='format:#,##0' ]);  


/* Creates basic  template report */
%macro cva_report_page (dsn);
 
 
proc report data=&DSN  nowd missing LS=160 PS=50   contents="" split="*"

style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0  }
style(header)={background=#CED3D6 cellheight=0  cellspacing=0 fontweight=bold  /*VERTICALALIGN=Middle */  /* just=center */ } ;

 
COLUMN  CLASS_CR_CVA         
      ("&CVA_010_rpt_label."
      OUTV_CVA_EAD_AMT          /* Col 010 */
      OUTV_CVA_DERIVATIVES_AMT         /* Col 020 */
      OUTV_CVA_SFT_AMT     )        /* Col 030 */
      ("&CVA_Var_rpt_label. "
      MULTIPLICATION_FACTOR   /* Col 040 */
      PREVIOUS_DAY            /* Col 050 */
      )         
      ("&CVA_Stress_var_rpt" 
      MULTIPLICATION_FACTOR2  /* Col 060 */
      LATEST_AVAILABLE        /* Col 070 */
      )
      OUTV_CVA_CHARGE_AMT            /* Col 080 */
      OUTV_CVA_TOTAL_RISK_EXP_AMT            /* Col 090 */
      (
      "&CVA_Memo_rpt_label."
      OUTV_CVA_CPTY_NO              /* Col 100 */
      OFWHICH_PROXY                 /* Col 110 */
      INCURRED_CVA                  /* Col 120 */
            )
      ("&CVA_hedg_notional_rpt"
      OUTV_NAME_CDS_AMT              /* Col 130 */ 
      OUTV_INDEX_CDS_AMT             /* Col 140 */
      )
      ;
        
define       CLASS_CR_CVA        /display format=$exp_type.    Style=[ font_weight=bold ]           "";
define       OUTV_CVA_EAD_AMT      /display format=&FORMAT_VALUE  &style_type.   '* ' ;
define       OUTV_CVA_DERIVATIVES_AMT     /display format=&FORMAT_VALUE   &style_type.       "&CVA_020_rpt_label. ";
define       OUTV_CVA_SFT_AMT         /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_030_rpt_label.";

define       MULTIPLICATION_FACTOR        /display format=&FORMAT_VALUE  &style_type.    ' ' "&CVA_040_rpt_label.";
define       PREVIOUS_DAY        /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_050_rpt_label.";
define       MULTIPLICATION_FACTOR2        /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_060_rpt_label.";
define       LATEST_AVAILABLE    /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_070_rpt_label";

define       OUTV_CVA_CHARGE_AMT        /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_080_rpt_label.";
define       OUTV_CVA_TOTAL_RISK_EXP_AMT        /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_090_rpt_label.";

define       OUTV_CVA_CPTY_NO           /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_100_rpt_label.";
define       OFWHICH_PROXY           /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_110_rpt_label.";

define       INCURRED_CVA        /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_120_rpt_label.";
/*define       MEAN_CREDIT_SPREAD  /display &style_type.    ' '          'MEAN CREDIT SPREAD';*/
 
define       OUTV_NAME_CDS_AMT     /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_130_rpt_label.";
define       OUTV_INDEX_CDS_AMT           /display format=&FORMAT_VALUE  &style_type.    ' '          "&CVA_140_rpt_label.";
 
    compute CLASS_CR_CVA;
       count+1;
       if mod(count,2) then do;
         call define(_row_,"Style", "Style=[background=#E6EDFF]");
       end;
    endcomp;
 
run;
 
%mend cva_report_page ;
 
 
%macro reportbody ;

%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.cva_report_data))
  or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
  %print_msg(warning,3,10);
  %print_msg(warning,3,15);
  %regulatory_reportnopage();
  %return;
  %goto FINAL;
%end;

%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
     
   ods tagsets.ExcelXP_Mod 
       options(
      sheet_name="&rpt_cd."
      sheet_interval='none' autofit_height="yes");
      %_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
       options(
      autofit_height="YES"  );

%end;  

  %regulatory_reportheaders (cva_report_data );  
  %cva_report_page (cva_report_data);
  
 
  /* subroutine for no data available for report page */
  %NOPAGE:      

%FINAL: 
footnote ;

%mend reportbody; /* end reportbody macro */                              

%reportbody;

%mend regrpt_capital_cva_crd4;
