/*-- Copyright (c) 2015 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/ 
/*
Model         Regulatory Risk Management 5.2 Datamodel
Subject Area  Config
Model Version 
Macro Name    ddl_script_static.sas
DBMS          SAS
Created       5/14/15 3:13:51 PM
Copyright (c) 2015 by SAS Institute Inc., Cary, NC 27513          
*/
/* Assign a libname to the location to store the static tables    */
/* and set the macro var LIBNAME to the libref name               */

PROC SQL;

CREATE TABLE &LIBNAME..ADD_ON
(
   ADD_ON_SET_ID        VARCHAR(32)
      LABEL = 'Add On Set Id',
   ADD_ON_NM            VARCHAR(40)
      LABEL = 'Add On Name',
   MATURITY_BAND_CD     VARCHAR(30)
      FORMAT = $18.
      INFORMAT = $18.
      LABEL = 'Maturity Band Code',
   ADD_ON_PCT           NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Add On Percent',
   ADD_ON_SET_TYPE_CD   VARCHAR(3)
      LABEL = 'Add On Set Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ADD_ON_NM,ADD_ON_SET_ID,ADD_ON_SET_TYPE_CD,MATURITY_BAND_CD)
);



CREATE TABLE &LIBNAME..ADD_ON_SET
(
   ADD_ON_SET_ID        VARCHAR(32)
      LABEL = 'Add On Set Id',
   ADD_ON_SET_DESC      VARCHAR(100)
      LABEL = 'Add On Set Description',
   ADD_ON_SET_TYPE_CD   VARCHAR(3)
      LABEL = 'Add On Set Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ADD_ON_SET_ID,ADD_ON_SET_TYPE_CD)
);



CREATE TABLE &LIBNAME..ADD_ON_SET_TYPE
(
   ADD_ON_SET_TYPE_CD   VARCHAR(3)
      LABEL = 'Add On Set Type Code',
   ADD_ON_SET_TYPE_DESC VARCHAR(100)
      LABEL = 'Add On Set Type Description' NOT NULL ,
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ADD_ON_SET_TYPE_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..ANALYTICAL_MODEL
(
   MODEL_TYPE_CD        VARCHAR(3)
      LABEL = 'Model Type Description',
   MODEL_DESC           VARCHAR(250)
      LABEL = 'Model Description',
   MODEL_RK             NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Model Key',
   MODEL_NM             VARCHAR(60)
      LABEL = 'Model Name',
   MODEL_CREATION_DT    DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Model Creation Date',
   MODEL_DEPLOYMENT_CD  VARCHAR(3)
      LABEL = 'Contact Type Code',
   VERSION_NO           VARCHAR(20)
      LABEL = 'Version No',
   MODEL_ID             VARCHAR(32)
      LABEL = 'Model Id',
   TARGET_PERIOD_CNT    NUMERIC(6)
      LABEL = 'Target Period Count',
   TARGET_PERIOD_TIME_UOM_CD VARCHAR(3)
      LABEL = 'Target Period Time UOM Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_RK)
);



CREATE TABLE &LIBNAME..APPROACH_TYPE
(
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   APPROACH_TYPE_DESC   CHARACTER(100)
      LABEL = 'Approach Type Description',
   CONSTRAINT PRIM_KEY PRIMARY KEY (APPROACH_TYPE_CD)
);



CREATE TABLE &LIBNAME..ASSESSMENT_RATING_GRADE
(
   ASSESSMENT_RATING_GRADE_RK NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Assessment Rating Grade Key',
   ASSESSMENT_RATING_GRADE_ID VARCHAR(32)
      LABEL = 'Assessment Rating Grade Id',
   ASSESSMENT_AGENCY    VARCHAR(5)
      LABEL = 'Assessment Agency Code' NOT NULL ,
   ASSESSMENT_GRADE     VARCHAR(20)
      LABEL = 'Assessment Grade',
   ASSESSMENT_SCORE_NO  NUMERIC(10,2)
      FORMAT = NLNUM10.2
      INFORMAT = NLNUM10.2
      LABEL = 'Assessment Score No',
   ASSESSMENT_TYPE_CD   VARCHAR(3)
      LABEL = 'Assessment Type Code',
   SHORTTERM_FLG        NUMERIC(8)
      LABEL = 'Shortterm Flag',
   MODEL_RK             NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Model Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ASSESSMENT_RATING_GRADE_RK)
);



CREATE TABLE &LIBNAME..CCF
(
   CCF_NM               VARCHAR(40)
      LABEL = 'CCF Name',
   CCF_PCT              NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'CCF Percent',
   CCF_SET_ID           VARCHAR(32)
      LABEL = 'CCF Set Id',
   SHORT_MATURITY_FLG   NUMERIC(8)
      LABEL = 'Short Maturity Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CCF_SET_ID,CCF_NM,SHORT_MATURITY_FLG)
);



CREATE TABLE &LIBNAME..CCF_EAP
(
   CCF_NM               VARCHAR(40)
      LABEL = 'CCF Name',
   COMMITTED_FLG        NUMERIC(8)
      LABEL = 'Committed Flag' NOT NULL ,
   CCF_PCT              NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'CCF Percent',
   CCF_EAP_SET_ID       VARCHAR(32)
      LABEL = 'CCF Eap Set Id',
   EXCESS_SPREAD_BAND_CD VARCHAR(30)
      LABEL = 'Excess Spread Band Code',
   EARLY_AMORTIZATION_TYPE_CD CHARACTER(3)
      LABEL = 'Early Amortization Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CCF_NM,CCF_EAP_SET_ID)
);



CREATE TABLE &LIBNAME..CCF_EAP_SET
(
   CCF_EAP_SET_ID       VARCHAR(32)
      LABEL = 'CCF Eap Set Id',
   CCF_EAP_SET_DESC     VARCHAR(100)
      LABEL = 'CCF Eap Set Description',
   ESTIMATION_MODEL_RK  NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Model Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CCF_EAP_SET_ID)
);



CREATE TABLE &LIBNAME..CCF_SET
(
   CCF_SET_ID           VARCHAR(32)
      LABEL = 'CCF Set Id',
   CCF_SET_DESC         VARCHAR(100)
      LABEL = 'CCF Set Description',
   ESTIMATION_MODEL_RK  NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Model Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CCF_SET_ID)
);



CREATE TABLE &LIBNAME..CONFIGURATION
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   REGULATORY_CONTEXT_ID     VARCHAR(32)
	  LABEL = 'Regulatory Context',
   ADD_ON_SET_ID        VARCHAR(32)
      LABEL = 'Add On Set Id',
   CCF_SET_ID           VARCHAR(32)
      LABEL = 'CCF Set Id',
   CCF_EAP_SET_ID       VARCHAR(32)
      LABEL = 'CCF Eap Set Id',
   HAIRCUT_SET_ID       VARCHAR(32)
      LABEL = 'Haircut Set Id',
   REGULATORY_OPTION_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Option Set Id',
   REGULATORY_RISK_WEIGHT_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATORY_PARAMETER_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Parameter Set Id',
   MINIMUM_LGD_SET_ID   CHARACTER(32)
      LABEL = 'Minimum LGD Set Id',
   HAIRCUT_FX_SET_ID    CHARACTER(32)
      LABEL = 'Haircut Fx Set Id',
   REGULATORY_LGD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory LGD Set Id',
   REGULATORY_PD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Pd Set Id',
   LE_CAP_MULT_SET_ID   VARCHAR(32) 
      label='Large Exposure Factor Set Identifier',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID)
);



CREATE TABLE &LIBNAME..CONFIGURATION_X_INTERNAL_ORG
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   INTERNAL_ORG_RK      NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,INTERNAL_ORG_RK)
);



CREATE TABLE &LIBNAME..EARLY_AMORTIZATION_TYPE
(
   EARLY_AMORTIZATION_TYPE_CD CHARACTER(3)
      LABEL = 'Early Amortization Type Code',
   LANGUAGE_CD          CHARACTER(3)
      LABEL = 'Language Code',
   EARLY_AMORTIZATION_TYPE_DESC CHARACTER(100)
      LABEL = 'Early Amortization Type Description',
   CONSTRAINT PRIM_KEY PRIMARY KEY (EARLY_AMORTIZATION_TYPE_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..ENTITY_SYSTEM_ID
(
   SYSTEM_ID            CHARACTER(32)
      LABEL = 'System Id',
   BUSINESS_ENTITY_DESC CHARACTER(100)
      LABEL = 'Business Entity Description',
   INTERNAL_ORG_RK      NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (SYSTEM_ID)
);


CREATE TABLE &LIBNAME..ENTITY_X_CONFIGURATION
(
	CONFIGURATION_ID     VARCHAR(32)
		LABEL = 'Configuration Id',
    SYSTEM_ID            CHARACTER(32)
      	LABEL = 'System Id',
	INTERNAL_ORG_RK      NUMERIC(8)
		FORMAT = 12.
		INFORMAT = 12.
		LABEL = 'Internal Org Key',
	CURRENCY             CHARACTER(3)
		LABEL = 'Currency',
		CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,INTERNAL_ORG_RK)
);


CREATE TABLE &LIBNAME..EXCESS_SPREAD_BAND
(
   EXCESS_SPREAD_BAND_CD VARCHAR(30)
      LABEL = 'Excess Spread Band Code',
   EXCESS_SPREAD_BAND_DESC VARCHAR(100)
      LABEL = 'Excess Spread Band Description',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   EXCESS_BAND_MIN      NUMERIC(18,5)
      FORMAT = NLNUM6.2
      INFORMAT = NLNUM6.2
      LABEL = 'Excess Band Min',
   EXCESS_BAND_MAX      NUMERIC(18,5)
      FORMAT = NLNUM6.2
      INFORMAT = NLNUM6.2
      LABEL = 'Excess Band Max',
   CONSTRAINT PRIM_KEY PRIMARY KEY (EXCESS_SPREAD_BAND_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..HAIRCUT
(
   HAIRCUT_PCT          NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Haircut Percent',
   HAIRCUT_NM           VARCHAR(40)
      LABEL = 'Haircut Name',
   HAIRCUT_SET_ID       VARCHAR(32)
      LABEL = 'Haircut Set Id',
   HAIRCUT_SOV_PCT      NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Haircut Sov Percent',
   MIN_HOLDING_PERIOD_DAYS_CNT NUMERIC(8)
      LABEL = 'Min Holding Period Days Count',
   REMARGIN_PERIOD_DAYS_CNT NUMERIC(8)
      LABEL = 'Remargin Period Days Count',
   MATURITY_BAND_CD     VARCHAR(30)
      LABEL = 'Maturity Band Code',
   RATING_GRADE_BAND_CD VARCHAR(3)
      LABEL = 'Rating Grade Band Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (HAIRCUT_NM,HAIRCUT_SET_ID,RATING_GRADE_BAND_CD,MATURITY_BAND_CD)
);



CREATE TABLE &LIBNAME..HAIRCUT_FX
(
   HAIRCUT_FX_SET_ID    VARCHAR(32)
      LABEL = 'Haircut Set Id',
   EXP_CURRENCY_CD      CHARACTER(3)
      LABEL = 'Exp Currency Code',
   CRM_CURRENCY_CD      CHARACTER(3)
      LABEL = 'Crm Currency Code',
   HAIRCUT_FX_PCT       NUMERIC(8)
      LABEL = 'Haircut Fx Percent',
   MIN_HOLDING_PERIOD_DAYS_CNT NUMERIC(8)
      LABEL = 'Min Holding Period Days Count',
   REMARGIN_PERIOD_DAYS_CNT NUMERIC(8)
      LABEL = 'Remargin Period Days Count',
   CONSTRAINT PRIM_KEY PRIMARY KEY (HAIRCUT_FX_SET_ID,EXP_CURRENCY_CD,CRM_CURRENCY_CD)
);



CREATE TABLE &LIBNAME..HAIRCUT_SET
(
   HAIRCUT_SET_ID       VARCHAR(32)
      LABEL = 'Haircut Set Id',
   HAIRCUT_SET_DESC     VARCHAR(100)
      LABEL = 'Haircut Set Description',
   FX_HAIRCUT_FLG       CHARACTER(1)
      LABEL = 'Fx Haircut Flag',
   ESTIMATION_MODEL_RK  NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Model Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (HAIRCUT_SET_ID)
);



CREATE TABLE &LIBNAME..HEDGING_SET_TYPE
(
   HEDGING_SET_TYPE_CD  VARCHAR(3)
      LABEL = 'HEDGING SET TYPE CODE',
   HEDGING_SET_TYPE_DESC VARCHAR(100)
      LABEL = 'HEDGING SET TYPE DESCRIPTION',
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration ID',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (HEDGING_SET_TYPE_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..HEDGING_SET_TYPE_X_MAT_BAND
(
   HEDGING_SET_TYPE_CD  VARCHAR(3)
      FORMAT = $3.
      INFORMAT = $3.
      LABEL = 'HEDGING SET TYPE CODE',
   MATURITY_BAND_CD     VARCHAR(30)
      FORMAT = $5.
      INFORMAT = $5.
      LABEL = 'Maturity Band Code',
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (HEDGING_SET_TYPE_CD,MATURITY_BAND_CD,CONFIGURATION_ID,LANGUAGE_CD)
);

CREATE TABLE &LIBNAME..LE_CAP_MULT (
     LE_EXCESS_MIN_PCT    NUMERIC(9,4) FORMAT=NLNUM9.4 INFORMAT=NLNUM9.4 label='Large Exposure Excess Minimum',
     LE_EXCESS_MAX_PCT    NUMERIC(9,4) FORMAT=NLNUM9.4 INFORMAT=NLNUM9.4 label='Large Exposure Excess Maximum',
     LE_CAP_MULT_SET_TYPE_CD VARCHAR(32) label='Large Exposure Capital Multiplier Set Type Code',
     LE_CAP_MULTIPLIER_RT NUMERIC(9,4) FORMAT=NLNUM9.4 INFORMAT=NLNUM9.4 label='Large Exposure Capital Multiplier',
     LE_CAP_MULT_SET_ID   VARCHAR(32) label='Large Exposure Factor Set Identifier',
     LANGUAGE_CD          VARCHAR(3) label='Language Code',
     CONSTRAINT PRIM_KEY PRIMARY KEY (LE_EXCESS_MIN_PCT, LE_EXCESS_MAX_PCT,
      LE_CAP_MULT_SET_TYPE_CD, LE_CAP_MULTIPLIER_RT, LE_CAP_MULT_SET_ID, LANGUAGE_CD)
);
CREATE TABLE &LIBNAME..LE_CAP_MULT_SET (
     LE_CAP_MULT_SET_ID   VARCHAR(32) label='Large Exposure Factor Set Identifier',
     LE_CAP_MULT_SET_TYPE_CD VARCHAR(32) label='Large Exposure Capital Multiplier Set Type Code',
     LANGUAGE_CD          VARCHAR(3) label='Language Code',
     LE_CAP_MULT_SET_DESC VARCHAR(100) label='Large Exposure Factor Set Description',
     CONSTRAINT PRIM_KEY PRIMARY KEY (LE_CAP_MULT_SET_ID, LE_CAP_MULT_SET_TYPE_CD, LANGUAGE_CD)
);
CREATE TABLE &LIBNAME..LE_CAP_MULT_SET_TYPE (
     LE_CAP_MULT_SET_TYPE_CD VARCHAR(32) label='Large Exposure Capital Multiplier Set Type Code',
     LANGUAGE_CD          VARCHAR(3) label='Language Code',
     LE_CAP_MULT_SET_DESC VARCHAR(100) label='Large Exposure Factor Set Description',
     CONSTRAINT PRIM_KEY PRIMARY KEY (LE_CAP_MULT_SET_TYPE_CD, LANGUAGE_CD)
);


CREATE TABLE &LIBNAME..MATURITY_BAND
(
   MATURITY_BAND_CD     VARCHAR(30)
      LABEL = 'Maturity Band Code',
   MATURITY_BAND_DESC   VARCHAR(100)
      LABEL = 'Maturity Band Description',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   MATURITY_BAND_YEAR_MIN NUMERIC(6,2)
      FORMAT = NLNUM6.2
      INFORMAT = NLNUM6.2
      LABEL = 'Maturity Band Year Min',
   MATURITY_BAND_YEAR_MAX NUMERIC(6,2)
      FORMAT = NLNUM6.2
      INFORMAT = NLNUM6.2
      LABEL = 'Maturity Band Year Max',
   CONSTRAINT PRIM_KEY PRIMARY KEY (MATURITY_BAND_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..MINIMUM_LGD_IRB_COLLATERAL
(
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD          CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   MINIMUM_COLLATERAL_LEVEL_PCT NUMERIC(8)
      LABEL = 'Minimum Collateral Level Percent',
   OVER_COLLATERAL_LEVEL_PCT NUMERIC(8)
      LABEL = 'Over Collateral Level Percent',
   MINIMUM_LGD_SET_ID   CHARACTER(32)
      LABEL = 'Minimum LGD Set Id',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CRM_TYPE_CD, CRM_SUBTYPE_CD, MINIMUM_LGD_SET_ID,SENIORITY_CD)
);



CREATE TABLE &LIBNAME..RATING_GRADE_BAND
(
   RATING_GRADE_BAND_CD VARCHAR(3)
      LABEL = 'Rating Grade Band Code',
   RATING_GRADE_BAND_DESC VARCHAR(100)
      LABEL = 'Rating Grade Band Description',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   ASSESSMENT_RATING_GRADE_MIN_RK NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Assessment Rating Grade Key',
   ASSESSMENT_RATING_GRADE_MAX_RK NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Assessment Rating Grade Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RATING_GRADE_BAND_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..REGULATORY_LGD
(
   REGULATORY_LGD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory LGD Set Id',
   REGULATORY_LGD_NM    CHARACTER(40)
      LABEL = 'Regulatory LGD Name',
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   REGULATORY_LGD_DESC  CHARACTER(200)
      LABEL = 'Regulatory LGD Description',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_LGD_SET_ID,REGULATORY_LGD_NM)
);



CREATE TABLE &LIBNAME..REGULATORY_LGD_SET
(
   REGULATORY_LGD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory LGD Set Id',
   REGULATOR_ID         CHARACTER(32)
      LABEL = 'Regulator Id',
   REGULATORY_DOC_TXT   CHARACTER(100)
      LABEL = 'Regulatory Document Txt',
   MIN_LGD_IRB_CLLTRL_SET_FLG CHARACTER(1)
      LABEL = 'Min LGD IRB Collateral Set Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_LGD_SET_ID)
);



CREATE TABLE &LIBNAME..REGULATORY_OPTION
(
   REGULATORY_OPTION_NM VARCHAR(40)
      LABEL = 'Regulatory Option Name',
   REGULATORY_OPTION_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Option Set Id',
   OPTION_VALUE         VARCHAR(20)
      LABEL = 'Option Value',
   OPTION_DESC          VARCHAR(200)
      LABEL = 'Option Description',
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_OPTION_SET_ID,REGULATORY_OPTION_NM)
);



CREATE TABLE &LIBNAME..REGULATORY_OPTION_SET
(
   REGULATORY_OPTION_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Option Set Id',
   REGULATOR_ID         VARCHAR(32)
      LABEL = 'Regulator Id',
   REGULATORY_DOC_TXT   VARCHAR(100)
      LABEL = 'Regulatory Document Txt',
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_OPTION_SET_ID)
);



CREATE TABLE &LIBNAME..REGULATORY_PARAMETER
(
   REGULATORY_PARAMETER_NM VARCHAR(40)
      LABEL = 'Regulatory Parameter Name',
   REGULATORY_PARAMETER_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Parameter Set Id',
   PARAMETER_VALUE      NUMERIC(18,5)
      FORMAT = NLNUM18.2
      INFORMAT = NLNUM18.2
      LABEL = 'Parameter Value',
   REGULATORY_PARAMETER_DESC VARCHAR(256)
      LABEL = 'Regulatory Parameter Description',
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   PARAMETER_CURRENCY_CD VARCHAR(3)
      LABEL = 'Parameter Currency Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_PARAMETER_NM,REGULATORY_PARAMETER_SET_ID)
);



CREATE TABLE &LIBNAME..REGULATORY_PARAMETER_SET
(
   REGULATORY_PARAMETER_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Parameter Set Id',
   REGULATOR_ID         VARCHAR(32)
      LABEL = 'Regulator Id',
   REGULATORY_DOC_TXT   VARCHAR(100)
      LABEL = 'Regulatory Document Txt',
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_PARAMETER_SET_ID)
);



CREATE TABLE &LIBNAME..REGULATORY_PD
(
   REGULATORY_PD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Pd Set Id',
   REGULATORY_PD_NM     CHARACTER(32)
      LABEL = 'Regulatory Pd Name',
   PD_PCT               NUMERIC(8)
      LABEL = 'Pd Percent',
   REGULATORY_PD_DESC   CHARACTER(200)
      LABEL = 'Regulatory Pd Description',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_PD_SET_ID,REGULATORY_PD_NM)
);



CREATE TABLE &LIBNAME..REGULATORY_PD_SET
(
   REGULATORY_PD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Pd Set Id',
   REGULATOR_ID         CHARACTER(32)
      LABEL = 'Regulator Id',
   REGULATORY_DOC_TXT   CHARACTER(100)
      LABEL = 'Regulatory Document Txt',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_PD_SET_ID)
);



CREATE TABLE &LIBNAME..REGULATORY_RISK_WEIGHT
(
   REGULATORY_RISK_WEIGHT_NM VARCHAR(40)
      LABEL = 'Regulatory Risk Weight Name',
   REGULATORY_RISK_WEIGHT_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   RISK_WEIGHT_PCT      NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Risk Weight Percent',
   RISK_WEIGHT_DESC     VARCHAR(200)
      LABEL = 'Risk Weight Description',
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_RISK_WEIGHT_SET_ID,REGULATORY_RISK_WEIGHT_NM,APPROACH_TYPE_CD)
);



CREATE TABLE &LIBNAME..REGULATORY_RISK_WEIGHT_SET
(
   REGULATORY_RISK_WEIGHT_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATOR_ID         VARCHAR(32)
      LABEL = 'Regulator Id',
   REGULATORY_DOC_TXT   VARCHAR(100)
      LABEL = 'Regulatory Document Txt',
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_RISK_WEIGHT_SET_ID,APPROACH_TYPE_CD)
);



QUIT;
