/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stored_process_approach.sas
 *
 * PURPOSE: Changes the mapping approach table
 * 
 *                        
 *
 *   NOTES: 
 *   Created: 10/06/05        
 *
 *****************************************************************************/

*ProcessBody;


%rrminit;

%global rundate rundatetime PATHSEP;
options source notes noquotelenmax;

%autoexec_criskm (sysid=&system_id, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=&reg_ctxt,config_set=&config_set);


data _null_;
set RD_MART.rundate;
call symput('RUNDATE', trim(left(datepart(RUNDATETIME))));
call symput('RUNDATETIME', trim(left(RUNDATETIME)));
run;

/*- get user option macros but config_set comes from the stp -*/
data _null_ ;
set RD_ROOT.calculation_options(where=(CONFIG_NAME NE "CONFIG_SET")); 
call execute ('%global ' !! trim(left(CONFIG_NAME)) !! ' ; '  );
run;

data _null_ ;
set RD_ROOT.calculation_options(where=(CONFIG_NAME NE "CONFIG_SET"));
call symput(trim(left(CONFIG_NAME)), trim(left(CONFIG_VALUE)));
if CONFIG_NAME="MAPPING_DATETIME" and CONFIG_VALUE='' then
call symput(trim(left(CONFIG_NAME)), dhms(today(),0,0,time()) );

run;

%macro approachclass;
%local STP_NAME;
%let STP_NAME=Approach type;

%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );


data _null_;
        length OneVar $256;
        n=0;
        line="&_apslist";
            do until (line='');
                OneVar =scan(line,1);
                n+1;
                if length(line) gt length(OneVar) then
                    line=substr(line, length(OneVar)+2);
                else
                    line='';
/*Individual parameter vars */
              call symput ("appvars"||trim(left(put(n,3.))),trim(left(OneVar)));   
            end;
/* Number of parameter vars */
           call symput ("Nappvars",trim(left(put(n,3.))));                       
run;





/* Need to loop through all of the parameters since we can't distinguish
between a asset class and other STP parameter */
/* Change only the parameters that appear in the users rd_map directory */

data rd_map.map_regulatory_approach ;
modify rd_map.map_regulatory_approach (where=((configuration_id="&Config_Set") and 
  (&MAPPING_DATETIME between VALID_FROM_DTTM and VALID_TO_DTTM)));
  %do iii=1 %to &nappvars;
     if (upcase(approach_class)=upcase("&&appvars&iii")) and 
    (upcase(symget("&&&appvars&iii")) ne "DEFAULT") then
      VALID_TO_DTTM=dhms(today(),0,0,time());
  %end;
run;

data work.new_approaches;
set rd_map.map_regulatory_approach (where=((configuration_id="&Config_Set") and 
  (&MAPPING_DATETIME between VALID_FROM_DTTM and VALID_TO_DTTM)));
  format VALID_FROM_DTTM VALID_TO_DTTM NLDATM21.;
  %do iii=1 %to &nappvars;
       if   (upcase(approach_class)=upcase("&&appvars&iii")) and 
      (upcase(symget("&&&appvars&iii")) ne "DEFAULT") then do;
      approach=symget("&&&appvars&iii");
        VALID_FROM_DTTM=dhms(today(),0,0,time());
        VALID_TO_DTTM=dhms('01Jan9999'd,00,00,00);
        output work.new_approaches;
     end;
  %end;
run;


proc append base=rd_map.map_regulatory_approach data=work.new_approaches force;run;
	%if &syserr eq 0 %then %do;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=10% );     
	%end;

%get_regrpt_nls_strings;

	%if &syserr eq 0 %then %do;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=30% );     
	%end;



%stpbegin;
	%if &syserr eq 0 %then %do;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=60% );     
	%end;

data _null_ ;
call symput("MAPPING_DATETIME", dhms(today(),0,0,time()) );
run;

title1 "&Approach &Mapping &Table";
title2 "&Generated: %SYSFUNC(DATE(), EURDFDE9.) at %SYSFUNC(TIME(), TIMEAMPM8.)";


proc print data=rd_map.map_regulatory_approach (where=((configuration_id="&Config_Set") and 
  (&MAPPING_DATETIME between VALID_FROM_DTTM and VALID_TO_DTTM)));
run;

title1 "&Added &entries - &Approach &Mapping &Table";
proc print data=work.new_approaches;run;

	%if &syserr gt 0 %then %do;
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
					  PORTFOLIO_FILTER_ID=&FILTER_ID,
					  LOG_FILE_NAME=%sysget(LOGFILE)   ,
							  STP_STATUS=Failed,STATUS_PCT=0% );

	%end;
	%else %do;
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Complete,STATUS_PCT=100% );   

	%end;

%stpend;





%mend approachclass;

%approachclass;
