/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stored_process_calculate_sensitivities
 *
 * PURPOSE: Generates sensitivities for portfolio in credit risk
 *
 *   USAGE: 
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/



*Processbody;
%rrminit;

/*- these macros are needed for the following projects -*/
%global PROJECT_SET OUTPATH VALPATH; 

options mprint mlogic mprintnest mlogicnest symbolgen;

/*- need to get current result set -*/
%let SENS_PROJECT_SET = %lowcase(&SENSITVITY_PROJECT_NAME);


%macro sensitivity;
%local STP_NAME;
%let STP_NAME=Perform sensitivity analysis;

	
/*- CRISKM Autoexec -*/
/*- Skip if the modelviewer update is running - it already ran -*/
%if %symglobl (_MODELVIEWER) EQ 0 %then %autoexec_criskm (sysid=&SYSTEM_ID, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=&reg_ctxt,config_set=&config_set);

%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );

/*- need to remember user-specified options -*/
%u00_recreate_macro_definitions;
        
/*- need to get result path -*/
    %let OUTPATH = %sysget(CRISKMRES)&pathsep%lowcase(&REGULATORY_PROJECT_SET_NAME);

 proc risk noseqcheck;
  environment open = RD_PROJ.&ENV_NAME  ;

  setoptions nooutall noallprice;

    sensitivity &SENS_PROJECT_SET 
       %if &hessian=YES %then hessian; 
       %if &vega=YES %then vega;
       %if &theta=YES %then theta;
      ;



      project  &SENS_PROJECT_SET
                data        = (Current_Full)
                            portfolio   = All_val
                            currency    = &Report_CCY
                            analysis    = &SENS_PROJECT_SET
                out         = &SENS_PROJECT_SET
                            outpath     = "&OUTPATH"
                          ;

      environment save;
    run;
    
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=20%   );  

       proc risk noseqcheck;
       environment  open        = RD_PROJ.&ENV_NAME ;
      
       runproject   &SENS_PROJECT_SET
                    date         = &rundate
                    data   = (Current_full)
                    options  = (cube=none outall noallprice noallscore nomddbs)
                    ;
       environment save;
    run;


 LIBNAME scens "&OUTPATH&PATHSEP&SENS_PROJECT_SET";
 
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=40%   );  

 proc transpose data=scens.sens out=work.scens_trans;
 run;
 
 data  work.scens_trans
   work.header ;
    set work.scens_trans;
    rename col1=Value;
    rename col2=Delta;
    rename col3=Gamma;
    label value  ="Base value";
    label _name_ ="Risk variable";
    label _label_ ="Description";
    sortdelta=abs(col2);
    if _n_>7 then output work.scens_trans;
    if _n_<=7 then output work.header;
   run;


 proc sort data=work.scens_trans out=work.scens_sorted ;
 by descending sortdelta  ;
  where sortdelta ne 0;
 run;

			%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60%   );  
										  
 data scens.sensitivities (drop=sortdelta);
 set  work.scens_sorted work.header;
 run;


 

   %stpbegin;  

   options obs=&ranking;

      title1 j=c "Results for sensitivity analysis stored process" ;
      title2 j=c "Results are based on data dated: %sysfunc(putn(&RUNDATE, NLDATE.))";
      title3 j=c "This stored process returns a report of the sensitivities of the risk variables";
      title4 j=c "Report Generated on :  %sysfunc(putn(%sysfunc(datetime()), NLDATMAP.))" ;


      proc print data=scens_sorted noobs;
      run;

   %stpend;

   options obs=max;
 				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Complete,STATUS_PCT=100% 
										   );   

    %if &SYSTEM_FATAL_ERROR EQ Y %then %do;
			%error_occured:
		%print_msg (error,1,5);
		%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
										  STP_STATUS=Failed,STATUS_PCT=0%
										 );
    %end;
%mend sensitivity;


%sensitivity;
