/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stored_process_capital_usfinal.sas
 *
 *
 * PURPOSE: This program is a stored procedure running the capital project.
 *
 *   USAGE: 
 *
 *   NOTES: 1. Modified for V4.2
 *          2. 
 *          3. 
 *
 *         
 *         
 *****************************************************************************/


*Processbody;
%rrminit;


%macro runcap_usfinal;

/*---------------------------------------------------------------------------
 * Step 1.
 *
 * Call autoexec for basic setup
 * -------------------------------------------------------------------------*/



%local STP_NAME;
%let STP_NAME=USFinal C Capital calculations;

%getdelimiter;

%autoexec_criskm (sysid=&SYSTEM_ID, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=USFINAL,config_set=&config_set);

%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );

 /*- Check for a copy of the user directories -*/ 
%if &SYSTEM_FATAL_ERROR EQ N %then %do;
/*-Check security for user and request mode -*/


/*---------------------------------------------------------------------------
 * Step 2.
 *
 * Check for existence of data files for user - continue if found
 * -------------------------------------------------------------------------*/
    /*- Check for a copy of the user directories -*/ 

    /*- need to remember user-specified options -*/
    

        %if %symglobl(RUN_STAGE) NE 1 %then %do;
            %let REFRESH = YES;
        %end;

        /*- only run necessary files -*/
        %if &REFRESH NE NO %then %do;
			%batch_criskm_00_init_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=15% );     

			%batch_criskm_10_def_fnc_usfinal;             
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );     

			%batch_criskm_20_prc_dat_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=45% );     

			%batch_criskm_30_crt_tmpl_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% );     

			%batch_criskm_35_run_tb_project;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=70% );     
            

			%batch_criskm_40_mtm_prj_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=85% );     


			%batch_criskm_50_reg_prj_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=95% );     

        %end;

        %else %if &RUN_STAGE = 0 %then %do;
			%batch_criskm_10_def_fnc_usfinal;             
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );     

			%batch_criskm_20_prc_dat_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=45% );     

			%batch_criskm_30_crt_tmpl_usfinal;          
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% );     
            
        %end;

        %else %if &RUN_STAGE = 10 %then %do;
 			%batch_criskm_20_prc_dat_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=45% );     

			%batch_criskm_30_crt_tmpl_usfinal;            
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% );     
            
        %end;

        %else %if &RUN_STAGE = 20 %then %do;
            %batch_criskm_30_crt_tmpl_usfinal;             
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% );     
            
        %end;

        %else %if &RUN_STAGE = 30 %then %do;
        %batch_criskm_35_run_tb_project;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=75% );     
        
        %end;
        
        %else %if &RUN_STAGE = 35 %then %do;
          %batch_criskm_40_mtm_prj_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=85% );     
          
        %end;

        %else %if &RUN_STAGE = 40 %then %do;
             %batch_criskm_50_reg_prj_usfinal;
            %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=95% );     
             
        %end;
        
         %batch_criskm_60_cap_prj_usfinal;
  	   	 %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Complete,STATUS_PCT=100%,UPDATE_DTTM_FLG=Y  );
        /*Creating the Result Views*/                                          
        %criskm_create_result_views; 
										  
										  
       
        options noovp noquotelenmax nocardimage;
        
    %end; %else
    %if &SYSTEM_FATAL_ERROR EQ Y %then %do;
		%error_occured:
		%print_msg (error,1,5);
		%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
										  STP_STATUS=Failed,STATUS_PCT=0%, UPDATE_DTTM_FLG=Y );
    %end;
  

%mend runcap_usfinal;

%runcap_usfinal;
