


/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stored_process_val_crd4.sas
 *
 *
 * PURPOSE: This program is a stored procedure for credit risk - runs MtM.
 *
 *   USAGE: 
 *
 *   NOTES: 1. This assumes the user had run in user mode.
 *          2. This assumes the user has run WRS to establish folders.
 *          3. Assumes OMR Settings are set for given host.
 *
 *         
 *****************************************************************************/
 
/*- user specified parameters -*/

*Processbody;  
%rrminit;

%macro runmtm_crd4;
%local STP_NAME;
%let STP_NAME=A Valuation project;
%getdelimiter;

%autoexec_criskm (sysid=&SYSTEM_ID, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=crd4 , config_set=&config_set);
%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );

/*- Check for a copy of the user directories -*/ 
    %if &SYSTEM_FATAL_ERROR EQ N %then %do;
/*-Check security for user and request mode -*/


        %if %symglobl(RUN_STAGE) NE 1 %then %do;
            %let REFRESH = YES;
        %end;

        /*- only run necessary files -*/
        %if &REFRESH NE NO %then %do;
		 	%if &syserr eq 0 %then %do;
            %batch_criskm_00_init_crd4;  
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=20% 
										  );     
			%end;
 		 	%if &syserr eq 0 %then %do;
            %batch_criskm_10_def_fnc_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=40% /* ,
										   config_set=&config_set.*/);   
			%end; 
			%if &syserr eq 0 %then %do;
            %batch_criskm_20_prc_data_crd4;  
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% 
										   );  
			%end;
			%if &syserr eq 0 %then %do;
            %batch_criskm_30_crt_tmpl_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=80% 
										  );  
        	%end;
			%if &syserr eq 0 %then %do;
            %batch_criskm_35_run_tb_project; 
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=85% );     

        	%end;
		%end;	
        %else %if &RUN_STAGE = 0 %then %do;
		
            %batch_criskm_10_def_fnc_crd4;     
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=40% 
										 ); 
            %batch_criskm_20_prc_data_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% 
										  );	
            %batch_criskm_30_crt_tmpl_crd4; 
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=80% 
										   ); 
            %batch_criskm_35_run_tb_project; 
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=85% );     
										   
        %end;

        %else %if &RUN_STAGE = 10 %then %do;
            %batch_criskm_20_prc_data_crd4;    
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% 
										   ); 
            %batch_criskm_30_crt_tmpl_crd4;        
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=80% 
										  ); 
            %batch_criskm_35_run_tb_project; 
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=85% );     
        %end;

        %else %if &RUN_STAGE = 20 %then %do;
            %batch_criskm_30_crt_tmpl_crd4;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=80% 
										   ); 
            %batch_criskm_35_run_tb_project; 
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=85% );     
        %end;

 
        %batch_criskm_40_mtm_prj_crd4;
 				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Complete,STATUS_PCT=100% 
										   );   
		        /*Creating the Result Views*/                                          
        %criskm_create_result_views;

        options noovp noquotelenmax nocardimage;

    %end; %else
    %if &SYSTEM_FATAL_ERROR EQ Y %then %do;
	%error_occured:
		%print_msg (error,1,5);
		%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
										  STP_STATUS=Failed,STATUS_PCT=0%
										 );
    %end;
	

%mend runmtm_crd4;

%runmtm_crd4;
