/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME:stp02_stored_process_scensim_imv.sas
 *
 * PURPOSE: Creates scenario simulation data for applet
 *
 *   USAGE:
 *
 *   NOTES:
 *
 *
 *****************************************************************************/

*Processbody;

%rrminit;
%global USERNAME REPORT_CCY REFRESH RF1 RF2 RF3 RF4 RF1_STRESS RF2_STRESS RF3_STRESS RF4_STRESS REPS;

options notes;

%getdelimiter;
/* Run the correct autoexec for each user */
%autoexec_criskm (sysid=&SYSTEM_ID, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=&reg_ctxt);

/* Have to read various global settings */
/* Read from xxx_options datasets */
%a00_init_options ;
/* Read REPORT_CCY from config sets */
data _null_;
set RD_CONF.configuration;      
    /*- currency -*/
    call symput("REPORT_CCY", CURRENCY);
run;

/*- these macro vars are needed for the following projects - if you change these you may 
break the Java side!!!*/
%global compressed_scenarioname PROJECT_SET OUTPATH IMVPATH;
/*
Find RD_ISA path
*/
data _NULL_;
    length path $4096;
    path = pathname("RD_ISA");
    call symput( "RD_ISA_path", trim(path) );
    comp_scen_name =  compress("&scenarioname_imv");
    fixed_scen_name = translate(comp_scen_name,'_','.');
    call symput( "compressed_scenarioname", fixed_scen_name);
run;
/*Have to make sure reps is not too big*/
%let REPS = 6;
/*- need to get current result set -*/
%let PROJECT_SET = &compressed_scenarioname;
/*- need to get result path -*/
%let OUTPATH = &RD_ISA_path.&pathsep.&PROJECT_SET;
/*- next project needs to know previous output path -*/
%let IMVPATH = &OUTPATH.&pathsep.imvproj;
%print_msg(note,2,283);
%print_msg(note,2,284);
%print_msg(note,2,285);

%macro scensim_imv;

    %local num_rf PORTEXISTS;

    /*
    Check that Mark-to-Market has been run by checking for portfolio file
    */
    
    data _NULL_;
        length path $4096;
        path = pathname("RD_TEMP");
        call symput( "RD_TEMP_path", trim(path) );
    run;
    %print_msg(note,2,287);
    %if (%sysfunc(cexist(RD_TEMP.&RD_TEMPLATE))) EQ 1 %then %do;
        %print_msg(note,2,288);
        proc catalog catalog=RD_TEMP.&RD_TEMPLATE;
            contents out=&RD_TEMPLATE._contents;
        run;quit;
        data portfolios(keep=name desc rename=(name=portfolios));
            set &RD_TEMPLATE._contents (where=(type="RISK7" and name eq 'ALL_VAL'));
            %print_msg(note,2,289);
            call symput ("PORTEXISTS","YES");
        run;
    %end;

    %if  ( (%symlocal(PORTEXISTS) eq 1) 
            AND ("&PORTEXISTS" eq "YES")  
            AND ((%dsexist(rd_mkt.mkt_current)) eq 1) ) %then %do;    
            
        /* replaced with call to a00_init_options above - %recreate_macros; */

        /*Process user inputs*/
        data _null_;
            tempCount = 0;
            %do ii = 1 %to 4;
                length temp&ii $128 msg $256;
                temp&ii = trim(left("&&rf&ii"));
                msg = "";
                /*Check for blank*/
                if temp&ii eq "" then do;
                    /*%put assigning dummy value to blank input risk factor &ii;*/
                    temp&ii = "dummy_rf&ii";
                    msg = "assigning dummy value to blank input risk factor";
                    put msg= temp&ii.=;
                end;
                /*Check for duplicates*/
                %do kk = 1 %to (&ii - 1);
                    /*%put checking for duplicates for risk factor &ii;*/
                    if temp&kk eq "&&rf&ii" then do;
                        /*%put assigning dummy value to duplicate input risk factor &ii;*/
                        temp&ii = "dummy_rf&ii";
                        msg = "assigning dummy value to duplicate input risk factor";
                        put msg= temp&ii.=;
                    end;
                %end;
                %print_msg(note,2,290);
                tempCount = tempCount + 1;
                call symput("in_rf_"||trim(left(tempCount)),trim(left(temp&ii)));
            %end;
            call symput("num_rf",tempCount);
        run;
        data _null_;
            %print_msg(note,2,291);
            %do ii = 1 %to &num_rf;
                %print_msg(note,2,292);
            %end;
        run;


        data work.curmarket (keep=&in_rf_1 &in_rf_2 &in_rf_3 &in_rf_4);
        set rd_mkt.mkt_current;
        run;

        data work.inmarket;
        set work.curmarket;
  
            array rfs (4) &in_rf_1 &in_rf_2 &in_rf_3 &in_rf_4;
            array rf_current_vals (4) &in_rf_1._current_val &in_rf_2._current_val 
                &in_rf_3._current_val &in_rf_4._current_val;
            array rf_stress_vars (4) &in_rf_1._stress_var &in_rf_2._stress_var 
                &in_rf_3._stress_var &in_rf_4._stress_var;
            array cell_indices (4) cell_index1 cell_index2 cell_index3 cell_index4;

            do i1 = 1 to 4;
                rf_current_vals(i1) = rfs(i1);
                cell_indices(i1) = 0;
            end;

            %do ii=1 %to 4;
                rf_stress_vars(&ii) = &&rf&ii._stress;
            %end;
            
            %do k = 1 %to 4;
                do cell_index&k = 0 to (&reps - 1);
            %end;
                    do i2 = 1 to 4;
                        rfs(i2) = rf_current_vals(i2) *
                            (1 + 
                                (cell_indices(i2) * rf_stress_vars(i2) * 0.01 / (&reps-1))
                              );
                    end;
                    output;
            %do k = 1 %to 4;
                end;
            %end;
         
        run;


        data work.scenario_isa_inputs (keep=&in_rf_1 &in_rf_2 &in_rf_3 &in_rf_4);
        set work.inmarket;
        run;

        proc risk noseqcheck;
            environment open = RD_PROJ.&ENV_NAME inherit=(RD_TEMP.&RD_TEMPLATE);

            marketdata Scenario_Data
            file  = work.scenario_isa_inputs
            type  = scenarios
            label = "Data for scenario inputs";

            simulation &compressed_scenarioname
            method = scenario
            data=scenario_data
            stress=1;

            project imvproj
            data         =  (Current_Full Scenario_Data)
            portfolio    = All_Val
            currency     = &Report_CCY
            analysis     = &compressed_scenarioname
            outpath         = "&OUTPATH"
            out             = imvproj
                                  ;
            environment save;
        run;

        proc risk noseqcheck;
            environment open = RD_PROJ.&ENV_NAME ;
            runproject imvproj
                 date         = &rundate
                 data         = (Current_full Scenario_data)
                 options      = (simstats simstates simvalues)
                          ;
            environment save;
        run;

        /** Begin post-processing for the applet **/
        libname scenario "&OUTPATH.&pathsep.imvproj";

        data scenario.orig_rf;
            &in_rf_1 = .;
            &in_rf_2 = .;
            &in_rf_3 = .;
            &in_rf_4 = .;
        run;
        data scenario.repair_simstate;
            set scenario.simstate scenario.orig_rf;
            if &in_rf_1 = . and &in_rf_2 = . and &in_rf_3 = . and &in_rf_4 = . then delete;
        run; 

        data work.scen;
        merge scenario.simvalue (keep=SimulationReplication value pl return)  
        scenario.repair_simstate (keep= &in_rf_1 &in_rf_2 &in_rf_3 &in_rf_4 SimulationReplication);
        by SimulationReplication;
        run;

        /*Risk produces duplicate rows if risk factors are dropped - remove.
        */
        
        %macro get_ordering();
            data _null_;
                %do ii = 1 %to 4;
                    %if &&rf&ii._stress gt 0 %then %do;
                        call symput("in_rf_order_"||trim(left("&ii")),trim(left("")));
                    %end;
                    %else %do;
                        call symput("in_rf_order_"||trim(left("&ii")),trim(left("descending")));
                    %end;
                %end;
            run;
        %mend;
        %get_ordering();

        proc sort data=work.scen out=work.scen_nodup nodupkey;
            by &in_rf_order_1 &in_rf_1 &in_rf_order_2 &in_rf_2 
                &in_rf_order_3 &in_rf_3 &in_rf_order_4 &in_rf_4;
        run;
        
        data label_header ;
        set work.scen_nodup ;
        if _n_=0 then output;
        run;

        proc transpose data=work.label_header(keep=&in_rf_1 &in_rf_2 &in_rf_3 &in_rf_4
                 value pl return) out=work.labels;
            var &in_rf_1 &in_rf_2 &in_rf_3 &in_rf_4  value pl return;
        run;

        data work.labels (keep=_label_ _name_ var_name skip_rf granularity);
        set work.labels;
            length skip_rf $5 var_name $5;
            label _label_="_LABEL_";
            if _n_ <=4 then do;
                var_name=compress('IN'||_n_);
                if "dummy_rf" eq substr(_name_,1,8) then do;
                    skip_rf = "true";
                end;
                else if trim(left(_label_)) eq "" then do;
                    skip_rf = "true";
                end;
                else do;
                    skip_rf = "false";
                end;
                granularity = &reps;
            end;
            else if _n_>4 then do;
                var_name=compress('OUT'||_n_-4);
            end;
        run;

        proc means noprint data=work.scen_nodup;
            var value pl return;
            output out = work.outvar_minmax;
        run;

        data work.outvar_minmax (keep= _STAT_ value pl return);
            set work.outvar_minmax;
            if _STAT_ eq "MIN" or _STAT_ eq "MAX";
        run;

        proc transpose data=work.outvar_minmax out=work.outvar_minmax_trans;
            id _STAT_;
        run;

        proc sort data=work.outvar_minmax_trans;
            by _name_;
        run;
        proc sort data=work.labels;
            by _name_;
        run;
        data work.var_metadata;
            merge work.labels work.outvar_minmax_trans;
            by _name_;
        run;

        /*Go back to original var_name order - Java expects this.*/
        proc sort data=work.var_metadata;
            by var_name;
        run;
        
        data work.isv_applet_input (keep=in1 in2 in3 in4 out1 out2 out3);
        set work.scen_nodup;
        rename &in_rf_1=IN1;
        rename &in_rf_2=IN2;
        rename &in_rf_3=IN3;
        rename &in_rf_4=IN4;
        rename value=OUT1;
        rename pl=OUT2;
        rename return=OUT3;
        label &in_rf_1="IN1";
        label &in_rf_2="IN2";
        label &in_rf_3="IN3";
        label &in_rf_4="IN4";
        label value="OUT1";
        label pl="OUT2";
        label return="OUT3";
        run;

        data scenario.isa_inputdata_applet;
            merge work.isv_applet_input work.var_metadata;
            format out3 nlpct16.2;
        run;

        %if %symglobl(_criskm_outputLoc) eq 0 %then %do;
            %global _criskm_outputLoc;
        %end;
        data _NULL_;
            call symput( "_criskm_outputLoc", '/jsp/isa_applet.jsp?task_key=Analysis&menu_key=Model_Viewer' );
        run;

        /*
            format in1-in4 out1 out2 out3 nlnum20.;
        */
    %end;
    %else %do;
        %print_msg(ERROR,2,293);
        %print_msg(ERROR,2,294);
    %end;
%mend;

%clean_dir(&OUTPATH.&pathsep.imvproj);
%scensim_imv;
