/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stp05_stored_process_fxstress.sas
 *
 *
 * PURPOSE: This program is a stored procedure for credit risk - runs FX stress.
 *
 *   USAGE: 
 *
 *   NOTES: 1. EXAMPLE only!
 *          2. This assumes the user had run in user mode.
 *          3. This assumes the user has run WRS to establish folders.
 *          4. Assumes OMR Settings are set for given host.
 *
 *         
 *         
 *****************************************************************************/
 
 
*Processbody;   /* Needed to initialize parameters if using workspace server rather than stp server */
%rrminit;
%global MITIGANTS_ALLOCATION_METHOD;


%autoexec_criskm (sysid=&SYSTEM_ID, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=&reg_ctxt,config_set=&config_set);
%macro runfxstress;
%local STP_NAME;
%let STP_NAME=FX stress test;

%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );

    %let MITIGANTS_ALLOCATION_METHOD=&MITIGANTS_ALLOCATION_BASE_PRJ;

    /*- define macros from a data set -*/
    %recreate_macros;

     /*- need to remember user-specified options -*/
    %u00_save_macro_definitions;


    %if %symglobl(RUN_STAGE) NE 1 %then %do;
        %let REFRESH = YES;
    %end;

    /*- only run necessary files -*/
    %if &REFRESH NE NO %then %do;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_00_initialize;
				%end;	
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_10_define_functions;             
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=10% );     
				%end;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_20_process_data;             
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=20% );     
				%end;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_30_create_template;         
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% ); 
				%end;						  
	 		 	%if &syserr eq 0 %then %do;
					%e00_create_project_environment;
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=35% );     
				%end;
    %end;

    %else %if &RUN_STAGE = 0 %then %do;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_10_define_functions;
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=10% );     
				%end;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_20_process_data;             
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=20% );
				%end;						  
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_30_create_template;             
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );
				%end;
    %end;

    %else %if &RUN_STAGE = 10 %then %do;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_20_process_data;             
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=20% );     
				%end;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_30_create_template;             
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );     
				%end;						  
    %end;

    %else %if &RUN_STAGE = 20 %then %do;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_30_create_template;             
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=30% );
				%end;
    %end;

    %else %if &RUN_STAGE = 30 %then %do;
	 		 	%if &syserr eq 0 %then %do;
					%e00_create_project_environment;
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=35% );     
				%end;
    %end;

    %else %do;

    %end;

	 		 	%if &syserr eq 0 %then %do;
					%batch_crisk_40_run_fx_stres_proj;
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=40% );     
				%end;
	 		 	%if &syserr eq 0 %then %do;
					%batch_crisk_50_run_reg_proj;
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=50% );     
				%end;
	 		 	%if &syserr eq 0 %then %do;
					%batch_criskm_60_run_cap_proj;
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=60% );     
				%end;
    %SYMDEL _FXSTRESSRPT;
	 		 	%if &syserr eq 0 %then %do;
					%u00_save_macro_definitions;
					%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=100% );     
				%end;
	%if &syserr gt 0 %then %do;
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
					  PORTFOLIO_FILTER_ID=&FILTER_ID,
					  LOG_FILE_NAME=%sysget(LOGFILE)   ,
							  STP_STATUS=Failed,STATUS_PCT=0% );

	%end;
	%else %do;
	 				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Complete,STATUS_PCT=100% );   

	%end;
 
%mend runfxstress;

%runfxstress;
