/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stp06_stored_proc_pdstress_crd4.sas
 *
 *
 * PURPOSE: This program is a stored procedure for credit risk - runs PD stress.
 *
 *   USAGE: 
 *
 *   NOTES: 1. EXAMPLE only!
 *          2. This assumes the user had run in user mode.
 *          3. This assumes the user has run WRS to establish folders.
 *          4. Assumes OMR Settings are set for given host.
 *   MODIFIED
 *          V4.1 hot fix release 07/05/05     
 *         
 *****************************************************************************/


/*- user specified parameters -*/
*Processbody;
%rrminit;

%autoexec_criskm (sysid=&SYSTEM_ID, usrtype=&usertype, usrname=&_SCANNED_USERNAME,reg_ctxt=&reg_ctxt,config_set=&config_set);
%macro runpdstress;
%local STP_NAME;
%let STP_NAME=PD stress test;

%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );

    /*- define macros from a data set -*/
    %recreate_macros;

    /*- need to remember user-specified options -*/
    %u00_save_macro_definitions;
    
    %if %symglobl(RUN_STAGE) NE 1 %then %do;
        %let REFRESH = YES;
    %end;

    /*- only run necessary files -*/
    %if &REFRESH NE NO %then %do;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_00_init_crd4;     
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=00% );     
			%end;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_10_def_fnc_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=10% );     
				
			%end;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_20_prc_data_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=20% );     
			%end;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_30_crt_tmpl_crd4; 
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=30% );     
			%end;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_35_run_tb_project;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=35% );     
			%end;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_40_mtm_prj_crd4;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=40% );     
			%end;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_50_reg_prj_crd4; 
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=50% );     
			%end;
    %end;

    %else %if &RUN_STAGE = 0 %then %do;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_10_def_fnc_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=10% );     
			%end;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_20_prc_data_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=20% );     
			%end;
	 		%if &syserr eq 0 %then %do;
				%batch_criskm_30_crt_tmpl_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=30% );     
			%end;
    %end;

    %else %if &RUN_STAGE = 10 %then %do;
			%if &syserr eq 0 %then %do;
				%batch_criskm_20_prc_data_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=20% );     
			%end;
	 		%if &syserr eq 0 %then %do;
				%batch_criskm_30_crt_tmpl_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=30% );     
			%end;
    %end;

    %else %if &RUN_STAGE = 20 %then %do;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_30_crt_tmpl_crd4;             
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=20% );     
			%end;
    %end;

    %else %if &RUN_STAGE = 30 %then %do;
 		 	%if &syserr eq 0 %then %do;
				%batch_criskm_35_run_tb_project;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=35% );     
			%end;
    %end;

    %else %if &RUN_STAGE = 35 %then %do;
		 	%if &syserr eq 0 %then %do;
				%batch_criskm_40_mtm_prj_crd4;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=40% );     
			%end;
    %end;

    /*- assume MtM project has been run -*/
    %else %do;

    %end;

	 	%if &syserr eq 0 %then %do;
			/*%batch_criskm_50_reg_prj_crd4;*/
			%batch_crisk_50_run_pd_stres_crd4;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=50% );     
		%end;
	 	%if &syserr eq 0 %then %do;
			%batch_criskm_60_cap_proj_crd4;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=60% );     
		%end;

/*- TEMP FLAG TO TRIGGER PD STRESS REPORTING -*/
    %SYMDEL _PDSTRESSRPT;
    /*- need to remember user-specified options -*/
	 	%if &syserr eq 0 %then %do;
			%u00_save_macro_definitions;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Progress,STATUS_PCT=100% );     
		%end;
  
	%if &syserr gt 0 %then %do;
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
					  PORTFOLIO_FILTER_ID=&FILTER_ID,
					  LOG_FILE_NAME=%sysget(LOGFILE)   ,
							  STP_STATUS=Failed,STATUS_PCT=0% );

	%end;
	%else %do;
			%criskm_update_stp_status(STP_NAME=&STP_NAME,
						  STP_STATUS=Complete,STATUS_PCT=100% );   

	%end;
%mend runpdstress;

%runpdstress;
