/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a05_define_irb_collateral_fmt.sas
 *
 * PURPOSE: Creates formats for min LGD and collateralization mapping.
 *
 *   USAGE: 
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro a05_define_irb_collateral_fmt;


/*- format for seniority code -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $16. LABEL $8. TYPE HLO $1.;
set RD_CONF.map_seniority end=lastobs;
FMTNAME = 'MAP_SENIORITY_TYPE';
START   = SENIORITY_CD;
END     = START;
if SENIORITY_FLG = 1 then LABEL='SEN';
else LABEL='SUB';
TYPE = 'C';
output;
if lastobs then do;
    START = '**OTHER**';
    END   = START;
    HLO   = 'O';
    LABEL = '';
    output;
end;
run;

proc format cntlin=fmt lib=RD_ENV;run;


/*- format for seniority flag -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $16. LABEL 8. TYPE HLO $1.;
set RD_CONF.map_seniority end=lastobs;
FMTNAME = 'MAP_SENIORITY_FLG';
START   = SENIORITY_CD;
END     = START;
LABEL = SENIORITY_FLG;
TYPE = 'C';
output;
if lastobs then do;
    START = '**OTHER**';
    END   = START;
    HLO   = 'O';
    LABEL = .;
    output;
end;
run;

proc format cntlin=fmt lib=RD_ENV;run;


/*- format for min LGD bucket mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $16. LABEL $8. TYPE HLO $1.;
set RD_CONF.map_min_lgd_irb_coll end=lastobs;
FMTNAME          = 'MAP_MIN_LGD_BUCKET_IRB_COLL' ;
START            = compress(put(SENIORITY_CD, $MAP_SENIORITY_TYPE.) || CRM_TYPE_CD || CRM_SUBTYPE_CD) ; 
END              = START;
LABEL            = MIN_LGD_BUCKET;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO='O' ;
    LABEL='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

Data RD_CONF.map_min_level_irb_coll ;
Set  RD_CONF.map_min_level_irb_coll ;
Where SENIORITY_CD = "&SENIORITY_CD" ;
Run ;

/*- format for min collateralization level bucket mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $16. LABEL $8. TYPE HLO $1.;
set RD_CONF.map_min_level_irb_coll end=lastobs;
FMTNAME          = 'MAP_MIN_LEVEL_BUCKET_IRB_COLL' ;
START            = compress(CRM_TYPE_CD || CRM_SUBTYPE_CD) ; 
END              = START;
LABEL            = MIN_COLL_LEVEL_BUCKET;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO='O' ;
    LABEL='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


Data RD_CONF.map_over_level_irb_coll;
Set  RD_CONF.map_over_level_irb_coll;
Where SENIORITY_CD = "&SENIORITY_CD";
Run ;

/*- format for over collateralization level bucket mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $16. LABEL $8. TYPE HLO $1.;
set RD_CONF.map_over_level_irb_coll end=lastobs;
FMTNAME          = 'MAP_OVER_LEVEL_BUCKET_IRB_COLL' ;
START            = compress(CRM_TYPE_CD || CRM_SUBTYPE_CD) ; 
END              = START;
LABEL            = OVER_COLL_LEVEL_BUCKET;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO='O' ;
    LABEL='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;
%mend a05_define_irb_collateral_fmt;
