/*****************************************************************************
 *    NAME: autoexec_criskm
 *
 * PURPOSE: defines environment variables and libraries for CRiskM
 *
 *   USAGE: 
 *
 *   NOTES: 1. This is the entry point for CRiskM. 
 *           
 *          2. Sets up environment variables and libraries.
 *
 *   Modified for V41 12/17/04
		   V46 03/06/09 -- I18N code is added
 *             05/12/09 -- code for retrieving CMHOME, CMUSER, CMINDATA and RRRHOME is added 
 *			   06/01/09	-- CHECK FOR SETINIT IN BACKEND CODE ADDED
 *             21/07/09 -- code for retrieving webdav_host, webdav_port, webdav_basepath is added 
 *****************************************************************************/

%macro autoexec_criskm (sysid=main, usrtype=master, usrname=, recreate_log=YES,config_set=,reg_ctxt=);
*options mprint mlogic mprintnest mlogicnest symbolgen;

%global system_id usertype username authenticate PATHSEP SYSTEM_FATAL_ERROR OMRSETTING
    criskm_stpserver original_username error warning note webdav_host webdav_port webdav_basepath CONFIG_UCMACRO_PATH reg_context;
%let system_id=%lowcase(&sysid);
%let usertype=%lowcase(&usrtype);
%let config_set=%lowcase(&config_set);
%let reg_context=%lowcase(&reg_ctxt);
%let CMHOME=;
%let CMAPP=;
%let CMUSER=;
%let CMINDATA=;
%let RRRHOME=;
%let original_username=%lowcase(&usrname);
%let username=%lowcase(&usrname);
%let ucmacros_path=;


/*Test for LDAP ID's and remove, e.g., '@sas.com' from the end*/
data _NULL_;
    at_sym_index = index("&original_username","@");
    host_index   = index("&original_username","\"); 
    if at_sym_index gt 1 then call symput( "username", substr("&original_username",1,at_sym_index-1) );
    if host_index gt 1 then call symput( "username", substr("&original_username",host_index+1) );
run;

%put system_id=&system_id..;
%put usertype=&usertype..;
%put username=&username..;
%put original_username=&original_username..;


/*- 5: set up error checking -*/

%let SYSTEM_FATAL_ERROR = Y;
%let OMRSETTING=YES;

 
%getdelimiter;

/* NF: Multi configuration- Initialise configuration specific path for ucmacros*/


%if %upcase(config_set)="BASEL" %then
%let curr_config_id=COMMON;
%else %do;
%let curr_config_id=&reg_ctxt;
%end;
%let curr_config_id=%lowcase(&curr_config_id);
%criskm_get_swc_property(propertyName=criskmmvac.ucmacros.config.path, q_rd_swc=&RD_SWC ,outvar=ucmacros_path);
   %let AUTOLIST = %sysfunc(compress(%sysfunc(getoption(sasautos)),%str(%(%))));
   %let CONFIG_UCMACRO_PATH = &ucmacros_path&pathsep&curr_config_id;
   options sasautos = ("&CONFIG_UCMACRO_PATH" &AUTOLIST);
   *options sasautos = ("&CONFIG_UCMACRO_PATH");

%macro check_macro;

%let macrofound=NO;

   /*- Test for existence of PATHSEP -*/
   %if %symexist(PATHSEP) %then %do ; 
      %if ("&PATHSEP" ne "") %then %let macroname=&PATHSEP ; 
   %end ; 

%if %symexist(macroname) = 0 or &macroname= %then %do;
    %put "ERROR: Regulatory Risk macro library doesn't exist.";
    %let SYSTEM_FATAL_ERROR = Y;
    %end;
%else %do;
    %let macrofound=YES;
    %let SYSTEM_FATAL_ERROR=N;
    %end; 

%mend check_macro;

%check_macro;

/* code to check if product is licensed-- begin*/

data _null_;
   length rc 8;
   rc = sysprod("PRODNUM159");
   put rc=;
   if rc EQ 1 then 
   do;
   put "Product is licensed";
   call symput("SYSTEM_FATAL_ERROR", "N");
   end;
   else do;
   	put "ERROR: There is no license for Regulatory Risk Management.";
	call symput("SYSTEM_FATAL_ERROR", "Y");
   end;
run;

%if &SYSTEM_FATAL_ERROR=Y %then %goto EXIT;

/* code to check if product is licensed-- end*/

/*retrieve property values from software component */
%criskm_get_swc_property(propertyName=criskmmva.CMHOME,q_rd_swc=&RD_SWC,outvar=CMHOME);
%criskm_get_swc_property(propertyName=criskmmva.CMAPP,q_rd_swc=&RD_SWC,outvar=CMAPP);
%criskm_get_swc_property(propertyName=criskmmva.CMUSER,q_rd_swc=&RD_SWC,outvar=CMUSER);
%criskm_get_swc_property(propertyName=criskmmva.CMINDATA,q_rd_swc=&RD_SWC,outvar=CMINDATA);
%criskm_get_swc_property(propertyName=criskmmva.RRRHOME,q_rd_swc=&RD_SWC,outvar=RRRHOME);

  options set = CMHOME "&CMHOME";
  options set = CMINDATA "&CMINDATA";
  options set = CMUSER "&CMUSER";
  options set = RRRHOME "&RRRHOME";
  options set = CMAPP "&CMAPP";
/*  options set = LEVCONFIG "&LEVCONFIG";*/




/*code for retrieving webdav related information from metadata-- begin*/
filename str1 temp;
data _null_;
length stname1 $ 10000;
stname1="";
trc=metadata_getattr("omsobj:TextStore?Textstore[@Name='Public Configuration Properties'][Objects/SoftwareComponent[@Name='Web Infrastructure Platform 9.4']]","StoredText",stname1);
file str1;
i = 1;
  length text $ 10000;  
  text = scan(stname1, i, "0a"x);
  do while( text ne " ");
	put text;
    i+ 1;
    text = scan(stname1, i, "0a"x);
  end;
run;

data _null_;
infile str1 ;
input ;
filename newstr1 temp;
file newstr1;
_INFILE_=tranwrd(_INFILE_,"\\","\");
put _INFILE_;
run;

data _null_;
infile newstr1;
 input;
  v0=index(_INFILE_,'iomsrv.httpserver.host=');
  if v0=1 then do;
  webdav_host=scan(_INFILE_,-1,"=");
  call symput ("webdav_host",trim(webdav_host));
  end;
  v0=index(_INFILE_,'iomsrv.httpserver.port=');
  if v0=1 then do;
  webdav_port=scan(_INFILE_,-1,"=");
  call symput ("webdav_port",trim(webdav_port));
  end;
  v0=index(_INFILE_,'iomsrv.httpserver.basepath.dir=');
  if v0=1 then do;
  webdav_basepath=scan(_INFILE_,-1,"=");
  if substr(webdav_basepath,1,1)='/' then 
  webdav_basepath=substr(webdav_basepath,2,length(webdav_basepath)-1);
  call symput ("webdav_basepath",trim(webdav_basepath));
  end;

run;
/*code for retrieving webdav related information from metadata-- end*/


%if &SYSTEM_FATAL_ERROR=Y %then %goto EXIT;

options replace notes source source2 ;

/**************************************************
 *   Set up environment variables and libraries
 **************************************************/
 /*- 2: set up environment variables and libraries -*/
/*- Define master root environment variable -*/

/* Options for the datamart and username */
/* These need to be set if running in batch mode independent of credit risk studio*/
/* Setting datamart to 'YES' AND Master to 'MASTER' will run the load reporting datamart jobs and update graphics,reports */
/* %let Master=MASTER;*/
/* %let datamart=YES;*/

/*- Define group root environment variable                                      -*/
/*- USE CAUTION WHEN MODIFYING THE USER ROOT DEFINITION                         -*/
/*- If you want to change the location of the user project directories,         -*/
/*- change !CMUSER above for a new root location        -*/
/*- Do not change the spacing or format of line                                 -*/

options set = CMGROUP "%sysget(CMUSER)&pathsep.groups&pathsep.&system_id";

%if %upcase(&usertype)=MASTER %then 
  options set = CRISKMUSER "%sysget(CMGROUP)&pathsep.&usertype";
%else
  options set = CRISKMUSER "%sysget(CMGROUP)&pathsep.&usertype&pathsep.&username";


options SET = CMLOGS "%sysget(CRISKMUSER)&pathsep.logs";
libname RD_LOGS  "!CMLOGS";

/*if executing stored process, do stored process initialization*/

/* The Stored Process Server creates environment variables that are not 
   created in a standard MVA session. Using the parameter _RESULT as a 
   test to determine the server mode. Global macro var criskm_stpserver 
   is set to Y (STP Server) or N (Batch) */
%let criskm_stpserver=;
%if %symglobl(_RESULT) = 1 %then %do;
  %let criskm_stpserver = Y;
%end;
%else %do;
  %let criskm_stpserver = N;
%end;


/*- I18N -*/

/*  %let CRMS_locale=en_US;*/
/*  option locale=&CRMS_locale;*/
   
  %let error=%sysfunc(sasmsg(sashelp.msg_types,ERROR, noquote));
  %let warning=%sysfunc(sasmsg(sashelp.msg_types,WARNING, noquote));
  %let note=%sysfunc(sasmsg(sashelp.msg_types,NOTE, noquote));

/*- end I18N -*/
    


/*- language files -*/
libname RD_NLS "%sysget(CMHOME)&pathsep.nls";
/*libname RD_NLS  "!CRISKMUSER&pathsep.env&pathsep.templates";*/

/*- Library for user configuation -*/
/* NOTE: In the case that the autoexec_criskm is called multiple times   */
/* (e.g. in the case of CRM allocation across entities) the ods path has */ 
/*  to be reset, for the RD_ROOT library to be defined succesfully.      */

ods path reset; 
libname RD_ROOT "%sysget(CRISKMUSER)";

/*- check nls library -*/
				  %if %check_lib(rd_nls) = 0 %then %do;
					  %let system_fatal_error = Y;
			      %end;
					   


%if &criskm_stpserver = Y %then %do;
    %if &SYSTEM_FATAL_ERROR=Y %then %return;
    %if %symglobl(log_file_name_prefix) eq 0 %then %do;
        %global log_file_name_prefix;
        %let log_file_name_prefix=;
    %end;

    %local user_id;
    %if %trim(%left("&username")) eq "" %then %do;
        %if %symglobl(_METAUSER) %then %let user_id = &_METAUSER;
    %end;
    %else %let user_id = &username;
    %if %upcase(&log_file_name_prefix) eq DEFAULT %then %let log_file_name_prefix=&user_id;

    %put NOTE: About to perform stored process initialization: ;

    %put using process_name=&log_file_name_prefix, group_name=&system_id, user_mode=&usertype, user_id=&user_id ;
    %init_stored_process (process_name=&log_file_name_prefix, group_name=&system_id, user_mode=&usertype, user_id=&user_id);
    %put NOTE: Finished stored process initialization;
    %put using process_name=&log_file_name_prefix, group_name=&system_id, user_mode=&usertype, user_id=&user_id ;

%end;

/*- user options library setup-*/
libname USRPREFS "%sysget(CMHOME)&pathsep.usrprefs";
/*
%global user_options_dataset;
%if %symglobl(username) %then %do;
  %if &username= %then %let user_options_dataset = USROPTS.user_options;
  %else %let user_options_dataset = USROPTS.user_options_&username;
%end;
%else %let user_options_dataset = USROPTS.user_options;
%put NOTE: Using user_options_dataset=&user_options_dataset ;
*/

/*-------------------------------------------------------------------------------*/

/*- Define environment variable for result directory -*/
options set = CRISKMRES "%sysget(CRISKMUSER)&pathsep.results";


/*- Get message files for errors -*/
  

/*- Run secruity check before running STP -*/

/*%if &criskm_stpserver = Y and &SYSTEM_FATAL_ERROR NE Y %then %do;
   %criskm_stp_securitycheck;
%end;*/

%if &SYSTEM_FATAL_ERROR=Y %then %goto EXIT;

/*- libraries for ETL data -*/
libname RD_MART  "!CMGROUP&pathsep.datamart";
libname RD_STAGE "!CMGROUP&pathsep.datamart&pathsep.staging";
libname RD_STAT  "!CMGROUP&pathsep.datamart&pathsep.static" ;
libname RD_MAP   "!CMGROUP&pathsep.datamart&pathsep.mapping" ;

/*-  test code-*/
libname static "!CMHOME&pathsep.datamart&pathsep.static" ;

/*- Risk Environment Libraries -*/

/*- for data sets used in environment setup -*/
libname RD_ENV   "!CRISKMUSER&pathsep.env";

/*- for functions package -*/
libname RD_FUNC  "!CRISKMUSER&pathsep.env&pathsep.functions";

/*- for template environment with variable definitions and object registrations -*/
libname RD_TEMP  "!CRISKMUSER&pathsep.env&pathsep.templates";

/*- for the main environment -*/
libname RD_PROJ  "!CRISKMUSER&pathsep.env&pathsep.projects" ;

/*- data libraries used for RiskDimensions -*/

/*- for current market data -*/
libname RD_MKT  ("!CRISKMUSER&pathsep.mktdata");

/*- for position data -*/
libname RD_POS  ("!CRISKMUSER&pathsep.instdata");

/*- for configuration/parameter/option data -*/
libname RD_CONF ("!CRISKMUSER&pathsep.config");

/*- history data for market risk factors and capital calculation results -*/
libname RD_HIST "!CRISKMUSER&pathsep.reshist";

/*- RiskDimensions result root -*/
libname RD_RES  "!CRISKMRES";

libname RD_ISA "!CRISKMUSER&pathsep.results&pathsep.scenario_imv_projects";
libname RD_RPS "!CRISKMUSER&pathsep.reports";

/*- reporting data mart -*/
libname RD_RPT "!CRISKMUSER&pathsep.reportmart";

/*- /*- reporting data mart -*/
libname RD_MOD "!CRISKMUSER&pathsep.models";

/* Input data views library */

libname RD_INPUT "!CRISKMUSER&pathsep.input_views";

	%if %dsexist(rd_root.INPUTS_RESULTS_VIEW_MASTER) eq 1 %then %do;
		%criskm_create_input_views;
	%end;


libname RD_OUT "!CRISKMUSER&pathsep.results&pathsep.result_views&pathsep.%upcase(&config_set)";

/* Manual adjustment views library */
libname RD_WORK "!CRISKMUSER&pathsep.scratch";

/*- 3: set format search libraries -*/
options FMTSEARCH = (RD_ENV.formats work.formats);



/*- 4: create message macros -*/
/* TODO: get this if statement working
%if %symglobl(CRISKM_SASCODE_INITED) EQ 0 %then %do;
    put 'performing criskm sascode initialization';
*/

/*Should the datasets be compressed or not-identify the flag from USER_PREFS*/
%global compressflag;
%let compressflag=N;
%if %dsexist(rd_root.user_prefs) eq 1 %then %do;
    proc sql noprint;
        select CONFIG_VALUE into :compressflag
        from rd_root.user_prefs
        where upcase(CONFIG_NAME)="COMPRESS_FLAG";
    quit;
%end;
%else %do;
	data _null_;
	call symput("compressflag","N");
	run;
%end;
options compress=&compressflag;

%if "&SYSTEM_FATAL_ERROR" EQ "N" and %symglobl(_systemcheck) EQ 0  %then %systemcheck; 

%EXIT:
options notes source;

%mend;
