/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b35_prep_regrpt_port_ca_crd4.sas
 *
 * PURPOSE: Create portoflio data for CA regulatory reports
 *
 *   USAGE:
 *
 *   NOTES:
 *
 *****************************************************************************/

/*-----------------------------------------------------------------------------
 * Step 1. Check to see if we user has requested the CA report
 * --------------------------------------------------------------------------*/
%macro b35_prep_regrpt_port_ca_crd4;
	%if (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CA_CRD4 OR  %UPCASE(&REGPROJECTNAME) EQ ALL) %then
		%goto FINFACT;
	%else  %goto SKIP;

	/*---------------------------------------------------------------------------
	 * Step 2. Check to see if we have data
 * -------------------------------------------------------------------------*/
%SKIP:

	/* User did not request CA portfolio - skip */
	%print_msg(WARNING,3,120);
	%return;


/*------------------------------------------------------------------------------------------
 * Note: Check if the rd_stage.financial_reporting_data exists and copy to the intds library
 * ----------------------------------------------------------------------------------------*/
%FINFACT:

/* Check if the data were created succesfully */
%if %dsexist(rd_stage.financial_reporting_data) LE 0 %then
	%do;
		%print_msg(WARNING,3,117);
		%status(CAPITAL_CA_CRD4,Problems creating input data for portfolio,CAPITAL_CA_CRD4);
		%return;
	%end;
%else
	%do;
		%if %attrn(rd_stage.financial_reporting_data,NOBS)=0 %then
			%do;
				%print_msg(WARNING,3,118);
				%status(CAPITAL_CA_CRD4,Problems creating input data for portfolio,CAPITAL_CA_CRD4);
				%return;
			%end;
		%else
			%do;

				data _intds.CAPITAL_CA_CRD4;
					length INTERNAL_ORG_RK $25.;
					set RD_STAGE.financial_reporting_data(rename=(INTERNAL_ORG_RK=INT_ORG_RK));

					if not missing(COUNTERPARTY_RK) then
						COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) );
					INSTID = 'INSTID'||compress(_n_);
					INSTTYPE ='regrpt_ca';
					INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);
				run;

				%status(CAPITAL_CA_CRD4,SUCCESS,Exposures for CA template,CAPITAL_CA_CRD4);
				%print_msg(NOTE,3,119);
			%end;
	%end;

options notes source;
%mend b35_prep_regrpt_port_ca_crd4;

/*
%b35_prep_regrpt_port_ca_crd4;
*/
