/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b35_prep_regrpt_port_cva_crd4.sas
 *
 * PURPOSE: Create portoflio data for regulatory reports under CVA reporting
 *
 *   USAGE: 
 *
 *   NOTES: 
 *    
 *
 *****************************************************************************/
%macro b35_prep_regrpt_port_cva_crd4;
   
   %get_regrpt_nls_strings;

%macro prepare_regrpt_port_cva (inputds);

/*---------------------------------------------------------------------------
 * Step 1.
 *
 * Check to see if the user has requested CVA data         
 * -------------------------------------------------------------------------*/    
   %let HAVEDATA=NO;

    %if (%INDEX(%UPCASE(&REGPROJECTNAME), CAPITAL_CVA_CRD4) or
         %INDEX(%UPCASE(&REGPROJECTNAME), ALL)) %then %do ;
                 
         %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
         %then %do;          
            libname _incrlib  "&REGPATH";
            %goto checkcva_opt;
         %end;
          
         %else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
         %then %do;          
            libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
            %goto checkcva_rnk;          
         %end;
    %end ;     
    
    %else %goto SKIP;
  
/*---------------------------------------------------------------------------
 * Step 2.
 *
 * Check to see if the user has requested CVA data
 * -------------------------------------------------------------------------*/    
    %SKIP:
    /* User did not request CVA portfolio - skip */   
    %print_msg (NOTE,3,63);
    
    %return;

    %CHECKCVA_OPT:
       %checkdata (_incrlib, &INPUTDS ,  CVA_CALCULATION_METHOD_TYPE IN ('STD','ALT') );
    
    %CHECKCVA_RNK:
       %checkdata (_incrlib, &INPUTDS ,  CVA_CALCULATION_METHOD_TYPE IN ('STD','ALT') );
    
    /* If no data then return*/
    %if (&HAVEDATA EQ NO)  %then 
    %do;
      %print_msg (WARNING,3,64);  
      %return;   
    %end; 

 /*---------------------------------------------------------------------------
 * Step 3.
 * Create CVA portfolio 
 * -------------------------------------------------------------------------*/

    /* dataset with the data of interest                                  */  
    data  _intds.CAPITAL_CVA_CRD4; 
       set _incrlib.&INPUTDS (where=(CVA_CALCULATION_METHOD_TYPE IN ('STD','ALT'))); 

       INSTID = compress('INSTEXP_'||_n_);
       INSTTYPE = 'regrpt_cva';

    run;    

/* If no data then return*/
   %checkdata (_intds, CAPITAL_CVA_CRD4, CVA_CALCULATION_METHOD_TYPE IN ('STD','ALT') );
   %if (&HAVEDATA EQ NO) %then %do;
      %print_msg (ERROR,3,2);/* Need to modify */ 
   %return;   
   %end; 
 
    

%if &HAVEDATA = YES %then 
%do;

   %status(CAPITAL_CVA_CRD4,SUCCESS,Exposures for CVA Exposures,CAPITAL_CVA_CRD4);
   
%end;
%else %do;
      %print_msg (ERROR,3,2);/* change message*/
%end;    
    
%mend prepare_regrpt_port_cva;

%prepare_regrpt_port_cva(cva_capital_charge);

%mend b35_prep_regrpt_port_cva_crd4;
