
/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b40_process_positions_end.sas
 *
 * PURPOSE: finishing up position processing
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *****************************************************************************/
 
%macro b40_process_positions_end;

 
 /*- check invalid positions and report -*/
 %macro check_invalid_positions;
 %local N_INVALID_APPROACH NO_EXP;
 /*- check invalid positions due to invalid approach -*/
     %let N_INVALID_APPROACH = %attrn(RD_POS.invalid_approach, NOBS);
     %if &N_INVALID_APPROACH GT 0 %then %do;
           %put ;
           %print_msg(WARNING, 2, 233);
           %put ;
    %end;
    
 /*- check positions with invalid components (switched to lower approach) -*/
     %let NO_EXP = %attrn(RD_POS.all_exp_with_invalid_components, NOBS);
     %if &NO_EXP > 0 %then %do;
         %put ;
         %print_msg(warning,2,35);
         %print_msg(warning,2,36);
         %print_msg(note,2,37);
         %put ;        
    %end;
    
 /*- check underlyings that do not belong to an active securitization pool -*/
    %let NO_EXP = %attrn(RD_POS.sec_underlying_no_exposure, NOBS);
    %if &NO_EXP > 0 %then %do;
        %put ;
        %print_msg(warning,2,301);
        %print_msg(note,2,302);
        %put ;        
    %end;
  %mend check_invalid_positions;
  
 %check_invalid_positions;

 /*-----------------------------------------------*
  *   code to replace missing values with '_#_'   * 
  *-----------------------------------------------*/
  
 %macro replace_missing_ref;

    data _null_;
	filename f1 temp;
	file f1;
	put "COUNTERPARTY_PD_RATING_GRADE";
	put "COUNTERPARTY_CLASS";
	put "CPTY_CLASS";
	put "STD_RW_BUCKET_CPTY";
	put "STD_RW_BUCKET_COUNTERPARTY";
	put "STD_RW_BUCKET_SOVEREIGN";
	put "STD_RW_BUCKET";
	put "STD_RW_BUCKET_SHORT";
	put "STD_RW_BUCKET_PASTDUE" ; 
	put "LGD_MODEL_RATING_GRADE";
	put "LGD_BUCKET_SEN";
	put "LGD_BUCKET_SUB";
	put "PD_MODEL_RATING_GRADE";
	put "PD_MODEL_FLOOR_GRADE";
	put "COLL_LEVEL_BUCKET";
	put "BASELI_RW_CLASS";
	put "IRB_RW_BUCKET";
	put "CCF_SET";
	put "ISSUE_CODE";
	put "HAIRCUT_SET";
	put "EL_MODEL_GRADE";
    run;

    data work._colnames1;
	infile f1 delimiter = ',' dsd;
	length NAME $32.;
	input NAME $; 
    run;

    proc sql noprint;
	create table pos_list as 
	  select memname from sashelp.vtable 
	  where libname ='RD_POS' and
                memtype='DATA';
    quit;
  
    data _null_;
	set pos_list end=final;
	call symput('tab'||strip(_n_),strip(memname));
	if final then call symputx('tot_tab',_n_);
    run;

    %do i=1 %to &tot_tab;
       proc contents data=rd_pos.&&tab&i
          out=work._colnames2(keep=name) noprint nodetails;
       run;

       proc sql noprint;
          create table work._colnames3 as select name from work._colnames2
	    where substr(name,length(name)-2) EQ '_ID' or name in( select name from work._colnames1 );
       quit;
 
       filename fixrefs catalog 'work.temp.fixrefs.source';
       data _null_;
         file fixrefs;
         set work._colnames3;
         put name "= coalescec(" name ", '_#_');";
       run;
    
       data rd_pos.&&tab&i;
         set rd_pos.&&tab&i;
         %inc fixrefs;
       run;
    
    %end;
%mend;

%replace_missing_ref;


 %clean_lib;
%mend b40_process_positions_end;
