/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: Batch_CRiskM_00_Initialize.sas
 *
 * PURPOSE: CRiskM batch run: create global macros and formats.
 *
 *   USAGE: 
 *
 *   NOTES: The numbers in filenames indicates run sequence groups.  In general, 
 *          programs within the same group can run in any order.
 *          
 *
 *****************************************************************************/

%macro batch_criskm_00_initialize;


/****************************************************************************
 *                      Global Macro Definitions
 ****************************************************************************/
 
/*- some global macros and user options -*/
%a00_init ;

/*- set up configuration tables  -*/
%a00_get_config_sets ;

/*- macros for rating agencies used -*/
%a00_define_rating_agencies ;

/*- macros for regulatory options -*/
%a05_define_regulatory_options ;

/*- macros for regulatory parameters -*/
%a05_define_regulatory_parms ;


/****************************************************************************
 *                             Mapping formats
 ****************************************************************************/
 
/*- mapping format for regulatory approach -*/
%a05_define_approach_fmt ;

/*- mapping formats for options at national discretion -*/
%a05_define_natl_disc_fmt ;

/*- mapping formats for counterparty and product classes and regulatory approach class -*/
%a05_define_class_fmt ;

/*- mapping formats for various type codes -*/ 
%a05_define_type_fmt ;

/*- mapping formats for rating grades from rating agencies -*/
%a05_define_rating_fmt ;

/*- mapping formats for various type codes in market data -*/
%a05_define_market_fmt ;

/*- create FX_HAIRCUT formats -*/
%a05_define_fx_haircut_value_fmt ;

/*- mapping formats for various maturity bands -*/
%a05_define_maturity_band_fmt ;

/*- mapping formats for various rating buckets, e.g. haircuts, risk weights -*/
%a05_define_rating_bucket_fmt ;

/*- mapping formats for PD floor and LGD buckets for equities under PD/LGD -*/
%a05_define_equity_pd_lgd_fmt;

/*- mapping formats for risk weight buckets not based on external assessment -*/
%a05_define_rw_bucket_fmt ;

/*- mapping formats for min LGD/collateralization levels for IRB collateral -*/
%a05_define_irb_collateral_fmt;

/*- mapping formats for PD, LGD, and RW buckets for reporting -*/
%a05_define_report_bucket_fmt;

/*- Create the formats necessary for regulatory reporting -*/
 %a10_create_regrpt_fmt;  


/*- mapping for haircut rating buckets and residual maturity bands -*/
%a10_def_hcut_mat_bnd_rtn_bkt_fmt;

/*- subsequent batch runs need to know which previous batches have been run -*/
%global RUN_STAGE;
%let RUN_STAGE = 0;

/*****************************************************************************
 *  Save Macro Definitions so this step doesnot have to be run multiple times.
 *****************************************************************************/
 
%u00_save_macro_definitions;
%mend batch_criskm_00_initialize;
