/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: batch_crm_allocation.sas
 *
 * PURPOSE: Check and run an entities data/projects
 *
 *   USAGE: CRM allocation across entities
 *
 *   NOTES: Modified for V4.2 01/07/06
 *          
 *          
 *
 *****************************************************************************/
 
%macro batch_crm_allocation;

/*---------------------------------------------------------------------------
 * Step 1.
 * Get the allocation list
 * -------------------------------------------------------------------------*/
/*- Delete the result macro variable to prevent re-direction of the log for other entities -*/

%global system_id_orig;

/*- 1a Set the original system_id -*/
%let system_id_orig=&SYSTEM_ID;
%SYMDEL _RESULT;

filename check catalog 'work.temp.check.source';    
proc sort data=rd_root.crm_allocation_list; by internal_org_rk; 
proc sort data=rd_stat.entity_system_id force; by internal_org_rk;run;

data work.include_in_allocation (where=(INCLUDE_IN_ALLOCATION='YES'));
 merge rd_root.crm_allocation_list  rd_stat.entity_system_id (keep=internal_org_rk system_id);
 by internal_org_rk;
run;


%macro _crm_entity_allocation;

/*---------------------------------------------------------------------------
 * Step 2.
 * Perform security check before continuing
 * -------------------------------------------------------------------------*/

data _null_;
 set work.include_in_allocation end=eof;
 file check;
 put '%let system_id=' system_id ';';
 put '%let usertype=MASTER;';
 /*put '%criskm_stp_securitycheck;'; */
 run;

 %inc check;
 
 %a05_existence_child_entities;
 %a10_create_entities;
 %a15_refresh_entity_datamarts;
 %b05_refresh_entity_results;
 %c05_consolidate_entities;
 %d05_finish_post_processing; 
/*---------------------------------------------------------------------------
 * Step 3.
 * Restore the orginal system settings by re-setting everything to the parent
 * -------------------------------------------------------------------------*/

%if %upcase("&SYSTEM_FATAL_ERROR") NE "Y" %then %do;

data _null_;
 set _root._parent_sysid;;
 call symput ("system_id",systemid);
run;

%autoexec_criskm (sysid=&system_id_orig, usrtype=MASTER, usrname=,recreate_log=NO);
%end;
%mend _crm_entity_allocation;

%_crm_entity_allocation;
%mend batch_crm_allocation;
