/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: convert_reg_parm_ccy.sas
 *
 * PURPOSE: Convert regulatory parameters into the reporting currency
 *
 *   USAGE: %convert_reg_parm_ccy ;
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro convert_reg_parm_ccy ;

    data RD_CONF.unconverted_reg_parms (keep = PARAMETER_NAME PARAMETER_VALUE REGULATORY_PARAMETER_DESC PARAMETER_CURRENCY_CD) 
         RD_CONF.regulatory_parms (keep = PARAMETER_NAME PARAMETER_VALUE REGULATORY_PARAMETER_DESC PARAMETER_CURRENCY_CD) ;

        /*- Define variables to be used in the hash as data and keys -*/
        length TO_CUR FROM_CUR $3. ;
        format MID nlnum10. ; 
        format MATURITY_LENGTH best12. ;
        
        /*- Declare a maturity of length 0 to get the spot rate, rather than -*/
        /*- a forward rate of some type -*/
        MATURITY_LENGTH = 0 ;

        /*- Set MID to a missing value to avoid an unitialized variable error -*/
        call missing(MID) ;
        
        /*- Declare a hash object for bringing in the exchange rate -*/
        if _N_ = 1 then do ;
            declare hash nha(hashexp:4,dataset:"RD_MKT.current_fx"); 
                rc = nha.defineKey('TO_CUR','FROM_CUR','MATURITY_LENGTH');
                rc = nha.defineData('MID') ;
                rc = nha.defineDone() ;
        end ;
        
        /*- Bring in the data set with the regulatory parameters -*/ 
        set RD_CONF.regulatory_parms ;

        /*-  and Do not process those parameters which do not require conversion -*/
        if PARAMETER_CURRENCY_CD not in ("","&REPORT_CCY") then do ;

            /*- Find the exchange rate for converting the parameter -*/
            /*- and convert if the rate is found -*/
            TO_CUR = "&REPORT_CCY" ;
            FROM_CUR = PARAMETER_CURRENCY_CD ;

            /*- Make sure to get the spot rate -*/
            rc = nha.find() ;
            if rc = 0 then do ;
                call symputx(strip(PARAMETER_NAME),PARAMETER_VALUE*MID,g) ;
                PARAMETER_VALUE = PARAMETER_VALUE*MID ;    
                output RD_CONF.regulatory_parms ; 
            end ;

            /*- If the correct rate is not found, look for the reciprocal rate -*/
            /*- and use it to convert the parameter -*/
            else do ;
                TO_CUR = PARAMETER_CURRENCY_CD ;
                FROM_CUR = "&REPORT_CCY" ;

                rc = nha.find() ;

                if rc = 0 then do ;
                    call symputx(strip(PARAMETER_NAME),PARAMETER_VALUE/MID,g) ;
                    PARAMETER_VALUE = PARAMETER_VALUE/MID ;   
                    output RD_CONF.regulatory_parms ;  
                end ;
     
                /*- If neither is found, do not change the parameter value -*/
                /*- and output to the data set -*/
                else output RD_CONF.regulatory_parms RD_CONF.unconverted_reg_parms;
            end ;
        end ;
        else output RD_CONF.regulatory_parms ;
    run; 

    /*- Determine if any values were unable to be converted and produce an -*/
    /*- error message and a fatal system error if needed -*/
    %macro report;

        %local NUNCONV ;
     
        %let NUNCONV = %attrn(RD_CONF.unconverted_reg_parms , NOBS);
    
        %if &NUNCONV > 0 %then %do;
            %put ;
			%print_msg(error, 2, 358);
			%print_msg(error, 2, 359);
            %put ;
            %let SYSTEM_FATAL_ERROR = Y ;
        %end;

    %mend report;

    %report;

%mend convert_reg_parm_ccy ;
