/*****************************************************************************
 *   Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *   NAME   : criskm_update_stp_status
 *
 *   PURPOSE: Macro to update the status of stp execution at some check points
 *
 *   NOTES  : Updates status of Stored Procedure in to dataset STP_EXECUTION_MASTER.
 *
 *   USAGE  : %criskm_update_stp_status(STP_NAME  =Name_of_stored_process    ,
 *										STP_STATUS=In Progress               ,
 *										STATUS_PCT=60%                       ,
 *                                      LOG_FILE_NAME=SAMPLE_LOG.log         ,
 *                                      PORTFOLIO_FILTER_ID=Sample1          ,
 *                                      CONFIG_SET=&CONFIG_SET               ,
 *										UPDATE_DTTM_FLG=Y);
 *
 *
 *****************************************************************************/

%macro criskm_update_stp_status(STP_NAME=,STP_STATUS=,PORTFOLIO_FILTER_ID=,STATUS_PCT=,LOG_FILE_NAME=,UPDATE_DTTM_FLG=);

/*Root_tmp is pointing to same location as rd_root but this library is having a filelockwait set to 5 secs*/
libname ROOT_TMP "%sysget(CRISKMUSER)" filelockwait=5;
/*Define portfolio filter id incase it is empty*/
%if %length(&PORTFOLIO_FILTER_ID) eq 0 %then %let PORTFOLIO_FILTER_ID=0000;

/*If the RD_ROOT.STP_EXECUTION_MASTER table is present then insert records for error handling else error out*/
%if %dsexist(ROOT_TMP.STP_EXECUTION_MASTER) eq 1 %then %do;

	proc sql noprint exec;
	/*Define stp_count that identifies if the stp was already run earlier for the given config set*/
	 select count(*) into :STP_COUNT
	 	from ROOT_TMP.STP_EXECUTION_MASTER
			where upcase(STPNAME)=upcase("&STP_NAME")
			   and upcase(CONFIG_SET)=upcase("&config_Set");
	quit;
	proc sql;
	/*If error then*/
	%if &syscc gt 4 %then %do;
		/*If stp was already existing then update RD_ROOT.STP_EXECUTION_MASTER*/
		 delete from ROOT_TMP.STP_EXECUTION_MASTER
  		  where  upcase(STPNAME)=upcase("&STP_NAME") and upcase(CONFIG_SET)=upcase("&config_Set");
		 insert into ROOT_TMP.STP_EXECUTION_MASTER
				(STPNAME ,CONFIG_SET,STATUS ,STATUS_PCT,PORTFOLIO_FILTER_ID,LOG_FILE_NAME,LAST_EXECUTION_DTTM)
				 VALUES("&STP_NAME","&CONFIG_SET","Failed","0%","&PORTFOLIO_FILTER_ID","%sysget(LOGFILE)",%sysfunc(datetime()));
	%end;
	/*If no error then*/
	%if &syscc le 4 %then %do;
		/*If stp was already existing then update RD_ROOT.STP_EXECUTION_MASTER*/
		%if &STP_COUNT gt 0 %then %do;
		 Update ROOT_TMP.STP_EXECUTION_MASTER
			Set STATUS=upcase("&STP_STATUS"),
				STATUS_PCT="&STATUS_PCT"
				%if &UPDATE_DTTM_FLG eq Y %then %do;
					,PORTFOLIO_FILTER_ID="&PORTFOLIO_FILTER_ID"
					,LOG_FILE_NAME="%sysget(LOGFILE)"
					,LAST_EXECUTION_DTTM=%sysfunc(datetime())
				%end;
			where  upcase(STPNAME)=upcase("&STP_NAME")
			   and upcase(CONFIG_SET)=upcase("&config_Set");
		%end;
		/*If stp was not existing then insert into RD_ROOT.STP_EXECUTION_MASTER*/
		%if &STP_COUNT = 0 %then %do;
			insert into ROOT_TMP.STP_EXECUTION_MASTER
				(STPNAME ,CONFIG_SET,STATUS ,STATUS_PCT,PORTFOLIO_FILTER_ID,LOG_FILE_NAME,LAST_EXECUTION_DTTM)
				 VALUES("&STP_NAME","&CONFIG_SET","&STP_STATUS","&STATUS_PCT","&PORTFOLIO_FILTER_ID","%sysget(LOGFILE)",%sysfunc(datetime()));
		%end;
	%end;
  	quit;
%end;
%else %do;
   %put ERROR: Dataset ROOT_TMP.STP_EXECUTION_MASTER does not exists.;
%end;
%symdel STP_COUNT /NOWARN;
%mend criskm_update_stp_status;
