/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: e05_project_ccr_std_mtm.sas
 *
 * PURPOSE: Compute exposure at default for CCR STD method.
 *
 *   USAGE:  
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/




%macro e05_project_ccr_std_mtm;

/*- these macros are needed for the following projects -*/
%global CCRSTDMTMPATH CCR_STD_MTM_DONE; 
%let CCR_STD_MTM_DONE = N; 
/*- next project needs to know previous output path -*/
%let CCRSTDMTMPATH = %lowcase(%sysget(CRISKMRES)&pathsep.&PROJECT_SET&pathsep&PROJECT_SET._ccr_std_mtm);

%if &N_TRADING_BOOK_EXP GT 0 and &N_TB_STD GT 0 %then %do;

    %clean_dir(&CCRSTDMTMPATH);

/*- sensitivity analysis -*/

    proc risk noseqcheck ;

    environment open = RD_PROJ.&ENV_NAME._TB;

    setoptions keeplib;

    crossclass by_instid (INSTID);
    /*- Mark-to-Market Analysis -*/
    project ccr_std_mtm_%lowcase(&PROJECT_SET)
            data            = Current_Full
            portfolio       = All_TB_STD
            analysis        = ccr_sensitivity
            currency        = &REPORT_CCY
            crossclass      = by_instid
            outpath         = "&OUTPATH"
            out             = &PROJECT_SET._ccr_std_mtm
            ; 

    runproject ccr_std_mtm_%lowcase(&PROJECT_SET)
            date        = &RUNDATE
            options     = (outall noallscore nomddbs)
            ;
           
    environment save noupdatemetadata;

    run;

/*- check for error -*/
    %if %dsexist(&RESLIB1..sens2) = 0 %then %goto EXIT;

    %let CCR_STD_MTM_DONE = Y; 
/*- prepare for the hedging set and ead calculation -*/
/*- keep only the variables of interest -*/
    data sensitivity(rename=(SENSITIVITY=DELTA NAME=RISK_FACTOR_ID)
                     keep=INSTID NAME SENSITIVITY);
    length NAME $32.;                 
    set &RESLIB1..sens2(where=((SENSITIVITY NE 0) AND (INSTID NE '+') ));
    run;
    
/*- check if user already computed delta -*/
/*- Only one computed delta for each exposure can be recognized (user supplied risk position is not
    subject to this restriction).  This mechanism is the best for the debt instrument or payment legs 
    splitted into multiple positions.
*/

/*- get counterparty_rk and netting_set_id -*/
    data risk_positions (drop=RESIDUAL_MATURITY NEXT_CONTRACT_RESET_DATE counter 
                         rename=(INSTID2=INSTID INSTID=INSTID1 OUTV_FACE_VALUE=FACE_VALUE_AMT)
                         index=(RPKEY=(INSTID1 ISSUE_KEY RISK_FACTOR_ID)));
    merge sensitivity (in=a)
          &RESLIB1..instvals
          (keep=INSTID ISSUE_KEY NETTINGSETID COUNTERPARTYID COUNTERPARTY_RK RESIDUAL_MATURITY 
                NEXT_CONTRACT_RESET_DATE COLLATERAL_FLG SHORTPOSITION OUTV_FACE_VALUE 
                OUTV_RISK_POSITION 
           in=b) ;
    by INSTID;
    if a;
    if first.INSTID then
       counter = 1;
    else counter = counter + 1;
    
    INSTID2 = compress(INSTID||"_"||counter);
    
    if not missing(NEXT_CONTRACT_RESET_DATE) then
       HEDGING_SET_MATURITY = max(0, round(YRDIF(&RUNDATE, NEXT_CONTRACT_RESET_DATE, "&DAY_BASIS"),&MATURITY_ROUNDOFF.));
    else 
       HEDGING_SET_MATURITY = RESIDUAL_MATURITY;
    HEDGING_SET_MAT_BAND = put(HEDGING_SET_MATURITY, MAP_HEDGING_SET_MAT_BAND.);  
    
    run;
    
/*- do not need to re-calculate if already supplied by user -*/
    data risk_positions;
    merge risk_positions (in=a)
          RD_POS.exposure_trading_book_rp 
          (keep=ISSUE_KEY RISK_FACTOR_ID INSTID rename=(INSTID=INSTID1) in=b)
          RD_POS.crm_instrument_trading_book_rp 
          (keep=ISSUE_KEY RISK_FACTOR_ID INSTID rename=(INSTID=INSTID1) in=c)
          RD_POS.crm_derivative_trading_book_rp
          (keep=ISSUE_KEY RISK_FACTOR_ID INSTID rename=(INSTID=INSTID1) in=d);
    by INSTID1 ISSUE_KEY RISK_FACTOR_ID;
    if a and not (b or c or d);
    run;

/*- get hedging set -*/
    proc sql; 
    create table &RESLIB1..risk_positions as 
    select t1.*, t3.MAT_BAND_FLG, t3.HEDGING_SET_ID, t3.HEDGING_SET_TYPE_CD
    from risk_positions as t1,
         RD_POS.risk_factor_hedging_set as t2,
         RD_POS.hedging_set as t3
    where
         t1.RISK_FACTOR_ID=t2.RISK_FACTOR_ID and
         t2.HEDGING_SET_RK=t3.HEDGING_SET_RK;
    quit;
    
/*- remove duplicate risk positions for the same issue: this usually occurs for the debt instrument 
    which may depend on multiple interest rate risk factors in the same currency. The risk positon for
    the debt instruments is calculated based on the modified duration instead a single rate.    -*/
    proc sort data=&RESLIB1..risk_positions nodupkey;
    by INSTID1 HEDGING_SET_ID;
    run;
    
    proc sort data=&RESLIB1..risk_positions; by RISK_FACTOR_ID; run;

/*- create new InstId for risk ositions -*/
    data &RESLIB1..risk_positions (drop=COLLATERAL_FLG OUTV_RISK_POSITION INSTID1
                                   index=(RISK_FACTOR_ID));
    merge &RESLIB1..risk_positions (in=a) 
          RD_POS.risk_factor (in=b keep=RISK_FACTOR_ID CURRENCY);
    by RISK_FACTOR_ID;
    if a;
 
    if MAT_BAND_FLG = 1 then
       HEDGING_SET_ID = compress(HEDGING_SET_ID||"_"||HEDGING_SET_MAT_BAND);
    INSTTYPE = put(HEDGING_SET_TYPE_CD, $MAP_RISK_POSITION_INSTTYPE.);
    CCF_SET = put("&CCF_SET", $MAP_CCF_SET.);
    CCF_TYPE = put(compress("&CCF_SET" ||HEDGING_SET_TYPE_CD), $MAP_CCF_TYPE_STD_CCR.);
    if COLLATERAL_FLG=1 then SHORTPOSITION=1;
    else SHORTPOSITION = 0;
    
/*- already computed delta -*/        
    if not missing(OUTV_RISK_POSITION) then do;
       DELTA=OUTV_RISK_POSITION;
       INSTTYPE="PRICED_RP";
    end;
    
/*- get the currency for the underlying risk factor for non-debt instruments -*/
    if missing(CURRENCY) or INSTTYPE NE "OTHER_RP" then CURRENCY="&REPORT_CCY";
    run;

/*- create data for the positions -*/
    data &RESLIB1..current_value (rename=(VALUE=MTM_VALUE OUTV_FACE_VALUE=FACE_VALUE_AMT 
                                          OUTV_MAT_EFF = EFFECTIVE_MATURITY_YEAR) 
                                  drop=COLLATERAL_FLG);
    set &RESLIB1..instvals (keep=INSTID VALUE COUNTERPARTY_RK NETTINGSETID COLLATERAL_FLG 
                                 OUTV_MAT_EFF OUTV_FACE_VALUE);
    INSTTYPE = "MTMVALUE";
    if COLLATERAL_FLG=1 then SHORTPOSITION=1;
    else SHORTPOSITION = 0;
    run;      

%EXIT :
%end;
%mend e05_project_ccr_std_mtm;
