/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: e20_project_stress_pd_crd4.sas
 *
 * PURPOSE: Pre-configured stress test on PDs for stored process.
 *
 *   USAGE: 
 *
 *   NOTES: 1. Same as e20_project_stress_pd_crd4.sas.
 *
 *
 *****************************************************************************/

%macro e20_project_stress_pd_crd4;

/*- create stress test scenario on PDs: all up by 10% (EXAMPLE ONLY) -*/
data _null_ ;
set RD_MKT.current_pd end=lastobs;
if _N_ =1 then do ;
    call execute ('proc risk; environment open = RD_PROJ.&ENV_NAME  ; ') ;
    call execute ('scenario &scenarioname_pd  changes=( ') ;
end;

if not lastobs then 
   call execute ( PD_NAME !!  " &stress_amt &typechange_stress," ) ;
else do;
   call execute ( PD_NAME !!  " &stress_amt &typechange_stress" ) ;
call execute ( " ) ; environment save noupdatemetadata; run;  " ) ;
end;
 
run;

/*- PD_10_PCT test: regulatory stress-*/

/*- these macros are needed for the following projects -*/
%global PROJECT_SET OUTPATH REGPATH _PDSTRESSRPT;

%let _PDSTRESSRPT=YES;
/*- need to get current result set -*/
%let PROJECT_SET = %lowcase(&scenarioname_pd);

/*- need to get result path -*/
%let OUTPATH = %sysget(CRISKMRES)&PATHSEP.&PROJECT_SET;

/*- next project needs to know previous output path -*/
%let REGPATH = %sysget(CRISKMRES)&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._calculations;
/*- clean the output directory -*/    
%clean_dir(&REGPATH);

%macro pdstress;

    proc risk;

    environment open = RD_PROJ.&ENV_NAME  ;

    setoptions keeplib;

    /*- portfolio from regulatory project set since stress does not affect MtM results -*/
    project Reg_&PROJECT_SET data = Current_Full
                             portfolio = All_Reg_&REGULATORY_PROJECT_SET_NAME
                             analysis  = (&scenarioname_pd)
                             currency  = &REPORT_CCY
                             outpath   = "&OUTPATH"
                             out       = &PROJECT_SET._calculations
                             ;

    runproject Reg_&PROJECT_SET
               options = (OUTALL /*noallscore*/ nomddbs)
               date    = &RUNDATE
/*               report*/
               ;   

    environment save noupdatemetadata;

    run;

  /* check for risk run success */
  %if %dsexist(&RESLIB1..summary) = 0 %then %do;
      %let SYSTEM_FATAL_ERROR = Y;
      %print_msg(error, 2, 153);
  %end;
  
%mend pdstress;

%pdstress;

/*- post-processing -*/
%post_regulatory_run_crd4;

/*
                             reports   = ( Post_Regulatory_0  Post_Regulatory_1  Post_Regulatory_MAP_HAIRCUT_FX2
                                           Post_Regulatory_3  Post_Regulatory_4  Post_Regulatory_5
                                           Post_Regulatory_6  Post_Regulatory_7  Post_Regulatory_8
                                           Post_Regulatory_9  Post_Regulatory_10  Post_Regulatory_11
                                          )
*/
%mend e20_project_stress_pd_crd4;
