/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: get_cpty_details_le1_crd4.sas
*
* PURPOSE: Gets Counterparty Details. (LE Template )
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/

%macro get_counterparty_details_crd4;
/*checking if it crosses the basic large exposure threshold*/

%if %UPCASE(&REGPROJECTNAME)=CAPITAL_LE2_CRD4 %then %do;
	proc sql ;
	 create table CAPITAL_LE_CPTY_ALL as
		select CAPITAL_LE.* 
			from _INTDS.CAPITAL_LE
				 inner join
				 LE_COUNTERPARTY_RK_LIST
				 on CAPITAL_LE.le_counterparty_rk = LE_COUNTERPARTY_RK_LIST.le_counterparty_rk;
	quit;

	proc sql ;
	 create table CAPITAL_LE_CPTY_LRG as
		select * 
			from _INTDS.CAPITAL_LE
				where le_counterparty_rk in ( &le_cpty_i,&le_cpty_u,&le_cpty_irb);
	quit;

	data FR_CPTY_DETAILS_TEMP;
		set CAPITAL_LE_CPTY_ALL CAPITAL_LE_CPTY_LRG;
	run;

	PROC SQL;
		CREATE TABLE CPTY_DETAILS_TEMP AS
			SELECT *,SUM(TOT_ORIG_EXP) as sum_ead_portion, &TOT_ELIG_CAP as TOT_ELIG_CAP
				FROM FR_CPTY_DETAILS_TEMP;
	quit;

	proc sql;
		drop table 
			CAPITAL_LE_CPTY_ALL,
			CAPITAL_LE_CPTY_LRG,
			FR_CPTY_DETAILS_TEMP
			;
	quit;

%end;
%else %if %UPCASE(&REGPROJECTNAME)=CAPITAL_LE3_CRD4 %then %do;
	PROC SQL;
	CREATE TABLE CPTY_DETAILS_TEMP AS
		SELECT *, SUM(TOT_ORIG_EXP) as sum_ead_portion, &TOT_ELIG_CAP as TOT_ELIG_CAP
			FROM _INTDS.CAPITAL_LE
				where counterparty_group in (select counterparty_group from _intds.groups)
					group by LECPTYID;
	QUIT;
%end;
%else %if %UPCASE(&REGPROJECTNAME)=CAPITAL_LE4_CRD4 or %UPCASE(&REGPROJECTNAME)= CAPITAL_LE5_CRD4 %then %do;
	PROC SQL;
		CREATE TABLE CPTY_DETAILS_TEMP AS
			SELECT * FROM _INTDS.CASHFLOW_CAPITAL_LE
				where le_counterparty_rk in  (&le_cpty_i,&le_cpty_u);
	QUIT;
%end;

/*keep only those columns that are reqd by LE2,3*/
	DATA CPTY_DETAILS_TEMP1 
	(KEEP= LECPTYID COUNTERPARTY_GROUP COUNTERPARTY_CD COUNTERPARTY_GROUP_PARENT_FLG CONNECTION_TYPE_CD COUNTERPARTY_NAME
	CPTY_TYPE_LE2 UNDERLYING_FLG);
	set CPTY_DETAILS_TEMP;
		IF COUNTERPARTY_GROUP='' THEN DO;
		IF UPCASE("&REGPROJECTNAME") IN ("CAPITAL_LE2_CRD4","ALL") THEN CPTY_TYPE_LE2='1';
		END;
		ELSE CPTY_TYPE_LE2='2';
		IF (NOT MISSING(LE_COUNTERPARTY_RK)) THEN LECPTYID = compress('LE' || input(LE_COUNTERPARTY_RK, $30.));
	run;

/*Pick counterparty_cd based on counterparty_group_parent_flg = 1/0*/
	PROC SORT DATA = CPTY_DETAILS_TEMP1 OUT=CPTY_SORTED NODUP; 
		BY COUNTERPARTY_GROUP DESCENDING COUNTERPARTY_GROUP_PARENT_FLG; 
	RUN;



data CPTY_SORTED (drop=rc STAG_CTPTY STAG_NM);

length STAG_CTPTY STAG_NM $32. ;
	if _n_ = 1 then do;
    declare hash hCD(dataset : "RD_STAGE.COUNTERPARTY_MART (where=(COUNTERPARTY_GROUP_PARENT_FLG eq 1) rename=(COUNTERPARTY_CD=STAG_CTPTY COUNTERPARTY_NAME=STAG_NM))");
    	rc = hCD.defineKey ("COUNTERPARTY_GROUP");
    	rc = hCD.defineData("STAG_CTPTY","STAG_NM");
    	rc = hCD.defineDone();

	end;
	set CPTY_DETAILS_TEMP1;

	rc = hCD.find();
	
	if rc = 0 then do;
  		CPTY_CD = STAG_CTPTY;
		CPTY_NM = STAG_NM;
	end;
	else do;
		CPTY_CD = COUNTERPARTY_CD ;
		CPTY_NM = COUNTERPARTY_NAME;
	end;

run;

data work.CPTY_SORTED;
  set work.CPTY_SORTED;
  PROJECT_NAME="%upcase(&REGPROJECTNAME)";
  run;

data rd_root.counterparty_details;
	 set 
		%if %dsexist(rd_root.counterparty_details) %then %do;
			rd_root.counterparty_details(where=(upcase(PROJECT_NAME)^="%upcase(&REGPROJECTNAME)")) 
		%end;
		work.cpty_sorted;
	run; 

%mend get_counterparty_details_crd4;



 
