/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_crm_financial.sas
 *
 * PURPOSE: Method program code for financial collateral.
 *          
 *
 *   USAGE: %pm_crm_financial;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_crm_financial;

    %initialize_regulatory_outvars;
                                   
    if SHORT_TERM_CLAIM_FLG = 1 and COUNTERPARTY_CLASS = 'BANK' then 
        OUTV_RW_COUNTERPARTY = STD_RW_CPTY_SHORT;
    else
        OUTV_RW_COUNTERPARTY = STD_RW_CPTY;

    OUTV_RW_ISSUE = 0;
    
    OUTV_LGD_CRM_SEN = 0;
    OUTV_LGD_CRM_SUB = 0;    

/*- for financial collateral eligible for simple approach, need RW based on issue RW bucket -*/
    if "&STD_CRM_APPROACH" = "SIMPLE" and ELIGIBLE_CRM_TYPE = 'FINANCIAL_SIMPLE' then do;  
       if EXT_ISSUE_MAP_RATING NE 'MISS' and (STD_RW_BUCKET  NE '_#_' or STD_RW_BUCKET_SHORT NE '_#_' ) then do;       

/*- short-term assessment can only be used for short-term claims -*/
/*- against banks and corporates: Basel II - 103                 -*/
          if SHORT_TERM_ASSESS_FLG = 1 and COUNTERPARTY_CLASS in ('BANK', 'CORPORATE') then do;
            OUTV_RW_ISSUE = STD_RW_SHORT_REF.STD_RW_BUCKET_SHORT;
          end;
          else do;
        
            select (COUNTERPARTY_CLASS);
        
                when ('BANK') do;
                    if upcase("&STD_BANK_OPTION") = "OPTION1" then 
                        OUTV_RW_ISSUE = STD_RW_BANK_OPT1_REF.STD_RW_BUCKET ;
                    else if upcase("&STD_BANK_OPTION") = "OPTION2" then
                        OUTV_RW_ISSUE = STD_RW_BANK_OPT2_LONG_REF.STD_RW_BUCKET ;                 
                end;
     
                when ('CORPORATE') do;
                    OUTV_RW_ISSUE = STD_RW_CORPORATE_REF.STD_RW_BUCKET ;
                end;
    
                when ('SOVEREIGN') do;
                    OUTV_RW_ISSUE = STD_RW_SOVEREIGN_REF.STD_RW_BUCKET ;  
                end;

                otherwise;
        
             end;
    
          end;
       end;
    else OUTV_RW_ISSUE = .;
    end;
   
    _VALUE_ = CRM_VALUE ;
    
%mend pm_crm_financial;
