/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_bank_std.sas
 *
 * PURPOSE: Method program code for bank exposures under STD approach.
 *
 *   USAGE: %pm_exp_bank_std;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_exp_bank_std;

    /*- initialize outvars -*/
    %initialize_regulatory_outvars;

/*- by default, get the RW associated with the counterparty -*/
/*- bank short term preferential treatment from option2     -*/
    if SHORT_TERM_BANK_OPT2_FLG = 1 then 
        OUTV_RW_COUNTERPARTY = STD_RW_CPTY_SHORT;
    else
        OUTV_RW_COUNTERPARTY = STD_RW_CPTY;    

    /*- get RW based on issue rating. These are used only for short-term assessment -*/
    /*- and Option 2, since Option 1 is based on sovereign rating -*/
    if (STD_RW_BUCKET  NE '_#_' or STD_RW_BUCKET_SHORT NE '_#_' ) and EXT_ISSUE_MAP_RATING NE 'MISS' then do;
        
        /*- Set the RW on the basis of being a short-term exposure -*/
        if SHORT_TERM_ASSESS_FLG = 1 then
            OUTV_RW_ISSUE = STD_RW_SHORT_REF.STD_RW_BUCKET_SHORT;

        /*- Set the RW for MDB and other international organizations */
        else if COUNTERPARTY_SUBCLASS in ('MDB', 'INT_ORG') then
            OUTV_RW_ISSUE = STD_RW_BANK_OPT2_LONG_REF.STD_RW_BUCKET;

        /*- Set the RW for PSE -*/
        else if COUNTERPARTY_SUBCLASS in ('PSE', 'LOCAL_GOV', 'REGIONAL_GOV', 'RELIGIOUS_ORG') then do;
            
             /*- Under Option 2, PSE are weighted without short-term preferential treatment (BII,p57) -*/
            if upcase("&STD_PSE_DOM_BANK_OPTION") = "OPTION2" then 
                OUTV_RW_ISSUE = STD_RW_BANK_OPT2_LONG_REF.STD_RW_BUCKET;
        end;                   

        else if upcase("&STD_BANK_OPTION") = "OPTION2" then do ;
            
            OUTV_RW_ISSUE = STD_RW_BANK_OPT2_LONG_REF.STD_RW_BUCKET;   

            /*- Check the currency of issues eligible for preferential treatment. From the counterparty -*/
            /*- method ineligible issues will be missing the preferential counterparty risk weight. -*/
            if STD_RW_CPTY_PREF NE . then do ;
                if (index(trim(CPTY_COUNTRY_CURRENCY), trim(CCY))) > 0 and SHORT_TERM_CLAIM_FLG = 1 then do ;
                    OUTV_RW_ISSUE = max(&STD_SHORT_BANK_RW_FLOOR,STD_RW_BANK_PREF_REF.STD_RW_BUCKET) ; 
                end ;
            end ;    
        end;
    end ;   
    else if STD_RW_CPTY_PREF NE . then do ;
        if (index(trim(CPTY_COUNTRY_CURRENCY), trim(CCY))) > 0 and SHORT_TERM_CLAIM_FLG = 1 then do ;
            OUTV_RW_ISSUE = max(&STD_SHORT_BANK_RW_FLOOR, STD_RW_CPTY_PREF);
        end ;
    end ;

    _VALUE_ = EXP_VALUE ;

%mend pm_exp_bank_std;
