/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_corporate_irba.sas
 *
 * PURPOSE: Method program code for corporate exposures under IRBA approach.
 *
 *   USAGE: %pm_exp_corporate_irba;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_exp_corporate_irba;

/*- initialize outvars -*/
    %initialize_regulatory_outvars;
    
/*- initialize exposure PD as counterparty PD -*/
    OUTV_PD_COUNTERPARTY = PD_CPTY;
/*- repo_style use counterparty PD assessment if available -*/
    if IRB_PRODUCT_CLASS = 'REPO_STYLE' and (not missing(OUTV_PD_COUNTERPARTY)) then
       OUTV_PD_ISSUE = OUTV_PD_COUNTERPARTY;
    else do;
       %get_pd_issue;
    end;
    
    %get_lgd_irba;

    /*- firm size: default to &IRB_SME_MAX_FIRM_SIZE (no firm size adjustment) -*/
    OUTV_FIRM_SIZE = COUNTERPARTY_SIZE;
    
    if (OUTV_FIRM_SIZE in (., 0) or COUNTERPARTY_SUBCLASS NE 'SME') then OUTV_FIRM_SIZE = &IRB_SME_MAX_FIRM_SIZE;
    
/*- EL for defaulted exposures must be estimated: Basel II - 272 and 471 -*/      
    if OUTV_PD_ISSUE = 100 then do;

        %get_el_irb ;    

        OUTV_RW_ISSUE = max(0, sum(OUTV_LGD, - OUTV_EL)) / &CAPITAL_RATIO * IRB_DEFAULT_SCALING_FACTOR;
    end;
    else do;
        OUTV_EL      = OUTV_PD_ISSUE * OUTV_LGD / 100;    
        OUTV_RW_ISSUE = IRB_RW_CORPORATE(OUTV_PD_ISSUE, OUTV_LGD, MAT_EFF, OUTV_FIRM_SIZE, 
                                       &IRB_SME_MIN_FIRM_SIZE, &IRB_SME_MAX_FIRM_SIZE, IRB_SCALING_FACTOR);
    end;

    _VALUE_ = EXP_VALUE ;
    
%mend pm_exp_corporate_irba;
