/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_equity_std_crd4.sas
 *
 * PURPOSE: Risk weight program for equities under standardized approach
 *          
 *   USAGE: %pm_exp_equity_std_crd4 ;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_exp_equity_std_crd4 ;

/*- initialize outvars -*/
    %initialize_regulatory_outvars;

     if COUNTERPARTY_CLASS = 'INSTITUTION' or COUNTERPARTY_SUBCLASS in ('FINANCIAL_ENTITY','INSURANCE','NQCCP') then do ;   
           /*- equity holding of an insurance company that is not deducted receives 370% risk weight: CRR Art. 471(2) -*/         
           if COUNTERPARTY_SUBCLASS = 'INSURANCE' then OUTV_RW_ISSUE = STD_RW_EQUITY_INSURANCE ;
           
           /*- significant investment in financial sector entity that is not deducted receives 250% risk weight: CRR Art. 48(4), 133(2) -*/ 
           else if EQUITY_POSITION_TYPE = 'SIG_INVEST' then OUTV_RW_ISSUE = STD_RW_EQUITY_FIN_ENTITY ;
           
           /*- non-significant investment in financial sector entity that is not deducted receives 100% risk weight: CRR Art. 46(4), 133(2) -*/ 
           else OUTV_RW_ISSUE = STD_RW_EQUITY_DEFAULT ;
 
     end ;
     
     else do ;
        /*- other equity exposures receive 100% risk weight: CRR Art. 133(2) -*/    
        OUTV_RW_ISSUE = STD_RW_EQUITY_DEFAULT ;
     end ;
     
    _VALUE_ = EXP_VALUE ;
    
%mend pm_exp_equity_std_crd4 ;
