/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_2.sas
 *
 * PURPOSE: Join exposures and crms by their link relationship. 
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *****************************************************************************/

%macro r00_post_regulatory_2;

/*- get all exposure-crm links -*/

/*- 1: get exposure-netting links -*/
    proc sql;
    create table &RESLIB1..exposure_netting_link as
    select exp.EXP_ID, crm.CRM_ID, 0 as EXPOSURE_RANK, 0 as CRM_RANK,
           exp.NETTING_SET_RK as NETTING_SET_RK
    from &RESLIB1..all_exposures as exp, 
         "&VALPATH&PATHSEP.crms_netting" as crm
    where exp.NETTING_SET_RK = crm.NETTING_SET_RK
    order by exp.NETTING_SET_RK;
    quit;
    
    data &RESLIB1..exposure_netting_link (drop=NETTING_SET_RK);
    merge &RESLIB1..exposure_netting_link (in=a) RD_POS.netting_set (in=b keep=MATURITY_DATE NETTING_SET_RK);
    if a and b;
    by NETTING_SET_RK;
    run;

/*- 2: update original exposure-crm link -*/
    data &RESLIB1..full_exposure_crm_link(index=(EXPCRM=(EXP_ID CRM_ID)));
    length EXP_ID CRM_ID $32.;
    set RD_POS.exposure_crm_link
        &RESLIB1..exposure_netting_link
        ; 
    run;

	%let var1 = %varexist(&RESLIB1..all_crms,TRADE_EXP_FLG);
	%let var2 = %varexist(&RESLIB1..all_crms,TRADING_BOOK_FLG);
	%let var3 = %varexist(&RESLIB1..all_crms,BANKRUPTCY_REMOTE_FLG);

/*- 3: create ALL possibilities for exposure-crm pairs for crm eligibility check -*/
   proc sql;
   create table &RESLIB1..all_exposure_crm(index=(EXPCRM=(EXP_ID CRM_ID))) as
   select exp.* , crm.*,
          link.EXPOSURE_RANK as EXPOSURE_RANK, 
          link.CRM_RANK as CRM_RANK,
          link.MATURITY_DATE as LINK_MATURITY_DATE,
          link.COVERED_VALUE_AMT as COVERED_VALUE_AMT
   from &RESLIB1..all_exposures as exp
   inner join &RESLIB1..full_exposure_crm_link as link 
   on exp.EXP_ID=link.EXP_ID
  inner join  &RESLIB1..all_crms  (drop =   %if &var1 %then %do; TRADE_EXP_FLG %end; 
											%if &var2 %then %do; TRADING_BOOK_FLG %end; 
											%if &var3 %then %do; BANKRUPTCY_REMOTE_FLG %end;) as crm 
   on crm.CRM_ID=link.CRM_ID
   order by exp.EXP_ID ;
   quit;

%mend r00_post_regulatory_2;
