*********************************************************************************;
* Copyright (c) 2015 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. *;
* Name   : rrm_create_entity_str.sas                                            *;
* Purpose: Create folder structure required for Entity creation.                *;
*                                                                               *;
* CHANGE LOG:                                                                   *;
*********************************************************************************;
%macro rrm_create_entity_str(usr_mode=,usr_nm=,CREATE_IN_USER_MODE=);

%global pathsep main_exist skip_entity_update ;

	%let CMHOME=;
	*********************************************************************************;
	* Retrieve property values from software component                              *;
	* Path will be refered till version Number.                                     *;
	*********************************************************************************;
	%criskm_get_swc_property(propertyName=criskmmva.CMHOME,q_rd_swc=&RD_SWC,outvar=CMHOME);
    options set = CMHOME "&CMHOME";

    %getdelimiter;

	/*Check if entity main Exist or not*/
	%LET home_loc=  %sysget(CMHOME);
	%LET group_loc= %sysget(CMHOME)&pathsep.groups;
	%LET main_loc = %sysget(CMHOME)&pathsep.groups&pathsep.main;
	%LET skip_entity_update=N;


	%IF %SYSFUNC(FILEEXIST(&group_loc )) %THEN
		%DO;
			%LET group_exist=Y;
		%END;
	%ELSE 
		%DO;
			%LET group_exist=N;
		%END;

	%IF %SYSFUNC(FILEEXIST(&main_loc )) %THEN
		%DO;
			%LET main_exist=Y;
		%END;
	%ELSE 
		%DO;
			%LET main_exist=N;
		%END;

************************************************************************;
* If main entity does not exist then goto exist.                       *;
* Main should be created first before any other entity can be created. *;
*                                                                      *;
* Main NOT AVAILABLE ,USER trying ENTITY Other than MAIN -ER-ROR       *;
************************************************************************;
/*
%IF &main_exist=N AND &system_id NE main %THEN %DO;
	%PUT ERROR:Entity MAIN Does not Exist.;
	%PUT Entity MAIN Required Before Creating Any New Entity.;
	%LET skip_entity_update=Y;
	%GOTO EXIT;
%END ;
*/
************************************************************************;
* If main entity does not exist and user requested for main.           *;
*                                                                      *;
* Main NOT AVAILABLE ,USER trying ENTITY MAIN -NO ER-ROR                *;
************************************************************************;
%IF &main_exist=N AND %lowcase(&system_id.) EQ main %THEN %DO; /*create_main: Loop Begin*/

	%IF &Execute_in=master_mode %THEN %DO;/*CREATE_MAIN_MASTER:LOOP BEGIN*/
		%PUT NOTE:Creating Entity MAIN.;
		%rrm_create_master;
	%END;/*CREATE_MAIN_MASTER:LOOP END*/
%END ;/*CREATE_MAIN:LOOP END*/
%IF &main_exist=Y AND %lowcase(&system_id.) EQ main  %THEN %DO; /*create_main: Loop Begin*/

	%IF &Execute_in=master_mode %THEN %DO;/*CREATE_MAIN_MASTER:LOOP BEGIN*/
		%PUT NOTE:Updating Entity MAIN in Master Mode.;
		%rrm_create_master;
	%END;/*CREATE_MAIN_MASTER:LOOP END*/
	%if &directory=users %then %do;
		%PUT NOTE:Requested Entity MAIN in user mode.;
			%IF %SYSFUNC(FILEEXIST(&main_loc.&pathsep.master )) %THEN %do; /*CREATE MAIN IN USERMODE:BEGIN*/
				%LET proceed_to_usermode=Y;
				%rrm_create_user;
			%END;/* CREATE MAIN IN USERMODE:END*/
			%ELSE %DO;
				%LET proceed_to_usermode=N;
				%PUT ERROR:Master Mode does Exist,Please create Master mode.;
				%LET skip_entity_update=Y;
				%goto EXIT;

			%END;
	%end;
%END;
************************************************************************;
* If main entity does not exist and user requested for main.           *;
************************************************************************;

%IF &group_exist=Y AND %lowcase(&system_id.) NE main %THEN %DO;
 *****************************************************************************;
 * Check for Entity group in Metadata                                        *;
 *****************************************************************************;
  data entity_value;
   length Entity_name $32. entity_exist 8.;
   Entity_name="";
   entity_exist=.;
   if _n_>1 then output;
  run;
     %rrm_check_group(group_nm=CreditRiskAdmin_&system_id.);
     %rrm_check_group(group_nm=CreditRiskUser_&system_id.);
     %rrm_check_group(group_nm=CreditRiskAnalyst_&system_id.);
	 
  proc sql noprint;
   select sum(entity_exist)  into :entity_exist_count
   from entity_value;
  quit;
  
  %if %sysevalf(&entity_exist_count eq 3) %then %do;
        %LET skip_entity_update=Y;
        %put ERROR:The Group &system_id. does not exist in metadata,Please refer to Admin Guide.;

		%goto EXIT;
    
  %end;
  

	%IF &Execute_in=master_mode %THEN %DO;/*create_main_master:Loop Begin*/
		%PUT NOTE:Creating Entity &system_id.;
		%rrm_create_master;
	%END;/*create_main_master:Loop Begin*/

	%ELSE %DO;/*create_main_master:Else Loop Begin*/
		%PUT NOTE:Requested Entity &system_id in user mode.;
			%IF %SYSFUNC(FILEEXIST(&group_loc.&pathsep.&system_id.&pathsep.master )) %THEN %do;
				%LET proceed_to_usermode=Y;
				%rrm_create_user;
			%END;
			%ELSE %DO;
				%LET proceed_to_usermode=N;
				%PUT ERROR:Master Mode does Exist for entity ,Please create Master mode.;
				%LET skip_entity_update=Y;
				%goto EXIT;
			%END;
	%END;/*create_main_master:Else Loop end*/
%END ;



%EXIT:

%mend rrm_create_entity_str;
